%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing restricted alpha        %
%          standard errors, test results and require the         %
%          user to select the new alpha or not                   %
%                                                                %
%          Function: alphadlg                                    %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                       infomat: summary information about       %
%                           about the estimation                 %
%                       pvals: pvalues of test (if any)          %
%                       LRtests: LR tests of restrictions        %
%                       epsilon: nxT matrix with residuals       %
%                       Psir: nxnq matrix                        %
%                       alphar: nxr matrix                       %
%                       Sigma_theta: covariance matrix for Psir  %
%                           and alphar                           %
%                                                                %
%          Output:                                               %
%                       h = handle                               %
%                                                                %
%          This version:        July 4, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = alphadlg(selector,cm,infomat,pvals,LRtests,epsilon,Psir,alphar,Sigma_theta)

if strcmp(selector,'init')==1;
   tm = cm;
   tm.restrict(1,1) = 1;
   %
   curr_ini = find_inisettings;
   if curr_ini.lagtest>0;
      lagenable = 'on';
   else;
      lagenable = 'off';
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   tm.newbZ1t = tm.newbeta'*tm.Z1t;
   tm.newbR1t = tm.newbeta'*tm.R1t;
   tm.epsilon = epsilon;
   tm.Psir = Psir;
   tm.alphar = alphar;
   tm.Sigma_theta = Sigma_theta;
   g = size(tm.Sigma_theta,2);
   %
   std_alpha = vecinv(sqrt(abs(diag(tm.Sigma_theta(g-(tm.n*tm.r)+1:g,g-(tm.n*tm.r)+1:g)))),tm.n);
   curralpha = vecstr(tm.evars,':      ');
   curralpha = strvcat(' ',' ',curralpha);
   for j=1:tm.r;
      addtoalpha = '';
      for i=1:tm.n;
         if tm.alphar(i,j)<0;
            if abs(tm.alphar(i,j))>1.0e-005;
               addtoalpha = strvcat(addtoalpha,[num2str(tm.alphar(i,j),'%1.4f') '  (' num2str(std_alpha(i,j),'%1.4f') ')     ']);
            else;
               addtoalpha = strvcat(addtoalpha,' 0       (-)      ');
            end;
         else;
            if abs(tm.alphar(i,j))>1.0e-005;
               addtoalpha = strvcat(addtoalpha,[' ' num2str(tm.alphar(i,j),'%1.4f') '  (' num2str(std_alpha(i,j),'%1.4f') ')     ']);
            else;
               addtoalpha = strvcat(addtoalpha,' 0       (-)      ');
            end;
         end;
      end;
      sizeadd = size(addtoalpha,2)-16;
      if j>9;
         sizeadd = sizeadd-1;
      end;
      paddalpha = '';
      for i=1:sizeadd;
         paddalpha = [paddalpha ' '];
      end;
      curralpha = [curralpha strvcat(' ',[paddalpha num2str(j)],addtoalpha)];
   end;
   curralpha = strvcat(curralpha,' ');
   %
   % import images
   %
   button_images = read_images;
   %
   tm.myrun = 0;
   currbeta = showbeta(tm.newbeta,tm.evars,strtrim([tm.xvars1 ' ' tm.restvec]));
   myuserestrict = 0;
   thisexit = 0;
   addheight = 0;
   %
   tm.model_info.header = 'Number of iterations for algorithm:';
   tm.model_info.info = num2str(infomat(1,1),'%0.0f');
   if curr_ini.reestbeta==0;
      tm.model_info.header = strvcat(tm.model_info.header,'Value of convergence criterion (max|dlnL/dalpha|):');
   else;
      if curr_ini.betagrad==1;
         tm.model_info.header = strvcat(tm.model_info.header,'Value of convergence criterion (max|dlnL/dbeta|):');
      else;
         tm.model_info.header = strvcat(tm.model_info.header,'Value of convergence criterion (|(lnL(i)-lnL(i-1))/lnL(i-1)|):');
      end;
   end;
   tm.model_info.info = strvcat(tm.model_info.info,num2str(infomat(1,2)),num2str(tm.evalue,'%0.4f'));
   tm.model_info.header = strvcat(tm.model_info.header,'Largest non-unit eigenvalue of the companion matrix:');
   %
   add_s = '';
   if tm.dfalpha>1;
      add_s = 's';
   end;
   if curr_ini.sscorrect==0;
      if isempty(LRtests)==0;
         tm.model_info.header = strvcat(tm.model_info.header,['LR-test of ' num2str(tm.dfalpha) ' alpha restriction' add_s ':']);
         tm.model_info.info = strvcat(tm.model_info.info,num2str(LRtests(1,1),'%0.4f'));
         if isempty(pvals)==0;
            tm.model_info.header = strvcat(tm.model_info.header,'p-value:');
            tm.model_info.info = strvcat(tm.model_info.info,num2str(pvals(1,1),'%0.4f'));
         end;
         if tm.dfbeta>0;
            tm.model_info.header = strvcat(tm.model_info.header,['LR-test of ' num2str(tm.dfbeta+tm.dfalpha) ' alpha and beta restrictions:']);
            tm.model_info.info = strvcat(tm.model_info.info,num2str(LRtests(1,2),'%0.4f'));
             addheight = 35;
            if isempty(pvals)==0;
               tm.model_info.header = strvcat(tm.model_info.header,'p-value:');
               tm.model_info.info = strvcat(tm.model_info.info,num2str(pvals(1,2),'%0.4f'));
            end;
         end;
      end;
   else;
      if isempty(LRtests)==0;
         tm.model_info.header = strvcat(tm.model_info.header,['F-test of (' num2str(tm.dfalpha) ',' num2str(cm.T-cm.df1) ') alpha restriction' add_s ':']);
         tm.model_info.info = strvcat(tm.model_info.info,num2str(LRtests(1,1),'%0.4f'));
         if isempty(pvals)==0;
            tm.model_info.header = strvcat(tm.model_info.header,'p-value:');
            tm.model_info.info = strvcat(tm.model_info.info,num2str(pvals(1,1),'%0.4f'));
         end;
         if tm.dfbeta>0;
            tm.model_info.header = strvcat(tm.model_info.header,['F-test of (' num2str(tm.dfbeta+tm.dfalpha) ',' num2str(cm.T-cm.df2) ')' ' alpha and beta restrictions:']);
            tm.model_info.info = strvcat(tm.model_info.info,num2str(LRtests(1,2),'%0.4f'));
            addheight = 35;
            if isempty(pvals)==0;
               tm.model_info.header = strvcat(tm.model_info.header,'p-value:');
               tm.model_info.info = strvcat(tm.model_info.info,num2str(pvals(1,2),'%0.4f'));
            end;
         end;
      end;
   end;
   %
   if tm.evalue>=1;
      mypermcompenable = 'off';
   else;
      mypermcompenable = 'on';
   end;
   cmatenable = mypermcompenable;
   weakexoenable = 'on';
   if tm.r==tm.n;
      weakexoenable = 'off';
   end;
   if (tm.n==1)&(tm.q1+tm.q0==0);
      gcenable = 'off';
   else;
      gcenable = 'on';
   end;
   dfc = round((((tm.n+tm.q1+tm.dcoint-tm.r)*tm.r)-tm.dfbeta)/tm.n);
   tm.df = tm.n*(tm.p-1)+tm.r+tm.q1*tm.pe+tm.q0*(tm.pe+1)+tm.d+dfc-round(tm.dfalpha/tm.n);
else;
   thisexit = 1;
   alphadlggui = findobj('Type','figure','Tag','AlphaDLG')';
   alpharest = get(alphadlggui,'UserData');
   curr_ini = get(alpharest.viewdata,'UserData');
   button_images = curr_ini.images;
   tm = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

scrsz = [1 1 1024 768];
realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      addb = 'Alpha';
      if tm.dfbeta>0;
         addb = 'Alpha and Beta';
      end;
      alphadlggui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','alphadlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-scrsz(3)/2)/2-50 (realscrsz(4)-435-addheight)/2 scrsz(3)/2+100 435+addheight], ...
         'Tag','AlphaDLG', ...
         'Resize','off', ...
         'Name',['Restrictions on ' addb ' - Results'], ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'CloseRequestFcn','alphadlg wayout', ...
         'ToolBar','none');


      if matlabnumber>=7.0;
         set(alphadlggui,'DockControl','off');
      end;

      %
      % File menu
      %

      filemenu = uimenu('Parent',alphadlggui, ...
         'Label','&File', ...
         'Tag','FileMenu');

      %
      % Objects on File menu
      %

      alpharest.viewdata = uimenu('Parent',filemenu, ...
         'Label','View &Data...', ...
         'Callback','alphadlg viewdata', ...
         'Enable','on', ...
         'Tag','ViewData');

      alpharest.savecoint = uimenu('Parent',filemenu, ...
         'Label','Save &Cointegration Relations...', ...
         'Callback','alphadlg savecoint', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','SaveResid');

      alpharest.savetc = uimenu('Parent',filemenu, ...
         'Label','Save &Transitory Components...', ...
         'Callback','alphadlg savetc', ...
         'Accelerator','T', ...
         'Enable',mypermcompenable, ...
         'Tag','SaveTC');

      alpharest.saveresid = uimenu('Parent',filemenu, ...
         'Label','Save &Residuals...', ...
         'Callback','alphadlg saveresid', ...
         'Accelerator','D', ...
         'Enable','on', ...
         'Tag','SaveCoint');

      uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

      alpharest.menuuse = uimenu('Parent',filemenu, ...
         'Label','&Use New Alpha', ...
         'Callback','alphadlg use', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuFileUse');

      alpharest.menuskip = uimenu('Parent',filemenu, ...
         'Label','R&ecycle New Alpha', ...
         'Callback','alphadlg skip', ...
         'Enable','off', ...
         'Tag','MenuFileSkip');

      alpharest.menucontinue = uimenu('Parent',filemenu, ...
         'Label','C&ontinue', ...
         'Separator','on', ...
         'Callback','alphadlg done', ...
         'Accelerator','C', ...
         'Enable','on', ...
         'Tag','MenuFileContinue');


      %
      % Tools menu
      %

      testmenu = uimenu('Parent',alphadlggui, ...
         'Label','&Tools', ...
         'Tag','TestMenu');

      %
      % Objects on Tools menu
      %

      alpharest.corrtest = uimenu('Parent',testmenu, ...
         'Label','&Serial Correlation...', ...
         'Callback','alphadlg corrtest', ...
         'Enable','on', ...
         'Accelerator','S', ...
         'Tag','CorrTest');

      alpharest.archtest = uimenu('Parent',testmenu, ...
         'Label','&ARCH...', ...
         'Callback','alphadlg archtest', ...
         'Accelerator','A', ...
         'Enable','on', ...
         'Tag','ArchTest');

      alpharest.normalitytest = uimenu('Parent',testmenu, ...
         'Label','&Normality...', ...
         'Callback','alphadlg normalitytest', ...
         'Accelerator','N', ...
         'Enable','on', ...
         'Tag','NormalityTest');

      alpharest.constancytest = uimenu('Parent',testmenu, ...
         'Label','&Parameter Constancy...', ...
         'Callback','alphadlg constancytest', ...
         'Accelerator','P', ...
         'Enable','on', ...
         'Tag','ConstancyTest');

      alpharest.lagorder = uimenu('Parent',testmenu, ...
         'Label','&Lag Order...', ...
         'Callback','alphadlg lagorder', ...
         'Separator','on', ...
         'Accelerator','L', ...
         'Enable',lagenable, ...
         'Tag','LagOrder');

      alpharest.weakexo = uimenu('Parent',testmenu, ...
         'Label','&Weak Exogeneity...', ...
         'Callback','alphadlg weakexo', ...
         'Enable',weakexoenable, ...
         'Tag','WeakExogeneity');

      alpharest.gctest = uimenu('Parent',testmenu, ...
         'Label','&Granger Causality...', ...
         'Callback','alphadlg gctest', ...
         'Accelerator','G', ...
         'Enable',gcenable, ...
         'Tag','GrangerCausality');

      if tm.n>2;
         alpharest.multigctest = uimenu('Parent',testmenu, ...
         'Label','M&ulti-Step Granger Causality...', ...
         'Callback','alphadlg multigctest', ...
         'Enable','on', ...
         'Tag','MultiGrangerCausality');
      end;

      if ((tm.p>1)&(tm.n>2))|(tm.q0>0)|((tm.q1>0)&(tm.pe>0));
         alpharest.exclude = uimenu('Parent',testmenu, ...
            'Label','&Exclusion', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ExclusionMenu');
         
         alpharest.firstdiffs = uimenu('Parent',alpharest.exclude, ...
            'Label','&First Differences', ...
            'Callback','alphadlg firstdiffs', ...
            'Enable','on', ...
            'Tag','FirstDiffMenu');
      end;

      if (tm.p>1)&(tm.r<tm.n);
         alpharest.common_cycles = uimenu('Parent',testmenu, ...
            'Label','Co&mmon Cycles...', ...
            'Callback','alphadlg common_cycles', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','ShowCommonCycles');
      end;

      if tm.datad>0;
         alpharest.dummy = uimenu('Parent',testmenu, ...
            'Label','&Deterministic Variables', ...
            'Separator','on', ...
            'Enable','on', ...
            'Tag','DummyVarMenu');

         alpharest.dummyexclusion = uimenu('Parent',alpharest.dummy, ...
            'Label','&Exclusion...', ...
            'Callback','alphadlg dummyexclusion', ...
            'Enable','on', ...
            'Tag','DummyExclusionMenu');

         alpharest.dummylongrun = uimenu('Parent',alpharest.dummy, ...
            'Label','&Long Run...', ...
            'Callback','alphadlg dummylongrun', ...
            'Enable',weakexoenable, ...
            'Tag','DummyLongRunMenu');

         if tm.datad>1;
            alpharest.propdummy = uimenu('Parent',alpharest.dummy, ...
            'Label','&Proportionality...', ...
            'Callback','alphadlg dummyprop', ...
            'Enable','on', ...
            'Tag','DummyPropMenu');
         end;

      end;

      alpharest.cmat = uimenu('Parent',testmenu, ...
         'Label','&C-Matrix...', ...
         'Callback','alphadlg cmat', ...
         'Separator','on', ...
         'Accelerator','M', ...
         'Enable',cmatenable, ...
         'Tag','CMatrix');

      alpharest.longrun_gir = uimenu('Parent',testmenu, ...
         'Label','L&ong Run GIRs...', ...
         'Callback','alphadlg longrun_gir', ...
         'Separator','off', ...
         'Enable',cmatenable, ...
         'Tag','LongRunGIRsMenu');

      alpharest.residanalysis = uimenu('Parent',testmenu, ...
         'Label','&Residual Analysis...', ...
         'Callback','alphadlg residanalysis', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','ResidAnalysis');

      alpharest.shortdyn = uimenu('Parent',testmenu, ...
         'Label','S&hort Run Dynamics...', ...
         'Callback','alphadlg shortdyn', ...
         'Accelerator','Y', ...
         'Enable','on', ...
         'Tag','ShortDyn');

      alpharest.distribution = uimenu('Parent',testmenu, ...
         'Label','Distri&bution...', ...
         'Callback','alphadlg distribution', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','DistributionMenu');

      %
      % Graphics menu
      %

      graphmenu = uimenu('Parent',alphadlggui, ...
         'Label','&Graphics', ...
         'Tag','GraphicsMenu');

      alpharest.menugraph = uimenu('Parent',graphmenu, ...
         'Label','&Cointegration Relations...', ...
         'Callback','alphadlg graphs', ...
         'Enable','on', ...
         'Tag','MenuGraph');

      alpharest.menupermcomp = uimenu('Parent',graphmenu, ...
         'Label','&Permanent and Transitory Components...', ...
         'Callback','alphadlg permcomp', ...
         'Enable',mypermcompenable, ...
         'Accelerator','E', ...
         'Tag','MenuPermComp');

      alpharest.menuresiduals = uimenu('Parent',graphmenu, ...
         'Label','&Residuals...', ...
         'Callback','alphadlg residuals', ...
         'Enable','on', ...
         'Accelerator','I', ...
         'Tag','MenuResiduals');

      alpharest.menufitted = uimenu('Parent',graphmenu, ...
         'Label','Fitted &Terms...', ...
         'Callback','alphadlg fitted', ...
         'Enable','on', ...
         'Tag','MenuFitted');

      alpharest.forecast = uimenu('Parent',graphmenu, ...
         'Label','Forec&asting...', ...
         'Callback','alphadlg forecast', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuForecast');

      alpharest.varforecast = uimenu('Parent',graphmenu, ...
         'Label','Forecast &Variable Transformations...', ...
         'Callback','alphadlg varforecast', ...
         'Enable','on', ...
         'Tag','MenuVARForecast');

      if tm.q1+tm.q0>0;
         set(alpharest.forecast,'Enable','off');
         set(alpharest.varforecast,'Enable','off');
      end;

      alpharest.menuchow = uimenu('Parent',graphmenu, ...
         'Label','Recursive Ch&ow Tests', ...
         'Callback','alphadlg chow', ...
         'Separator','on', ...
         'Accelerator','O', ...
         'Enable','on', ...
         'Tag','MenuChow');

      alpharest.menuploberger = uimenu('Parent',graphmenu, ...
         'Label','Recursive &Fluctuation Test', ...
         'Callback','alphadlg ploberger', ...
         'Accelerator','F', ...
         'Enable','on', ...
         'Tag','MenuPloberger');

      alpharest.genimpulse = uimenu('Parent',graphmenu, ...
         'Label','&Generalized Impulse Responses...', ...
         'Callback','alphadlg genimpulse', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuGeneralizedImpulse');

%      if (isempty(tm.isdummy)==0)&(max(tm.isdummy)==1);
      if tm.datad>0;
         alpharest.dummyimpulse = uimenu('Parent',graphmenu, ...
            'Label','&Dummy Impulse Responses...', ...
            'Callback','alphadlg dummyimpulse', ...
            'Enable','on', ...
            'Tag','MenuDummyImpulse');
      end;

      alpharest.companion = uimenu('Parent',graphmenu, ...
         'Label','Eigenvalues of Companion &Matrix', ...
         'Callback','alphadlg companion', ...
         'Separator','on', ...
         'Enable','on', ...
         'Tag','MenuCompanion');

      %
      % Help menu
      %

      helpmenu = uimenu('Parent',alphadlggui, ...
         'Label','&Help', ...
         'Tag','HelpMenu');

      alpharest.beta_help = uimenu('Parent',helpmenu, ...
            'Label','&Restrictions on Alpha', ...
            'Callback','help_fcn(''RestrictionsonAlpha'');', ...
            'Accelerator','H', ...
            'Separator','off', ...
            'Enable','on', ...
            'Tag','MenuAlphaHelp');

      %
      % Horizontal lines for toolbar
      %

%      xline([1 scrsz(4)/2+51+addheight (scrsz(3)/2)+40],[0.5 1]);

      xline([1 434+addheight (scrsz(3)/2)+100],[0.5 1]);

      alpharest.toolbar = uitoolbar('Parent',alphadlggui, ...
                        'HandleVisibility','off', ...
                        'Interruptible','on', ...
                        'Clipping','on');

      %
      %  Use button
      %

      alpharest.use = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Use New Alpha', ...
                         'CData',button_images.pickalpha, ...
                         'ClickedCallback','alphadlg use', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','UseButton');

      alpharest.skip = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Recycle New Alpha', ...
                         'CData',button_images.skipalpha, ...
                         'ClickedCallback','alphadlg skip', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','off', ...
                         'Tag','SkipButton');

      %
      %  Done button
      %

      alpharest.done = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Continue', ...
                         'CData',button_images.continue, ...
                         'ClickedCallback','alphadlg done', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'UserData','waiting', ...
                         'Enable','on', ...
                         'Tag','DoneButton');

      %
      % Graphics button
      %

      alpharest.graphs = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Cointegration Relations', ...
                         'CData',button_images.graph, ...
                         'ClickedCallback','alphadlg graphs', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'UserData','working', ...
                         'Enable','on', ...
                         'Tag','Graphics');

      alpharest.permcomp = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Permanent and Transitory Components', ...
                         'CData',button_images.permcomp, ...
                         'ClickedCallback','alphadlg permcomp', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable',mypermcompenable, ...
                         'Tag','PermCompGraphics');

      alpharest.residgraph = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Residuals', ...
                         'CData',button_images.histogram, ...
                         'ClickedCallback','alphadlg residuals', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ResidGraphics');

      %
      % Forecasting button
      %

      alpharest.forecast_button = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Forecasting', ...
                         'CData',button_images.forecast, ...
                         'ClickedCallback','alphadlg forecast', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','ForecastGraph');

      if tm.q1+tm.q0>0;
         set(alpharest.forecast_button,'Enable','off');
      end;

      %
      % Chow test button
      %

      alpharest.chow = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Recursive Chow Tests', ...
                         'CData',button_images.chow, ...
                         'ClickedCallback','alphadlg chow', ...
                         'Separator','on', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecChowGraph');

      alpharest.ploberger = uipushtool('Parent',alpharest.toolbar, ...
                         'TooltipString','Recursive Fluctuation Test', ...
                         'CData',button_images.fluctest, ...
                         'ClickedCallback','alphadlg ploberger', ...
                         'Separator','off', ...
                         'Interruptible','on', ...
                         'Clipping','on', ...
                         'Enable','on', ...
                         'Tag','RecPlobGraph');

      %
      % Outer axis
      %

      axesbox([2 2 (scrsz(3)/2)+98 420+addheight],'Maximum Likelihood Results',135,[0.5 1]);

      %
      % Outer axis for showing beta
      %

      axesbox([14 143+addheight scrsz(3)/2+72 262],'Current Beta'' and Alpha Matrix',114,[0.5 1]);

      %
      % Outer axis for additional info
      %

      axesbox([14 14 scrsz(3)/2+72 115+addheight],'Estimation Information',105,[0.5 1]);

      %
      % Listbox for showing estimated beta
      %

      alpharest.betamat = uicontrol('Units','pixels', ...
         'BackgroundColor','white', ...
         'Position',[30 280+addheight scrsz(3)/2+40 110], ...
         'Style','listbox', ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'TooltipString','Restricted beta estimates', ...
         'Max',2, ...
         'Value',[], ...
         'String',currbeta, ...
         'Enable','inactive', ...
         'UserData',myuserestrict, ...
         'HorizontalAlignment','center', ...
         'Tag','AlphaListbox');

      %
      % Listbox for showing estimated conditional standard
      % errors for beta
      %

      alpharest.alphamat = uicontrol('Units','pixels', ...
         'BackgroundColor','white', ...
         'Position',[30 159+addheight scrsz(3)/2+40 110], ...
         'Style','listbox', ...
         'FontSize',10, ...
         'FontName','FixedWidth', ...
         'TooltipString','Restricted alpha estimates with standard errors within parentheses', ...
         'Max',2, ...
         'Value',[], ...
         'String',curralpha, ...
         'Enable','inactive', ...
         'UserData','working', ...
         'HorizontalAlignment','center', ...
         'Tag','AlphaStdListbox');

      %
      % Show output text
      %


      alpharest.model_header = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 30 scrsz(3)/2+40 83+addheight], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'Visible','on', ...
         'HorizontalAlignment','left', ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'String',tm.model_info.header, ...
         'Tag','OutputText');

      head_ext = get(alpharest.model_header,'Extent');
      if head_ext(1,4)<=83+addheight;
         new_pos = [30 30+(83+addheight-head_ext(1,4))/2 head_ext(1,3:4)];
      else;
         new_pos = [30 30 head_ext(1,3) 83+addheight];
      end;
      set(alpharest.model_header,'Position',new_pos);

      alpharest.model_info = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[35+new_pos(1,3) new_pos(1,2) scrsz(3)/2+35-new_pos(1,3) new_pos(1,4)], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String',tm.model_info.info, ...
         'ForegroundColor',curr_ini.gui_foreground_color, ...
         'HorizontalAlignment','left', ...
         'Tag','ModelInfoText');

      set(alphadlggui,'UserData',alpharest,...
         'HandleVisibility','callback');

   case 'fitted'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         thisgraph = fittedterms('init',tm,[tm.Psir tm.alphar],tm.newbeta);
         fitted = get(thisgraph,'UserData');
         set(fitted.show,'UserData','done');
         killguipid(thisgraph);
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'companion'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_companion(tm.newbeta,tm.alphar,tm.Psir,tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'distribution'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         %
         thisgraph = distdlg('init',tm.cbs);
         killguipid(thisgraph);
         %
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'common_cycles'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         show_common_cycles(tm,curr_ini,tm.alphar,tm.Psir,tm.newbeta);
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'dummyprop'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         oldalpha = tm.alpha;
         oldbeta = tm.beta;
         oldPsi = tm.Psi;
         tm.alpha = tm.alphar;
         tm.beta = tm.newbeta;
         tm.Psi = tm.Psir;
         proportionality_dummies_dlg('init',tm,curr_ini);
         tm.alpha = oldalpha;
         tm.beta = oldbeta;
         tm.Psi = oldPsi;
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'dummylongrun'
      if tm.myrun==0;
         tm.myrun = 1;
         oldalpha = tm.alpha;
         oldbeta = tm.beta;
         oldPsi = tm.Psi;
         tm.alpha = tm.alphar;
         tm.beta = tm.newbeta;
         tm.Psi = tm.Psir;
         show_longrun_dummies(alphadlggui,tm,curr_ini);
         tm.alpha = oldalpha;
         tm.beta = oldbeta;
         tm.Psi = oldPsi;
         tm.myrun = 0;
      end;
   case 'dummyexclusion'
      if tm.myrun==0;
         tm.myrun = 1;
         show_exclude_dummies(alphadlggui,tm,curr_ini);
         tm.myrun = 0;
      end;
   case 'dummyimpulse'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         %
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         alpha = tm.alphar;
         beta = tm.newbeta;
         Psi = tm.Psir;
         Sigma_theta = tm.Sigma_theta;
         %
         txt = 'Would you like to impose restrictions on the dummy variables?';
         if (tm.datad>1)|((tm.r<tm.n)&(tm.r>0));
            answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'no');
         else;
            answer = 'No';
         end;
         if strcmp(answer,'Yes')==1;
            %
            % open a select restrictions dialog
            %
            cm = restrict_dummies_dlg('init',tm,curr_ini);
            if strcmp(cm.action,'cancel')==0;
               %
               % check if we should use new estimated
               %
               if (isfield(cm,'applied')==1)&(isempty(cm.applied)==0)&(ischar(cm.applied)==1)&(strcmp(cm.applied,'applied')==1);
                  if isfield(cm,'dm')==1;
                     txt = 'Are you sure you want to use the restricted estimates for the dummy impulse responses?';
                     answer = query(txt,'question',120,'Structural VAR - Dummy Restrictions',300,'yes');
                     if strcmp(answer,'Yes')==1;
                        alpha = cm.dm.alpha;
                        beta = cm.dm.beta;
                        Psi = cm.dm.Psi;
                        Omega = cm.dm.Omega;
                        Sigma_theta = cm.dm.Sigma_theta;
                     end;
                  end;
               end;
            else;
               %
               % no dummy impulses
               %
               set(alphadlggui,'Visible','on');
               drawnow;
               return;
            end;
         end;
         %
         setlogtext(strvcat(['Computing impulse responses for dummies up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
         abort = '';
         %
         [tm.duir,tm.duir_std,tm.buir,tm.buir_std,abort] = dummy_impulses_fcn(tm,alpha,beta,Psi,Omega,Sigma_theta,1);
         %
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+tm.c)/200);
            for i=1:size(tm.duir,2);
               for j=1:tm.n*tm.datad;
                  if abs(tm.duir_std(j,i))<1.0e-008;
                     tm.duir_std(j,i) = 0;
                  end;
               end;
            end;
            tm.duir_upper = tm.duir+(c_val*tm.duir_std);
            tm.duir_lower = tm.duir-(c_val*tm.duir_std);
            %
            if isempty(tm.buir)==0;
               for i=1:size(tm.buir,2);
                  for j=1:tm.r*tm.datad;
                     if abs(tm.buir_std(j,i))<1.0e-008;
                        tm.buir_std(j,i) = 0;
                     end;
                  end;
               end;
               tm.buir_upper = tm.buir+(c_val*tm.buir_std);
               tm.buir_lower = tm.buir-(c_val*tm.buir_std);
            else;
               tm.buir_upper = [];
               tm.buir_lower = [];
            end;
            %
            thisgraph = duir_graphdlg('init',tm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'genimpulse'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         setlogtext(strvcat(['Computing generalized impulse responses up to period ' num2str(tm.h)],['with asymptotic ' num2str(tm.c) ' % confidence bands...']));
         abort = '';
         %
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         [tm.gir,tm.gir_std,tm.bir,tm.bir_std,abort] = generalized_impulses_fcn(tm,tm.alphar,tm.newbeta,tm.Psir,Omega,tm.Sigma_theta,1);
         if strcmp(abort,'cancel')==0;
            %
            % get the value from the normal distribution corresponding to the
            % chosen levels of significance c
            %
            c_val = norm_inv((100+tm.c)/200);
            for i=1:size(tm.gir,2);
               for j=1:tm.n*tm.n;
                  if abs(tm.gir_std(j,i))<1.0e-008;
                     tm.gir_std(j,i) = 0;
                  end;
               end;
            end;
            tm.gir_upper = tm.gir+(c_val*tm.gir_std);
            tm.gir_lower = tm.gir-(c_val*tm.gir_std);
            if isempty(tm.bir)==0;
               for i=1:size(tm.bir,2);
                  for j=1:tm.r*tm.n;
                     if abs(tm.bir_std(j,i))<1.0e-008;
                        tm.bir_std(j,i) = 0;
                     end;
                  end;
               end;
               tm.bir_upper = tm.bir+(c_val*tm.bir_std);
               tm.bir_lower = tm.bir-(c_val*tm.bir_std);
            else;
               tm.bir_upper = [];
               tm.bir_lower = [];
            end;
            thisgraph = gir_graphdlg('init',tm);
            ir_graph = get(thisgraph,'UserData');
            set(ir_graph.show,'UserData','done');
            killguipid(thisgraph);
         end;
         %
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'residanalysis'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_residual_analysis(alphadlggui,tm,ind);
         tm.myrun = 0;
      end;
   case 'corrtest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_corrtest(alphadlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'archtest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_archtest(alphadlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'normalitytest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_normalitytest(alphadlggui,tm,curr_ini,ind);
         tm.myrun = 0;
      end;
   case 'constancytest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_constancytest(alphadlggui,tm.newbeta,tm,curr_ini,ind,1,0);
         tm.myrun = 0;
      end;
   case 'weakexo'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_weakexo(alphadlggui,tm.newbeta,tm.alphar,tm.Sigma_theta,tm,curr_ini,ind,1);
         tm.myrun = 0;
      end;
   case 'longrun_gir'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         [lr_gir,lr_gir_std] = longrun_gir_fcn(tm.alphar,tm.newbeta,tm.Psir,Omega,tm.Sigma_theta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d);
         %
         addrest = ' restricted';
         if tm.dfbeta==0;
            addrest = '';
         end;
         ctext = strvcat(' ',['LONG RUN GENERALIZED IMPULSE RESPONSES (for' addrest ' rank=' num2str(tm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         ctext = strvcat(ctext,showc(lr_gir,tm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(lr_gir_std,tm.myvars),' ','t-ratios:',' ',showc(inf2nan(lr_gir./lr_gir_std),tm.myvars),' ');
         drawnow;
         textgui(ctext,'Long Run GIRs',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         %
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'cmat'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = ' restricted';
         if tm.dfbeta==0;
            addrest = '';
         end;
         if tm.r<tm.n;
            C = cmat(tm.Psir,tm.alphar,tm.newbeta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,1,tm.Sigma_theta);
         else;
            C = cmat_stat(tm.Psir,tm.alphar,tm.newbeta,tm.epsilon,tm.Z1,tm.Z2,tm.p,tm.d,1,tm.Sigma_theta);
         end;
         ctext = strvcat(' ',['THE C-MATRIX (for' addrest ' rank=' num2str(tm.r,'%1.0f') ')']);
         numchar = size(ctext,2);
         addcorr = '';
         for i=1:numchar;
            addcorr = strcat(addcorr,'=');
         end;
         ctext = strvcat(ctext,addcorr,' ');
         ctext = strvcat(ctext,showc(C(:,1:tm.n),tm.myvars),' ');
         ctext = strvcat(ctext,'Estimated asymptotic standard errors:',' ',showc(C(:,tm.n+1:2*tm.n),tm.myvars),' ','t-ratios:',' ',showc(inf2nan(C(:,1:tm.n)./C(:,tm.n+1:2*tm.n)),tm.myvars),' ');
         set(alphadlggui,'Visible','off');
         drawnow;
         textgui(ctext,'C-Matrix',[(realscrsz(3)-700)/2 (realscrsz(4)-500)/2 700 500],'Results',38);
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'lagorder'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_lagordertest(alphadlggui,tm.newbeta,tm.alphar,tm.Psir,tm.Sigma_theta,tm,curr_ini,ind,1);
         tm.myrun = 0;
      end;
   case 'firstdiffs'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_firstdiffstests(alphadlggui,tm.newbeta,tm.alphar,tm.Psir,tm.Sigma_theta,tm,curr_ini,ind,0);
         tm.myrun = 0;
      end;
   case 'gctest'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         show_gctest(alphadlggui,tm.newbeta,tm.alphar,tm.Psir,tm.Sigma_theta,tm,curr_ini,ind,1);
         tm.myrun = 0;
      end;
   case 'multigctest'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         ind = 1;
         if tm.dfbeta==0;
            ind = 0;
         end;
         alpha = tm.alpha;
         Psi = tm.Psi;
         tm.alpha = tm.alphar;
         tm.Psi = tm.Psir;
         this_graph = select_mgc('init',tm,tm.newbeta,tm.Sigma_theta,1,ind,0);
         mgc = get(this_graph,'UserData');
         set(mgc.show,'UserData','done');
         killguipid(this_graph);
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.alpha = alpha;
         tm.Psi = Psi;
         tm.myrun = 0;
      end;
   case 'shortdyn'
      if tm.myrun==0;
         tm.myrun = 1;
         Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         shortstr = shortrun(tm.alphar,tm.Psir,Omega,tm.newbeta,tm.Z1,tm.Z2,tm.p,tm.pe,tm.d,tm.deterselect,tm.q0,tm.q1,tm.evars,tm.xvars0,tm.xvars1,tm.deter,tm.restvec,1,tm.outputfile,1,tm.Sigma_theta);
         if tm.dfbeta>0;
            myshortstr = shortstr(2,:);
            oldsize = size(myshortstr,2);
            myshortstr = strrep(myshortstr,'for rank=','for restricted rank=');
            newsize = size(myshortstr,2);
            myshortstr = myshortstr(1,1:newsize-11);
            kind = findstr(myshortstr,')');
            if isempty(kind)==0;
               shortstr(2,:) = myshortstr;
               shortstr(3,:) = strrep(shortstr(3,:),'=           ','============');
            end;
         end;
         set(alphadlggui,'Visible','off');
         drawnow;
         textgui(shortstr,'Short Run Dynamics',[(realscrsz(3)-800)/2 (realscrsz(4)-500)/2 800 500],'Results',38);
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'graphs'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         set(alphadlggui,'Visible','off');
         drawnow;
         thisgraph = cointgraphdlg('init',tm,tm.newbZ1t,tm.newbR1t,ind);
         graph = get(thisgraph,'UserData');
         set(graph.show,'UserData','done');
         killguipid(thisgraph);
         set(alphadlggui,'Visible','on');
         drawnow;
         set(alphadlggui,'UserData',alpharest);
         tm.myrun = 0;
      end;
   case 'ploberger'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         show_ploberger(alphadlggui,tm.newbeta,tm,curr_ini,ind,1);
         tm.myrun = 0;
      end;
   case 'chow'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         show_chow(alphadlggui,tm.newbeta,tm,curr_ini,ind,1);
         tm.myrun = 0;
      end;
   case 'permcomp'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         [y_t,perm_y,trans_y] = permcomp(tm.Psir,tm.alphar,tm.newbeta,tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.d,tm.dcoint,tm.p,tm.pe,tm.q1,tm.q0);
         set(alphadlggui,'Visible','off');
         drawnow;
         thisgraph = pctcdlg('init',tm,y_t,perm_y,trans_y,ind);
         pctc = get(thisgraph,'UserData');
         set(pctc.show,'UserData','done');
         killguipid(thisgraph);
         set(alphadlggui,'Visible','on');
         drawnow;
         set(alphadlggui,'UserData',alpharest);
         tm.myrun = 0;
      end;
   case 'varforecast'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         old_tm = tm;
         tm.beta = tm.newbeta;
         tm.alpha = tm.alphar;
         tm.Psi = tm.Psir;
         tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         %
         thisgraph = var_forecastdlg('init',tm,[1 1]);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         tm = old_tm;
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'forecast'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alphadlggui,'Visible','off');
         drawnow;
         old_tm = tm;
         tm.beta = tm.newbeta;
         tm.alpha = tm.alphar;
         tm.Psi = tm.Psir;
         tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
         %
         thisgraph = forecastdlg('init',tm,[1 1]);
         f_cast = get(thisgraph,'UserData');
         set(f_cast.show,'UserData','done');
         killguipid(thisgraph);
         tm = old_tm;
         set(alphadlggui,'Visible','on');
         drawnow;
         tm.myrun = 0;
      end;
   case 'residuals'
      if tm.myrun==0;
         tm.myrun = 1;
         ind = 0;
         if tm.dfbeta>0;
            ind = 1;
         end;
         set(alphadlggui,'Visible','off');
         drawnow;
         thisgraph = epsilondlg('init',tm,ind);
         epsi = get(thisgraph,'UserData');
         set(epsi.show,'UserData','done');
         killguipid(thisgraph);
         set(alphadlggui,'Visible','on');
         drawnow;
         set(alphadlggui,'UserData',alpharest);
         tm.myrun = 0;
      end;
   case 'viewdata'
      if tm.myrun==0;
         tm.myrun = 1;
         if matlabnumber>=6.0;
            myfile = {'*.txt;*.data;*.wk1;*.xls;*.mat;*.csv', 'Data Files (*.txt, *.data, *.wk1, *.xls, *.mat, *.csv)'; ...
                    '*.txt;*.data', 'Text Files (*.txt, *.data)'; ...
                    '*.mat', 'MatLab MAT Files (*.mat)'; ...
                    '*.wk1', 'Lotus 1-2-3 Spreadsheets (*.wk1)'; ...
                    '*.xls', 'Excel Spreadsheets (*.xls)'; ...
                    '*.csv', 'Comma Separated Value Files (*.csv)'; ...
                    '*.*', 'All Files (*.*)'};
         else;
            if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1);
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               basedir = getpath(strtrim(afile));
               file_fltr = 'Data Files (*.txt, *.data, *.wk1, *.mat, *.csv)|*.txt;*.data;*.wk1;*.mat;*.csv|Text Files (*.txt, *.data)|*.txt;*.data|MatLab MAT Files (*.mat)|*.mat|Lotus 1-2-3 Spreadsheets (*.wk1)|*.wk1|Comma Separated Value Files (*.csv)|*.csv|All Files (*.*)|*.*|';
               best_pos = 1;
               title_txt = 'Open';
            else;
               fix_fig = findobj('Tag','StructuralVAR');
               model = get(fix_fig,'UserData');
               afile = get(model.endogenous,'String');
               afile = strtrim(afile);
               if fileexist(afile)==1;
                  adir = getpath(afile);
                  if strcmp(computer,'PCWIN')==1;
                     if strcmp(adir(1,size(adir,2)),'\')==0;
                        adir = [adir '\'];
                     end;
                  else;
                     if strcmp(adir(1,size(adir,2)),'/')==0;
                        adir = [adir '/'];
                     end;
                  end;
               else;
                  adir = tm.outputdir;
               end;
               myfile = [adir '*.txt;*.data;*.wk1;*.mat;*.csv'];
            end;
         end;
         if (iscompiled==1)&(iswinnt==1)&(curr_ini.opendialog==1)&(matlabnumber<6.0);
            [openfile,openpath] = fileopen(basedir,file_fltr,best_pos,title_txt);
         else;
            if matlabnumber>=6;
               [openfile,openpath] = uigetfile(myfile,'Open',getpath(tm.endofile));
            else;
               [openfile,openpath] = uigetfile(myfile,'Open');
            end;
         end;
         drawnow;
         if isnumeric(openfile)==0;
            openfile = strcat(openpath,openfile);
            set(alphadlggui,'Visible','off');
            drawnow;
            textgui(openfile,['View Data - ' openfile],[(realscrsz(3)-(realscrsz(4)-80))/2 1 realscrsz(4)-80 realscrsz(4)-54],'Data',25);
            set(alphadlggui,'Visible','on');
            drawnow;
         end;
         tm.myrun = 0;
      end;
   case 'savecoint'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         myfile = [tm.outputdir 'coint-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myR myT] = size(tm.newbZ1t);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving cointegration relations to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myR;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '               ci_' num2str(i,'%1.0f')];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),tm.newbZ1t(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'savetc'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         [y_t,perm_y,trans_y] = permcomp(tm.Psir,tm.alphar,tm.newbeta,tm.epsilon,tm.x0,tm.x1,tm.x1_r,tm.x2,tm.d,tm.dcoint,tm.p,tm.pe,tm.q1,tm.q0);
         myfile = [tm.outputdir 'trans.comp-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(trans_y);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving transitory components to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '              tc_' tm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),trans_y(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'saveresid'
      if tm.myrun==0;
         tm.myrun = 1;
         addrest = 'rest-';
         if tm.dfbeta==0;
            addrest = '';
         end;
         myfile = [tm.outputdir 'eps-' addrest num2str(tm.r,'%1.0f') '.data'];
         [savefile,savepath] = uiputfile(myfile,'Save As');
         drawnow;
         if isnumeric(savefile)==0;
            [myN myT] = size(tm.epsilon);
            myt = '';
            for i=1:myT;
               myt = strvcat(myt,getdate(tm.samplebeg,tm.sampleend,tm.freq,i/myT));
            end;
            setlogtext(['Saving residuals to ' savefile '...']);
            savefile = strcat(savepath,savefile);
            fid = fopen(savefile,'wt');
            myprintstr = '';
            firststr = ' DATE  ';
            prt_str = ['%' num2str(2*(curr_ini.exportdata+3),'%0.0f') '.' num2str(curr_ini.exportdata+3,'%0.0f') 'f'];
            for i=1:myN;
               myprintstr = [myprintstr '   ' prt_str];
               firststr = [firststr '             eps_' tm.myvars(i,:)];
            end;
            fprintf(fid,[firststr '\n']);
            for i=1:myT;
               fprintf(fid,['%s ' myprintstr '\n'],myt(i,:),tm.epsilon(:,i)');
            end;
            fclose(fid);
         end;
         tm.myrun = 0;
      end;
   case 'use'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alpharest.use,'Enable','off');
         set(alpharest.menuuse,'Enable','off');
         set(alpharest.skip,'Enable','on');
         set(alpharest.menuskip,'Enable','on');
         set(alpharest.betamat,'UserData',1);
         set(alphadlggui,'UserData',alpharest);
         tm.myrun = 0;
      end;
   case 'skip'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alpharest.use,'Enable','on');
         set(alpharest.menuuse,'Enable','on');
         set(alpharest.skip,'Enable','off');
         set(alpharest.menuskip,'Enable','off');
         set(alpharest.betamat,'UserData',0);
         set(alphadlggui,'UserData',alpharest);
         tm.myrun = 0;
      end;
   case 'done'
      if tm.myrun==0;
         tm.myrun = 1;
         set(alpharest.done,'UserData','done');
         set(alphadlggui,'UserData',alpharest);
         tm.myrun = 0;
      end;
   case 'wayout'
      set(alpharest.done,'UserData','done');
      if strcmp(get(alpharest.alphamat,'UserData'),'done')==1;
         delete(alphadlggui);
      end;
end;

if strcmp(selector,'init')==1;
   set(alphadlggui,'Visible','on');
end;

if strcmp(selector,'wayout')==0;
   curr_ini.images = button_images;
   curr_ini.models = tm;
   set(alpharest.viewdata,'UserData',curr_ini);
end;

if nargout==1;
   h = alphadlggui;
end;

if thisexit==0;
   waitfor(alpharest.done,'UserData','done');
end;

%
% end of alphadlg.m
%
