
function betar = boot_betarestrict(S_00,S_11,S_01,S_10,beta,T,modelsdir,modelfile,dcoint,mm)

%
% Check if available matrices for restrictions are available
%

check_nan = sum(isnan(vec(beta)));
if (isalmostequal(check_nan,0)==0)|(rank(beta)<size(beta,2));
   betar = mm.beta;
   return;
end;

check_nan = sum(isnan(vec(S_11)));
if (isalmostequal(check_nan,0)==0)|(rank(S_11)<size(S_11,2));
   betar = mm.beta;
   return;
end;

r = size(beta,2);
n = size(S_00,1);
nq1 = size(beta,1);
sivec = zeros(r,1);
q1 = nq1-n-dcoint;

i = 1;
while i<=r;
   file = strcat(modelsdir,'H_',num2str(i),'-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.rest');
   if fileexist(file)==1;
      h = loaddata(file);
      if i==1;
         H = h;
         bH = h;
      else;
         H = [H h];
         bH = [[bH zeros(size(bH,1),size(h,2))];[zeros(size(h,1),size(bH,2)) h]];
      end;
      sivec(i,1) = size(h,2);
   end;
   i = i+1;
end;

if sivec(r,1)==0;
   betar = 0;
else;
   %
   % Computing input values for beta
   %
   S_bb = beta'*beta;
   %
   % Solving the eigenvalue problem
   %
   % Step 1: Diagonalize S_bb
   %
   [W,rho] = eig(S_bb);
   rho = diag(rho,0);
   [rho2,AscInd] = sort(abs(rho));
   nr = size(AscInd,1);
   DescInd = zeros(nr,1);
   i1 = 1;
   while i1<=nr;
      DescInd(i1)=AscInd(nr+1-i1);
      i1 =i1+1;
   end;
   %
   % Resort eigenvalues and eigenvectors
   % in descending order
   %
   rho = rho(DescInd);
   sqrho = sqrt(rho);
   rho = diag(rho,0);
   sqrho = diag(sqrho,0);
   W = W(:,DescInd);
   sqS_bb = (W/(sqrho))*W';
   oldlambda = zeros(r,1);
   i=1;
   dfbeta = 0;
   while i<=r;
      %
      % Selecting the restrictions from H
      %
      si = sivec(i,1);
      dfbeta = dfbeta+(nq1-r-si+1);
      sj = size(H,2);
      if i==1;
         Hsel = [eye(si);zeros(sj-si,si)];
      elseif i==r;
         Hsel = [zeros(sj-si,si);eye(si)];
      else;
         sk = sivec(1,1);
         j=2;
         while j<=i-1;
            sk = sk+sivec(j,1);
            j = j+1;
         end;
         Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
      end;
      Hi = H*Hsel;
      %
      % Step 2: Reformulating eigenvalue problem to
      %         calculating the eigenvalues for
      %
      %         adjS_bb = sqS_bb*beta'*Hi*inverse(Hi'*Hi)*Hi'*beta*sqS_bb
      %
      adjS_bb = sqS_bb*beta'*(Hi/(Hi'*Hi))*Hi'*beta*sqS_bb;
      [U,lambdai] = eig(adjS_bb);
      lambdai = diag(lambdai,0);
      [lambdai2,AscInd] = sort(abs(lambdai));
      nr = size(AscInd,1);
      DescInd = zeros(nr,1);
      i1 = 1;
      while i1<=nr;
         DescInd(i1)=AscInd(nr+1-i1);
         i1 =i1+1;
      end;
      %
      % Resort eigenvalues and eigenvectors
      % in descending order
      %
      lambdai = lambdai(DescInd);
      U = U(:,DescInd);
      %
      % Renormalize U such that V'S_bbV=I
      %
      V = sqS_bb*U;
      %
      % Computing the initial estimate of betai
      % using the first eigenvector from the
      % solution to the above eigenvalue problem
      %
      betai = beta*V(:,1);
      oldlambda(i,1) = lambdai(1,1);
      %
      check_nan = sum(isnan(betai));
      check_imag = sum(imag(betai));
      if (isalmostequal(check_nan,0)==0)|(isalmostequal(check_imag,0)==0);
         betai = beta(:,i);
      end;
      %
      if i==1;
         betainit = betai;
      else;
         betainit = [betainit betai];
      end;
      i=i+1;
   end;
   for i=1:r;
      if oldlambda(i,1)==1;
         oldlambda(i,1) = 0;
      end;
   end;
   betainit = real(betainit);
   abort = '';
   if dfbeta>0;
      curr_ini = find_inisettings;
      if curr_ini.convcrit<10;
         ch_convcrit = ['1.0e-00' num2str(curr_ini.convcrit)];
      else;
         ch_convcrit = ['1.0e-0' num2str(curr_ini.convcrit)];
      end;
      ccrit = mystr2num(ch_convcrit);
      %
      % Starting up the iterations
      %
      grad = 1;
      %
      %
      %
      it = 1;
      while ((it<=curr_ini.maxit)&(grad>ccrit));
         i = 1;
         newlambda = zeros(r,1);
         while i<=r;
            %
            % Selecting the restrictions from H
            %
            si = sivec(i,1);
            sj = size(H,2);
            if i==1;
               Hsel = [eye(si);zeros(sj-si,si)];
               tau = betainit(:,2:r);
            elseif i==r;
               Hsel = [zeros(sj-si,si);eye(si)];
               tau = betainit(:,1:r-1);
            else;
               sk = sivec(1,1);
               j=2;
               while j<=i-1;
                  sk = sk+sivec(j,1);
                  j = j+1;
               end;
               Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
               tau = [betainit(:,1:i-1) betainit(:,i+1:r)];
            end;
            Hi = H*Hsel;
            %
            % Computing the S_ij_tau matrices
            %
            S_00_tau = S_00-(S_01*(tau/(tau'*S_11*tau))*tau'*S_10);
            S_11_tau = S_11-(S_11*(tau/(tau'*S_11*tau))*tau'*S_11);
            S_01_tau = S_01-(S_01*(tau/(tau'*S_11*tau))*tau'*S_11);
            S_10_tau = S_10-(S_11*(tau/(tau'*S_11*tau))*tau'*S_10);
            HS_11_tau = Hi'*S_11_tau*Hi;
            %
            % Solving the eigenvalue problem for fixed tau
            %
            % Step 1: Diagonalize HS_11_tau
            %
            [W,rho] = eig(HS_11_tau);
            rho = diag(rho,0);
            [rho2,AscInd] = sort(abs(rho));
            nr = size(AscInd,1);
            DescInd = zeros(nr,1);
            i1 = 1;
            while i1<=nr;
               DescInd(i1)=AscInd(nr+1-i1);
               i1 = i1+1;
            end;
            %
            % Resort eigenvalues and eigenvectors
            % in descending order
            %
            rho = rho(DescInd);
            sqrho = sqrt(rho);
            rho = diag(rho,0);
            sqrho = diag(sqrho,0);
            W = W(:,DescInd);
            %
            % Step 2: Reformulating eigenvalue problem to
            %         calculating the eigenvalues for
            %
            %         adjHS_11_tau =
            %        sqHS_11_tau*Hi'*S_10_tau*inverse(S_00_tau)*S_01_tau*Hi*sqHS_11_tau
            %
            sqHS_11_tau = (W/(sqrho))*W';
            adjHS_11_tau = sqHS_11_tau*Hi'*(S_10_tau/(S_00_tau))*S_01_tau*Hi*sqHS_11_tau;
            [U,lambdai] = eig(adjHS_11_tau);
            lambdai = diag(lambdai,0);
            [lambdai2,AscInd] = sort(abs(lambdai));
            nr = size(AscInd,1);
            DescInd = zeros(nr,1);
            i1 = 1;
            while i1<=nr;
               DescInd(i1)=AscInd(nr+1-i1);
               i1 = i1+1;
            end;
            %
            % Resort eigenvalues and eigenvectors
            % in descending order
            %
            lambdai = lambdai(DescInd);
            U = U(:,DescInd);
            %
            % Renormalize U such that V'HS_11_tauV=I
            %
            V = sqHS_11_tau*U;
            newlambda(i,1) = lambdai(1,1);
            newbetai = Hi*V(:,1);
            %
            % Changing betainit to include newbetai
            % for column i
            %
            check_nan = sum(isnan(newbetai));
            check_imag = sum(imag(newbetai));
            if (isalmostequal(check_nan,0)==0)|(isalmostequal(check_imag,0)==0);
               newbetai = beta(:,i);
            end;
            if i==1;
               betainit = [newbetai betainit(:,2:r)];
            elseif i==r;
               betainit = [betainit(:,1:r-1) newbetai];
            else;
               betainit = [betainit(:,1:i-1) newbetai betainit(:,i+1:r)];
            end;
            i = i+1;
         end;
         betainit = real(betainit);
         newlambda = real(newlambda);
         %
         % Calculate the convergence criterion using the
         % log-likelihood function
         %
         if curr_ini.betagrad==0;
            oldsum = sum(log(ones(r,1)-oldlambda));
            newsum = sum(log(ones(r,1)-newlambda));
            logdetS_00 = log(det(S_00));
            grad = abs(((newsum-oldsum)/(logdetS_00+oldsum)));
         else;
            %
            % computing the gradient vector
            %
            check_nan = sum(isnan(vec(betainit)));
            if (isalmostequal(check_nan,0)==1)&(rank((betainit'*S_11*betainit))==size(betainit,2));
               alphainit = (S_01*betainit)/(betainit'*S_11*betainit);
               Omegainit = S_00-(((S_01*betainit)/(betainit'*S_11*betainit))*betainit'*S_10);
            else;
               alphainit = (S_01*beta)/(beta'*S_11*beta);
               Omegainit = S_00-(((S_01*beta)/(beta'*S_11*beta))*beta'*S_10);
            end;
            inv_Omegainit = Omegainit\eye(n);
            grad = T*vec(alphainit)'*kron(eye(r),inv_Omegainit*(S_01-(alphainit*betainit'*S_11)))*bH;
            grad = max(abs(grad));
         end;
         oldlambda = newlambda;
         it=it+1;
      end;
   else;
   end;
   betar = betainit;
   file = strcat(modelsdir,'normalize-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.norm');
   if fileexist(file)==1;
      h = loaddata(file);
      %
      % Make sure that normalization works properly
      %
      % 1. check the length of h and fix if too short
      %
      if size(h,1)<r;
         hn = size(h,1)+1;
         for k=hn:r;
            si = sivec(k,1);
            sj = size(H,2);
            if k==1;
               Hsel = [eye(si);zeros(sj-si,si)];
            elseif k==r;
               Hsel = [zeros(sj-si,si);eye(si)];
            else;
               sk = sivec(1,1);
               for j=2:k-1;
                  sk = sk+sivec(j,1);
               end;
               Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
            end;
            Hi = H*Hsel;
            for g=1:size(Hi,1);
               if abs(Hi(g,1))>1.0e-006;
                  h = [h;g];
                  g = size(Hi,1)+1;
               end;
            end;
         end;
      end;
      %
      % 2. check all coefficients to make sure they are valid
      %
      h = h(1:r,1);
      for k=1:r;
         si = sivec(k,1);
         sj = size(H,2);
         if k==1;
            Hsel = [eye(si);zeros(sj-si,si)];
         elseif k==r;
            Hsel = [zeros(sj-si,si);eye(si)];
         else;
            sk = sivec(1,1);
            for j=2:k-1;
               sk = sk+sivec(j,1);
            end;
            Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
         end;
         Hi = H*Hsel;
         mynorm = h(k,1);
         if max(abs(Hi(mynorm,:)))<1.0e-006;
            for l=1:r;
               if abs(Hi(l,1))>1.0e-006;
                  h(k,1) = l;
                  l = r+1;
               end;
            end;
         end;
      end;
      %
      % we are now ready to normalize betar
      %
      i = 1;
      while i<=r;
         normcoeffi = h(i,1);
         normbetai = betar(normcoeffi,i);
         if abs(normbetai)<1.0e-006;
            normbetai = 1;
         end;
         j=1;
         while j<=nq1;
            betar(j,i) = betar(j,i)/normbetai;
            j = j+1;
         end;
         i = i+1;
      end;
   end;
end;

%
% end of boot_betarestrict.m
%
