function [x1out,deterout,deterdel] = checkdeter(x1,x1_r,deter)

%
% Makes sure that deterministic variables are not linearly dependent.
% If they are, this function removes all those variables and adjusts
% the name string accordingly for them.
%
% NOTE: if x1 = [1;2;3;4;5] and x1_r = [0;1;2;3;4], then this function
%       treats them as linearly dependent since x1 = 1+x1_r, i.e. x1 is
%       an affine function of x1_r. In a time series model, both x1 and
%       x1_r represent a linear trend and only one of them may be
%       included.
%

if nargin<3;
   deter = '';
end;

deterout0 = '';
deterdel0 = '';

if nargin==1;
   x1_r = [];
end;

if (size(x1,1)==size(x1_r,1))|(isempty(x1_r)==1);
   x = [x1_r x1];
else;
   if size(x1,2)==size(x1_r,2);
      x = [x1_r' x1'];
   else;
      [T1 n1] = size(x1);
      [T2 n2] = size(x1_r);
      if n1>T1;
         x1 = x1';
         [T1 n1] = size(x1);
      end;
      if n2>T2;
         x1_r = x1_r';
         [T2 n2] = size(x1_r);
      end;
      if T1>T2;
         x = [x1_r x1(1:T2,:)];
      else;
         x = [x1_r(1:T1,:) x1];
      end;
   end;
end;

[T d1] = size(x);
if d1>T;
   x = x';
   [T d1] = size(x);
end;

[deletevars,keepvars] = getdelvars(x1,x1_r);
if isempty(x1_r)==1;
   x1out = x(:,keepvars');
else;
   x1out = x(:,2:d1);
   x1out = x1out(:,keepvars');
end;
if strcmp(deter,'')==0;
   if isempty(deletevars)==0;
      detervec = vecstr(deter);
      for i=1:size(keepvars,1);
         if i==1;
            deterout0 = strrep(detervec(keepvars(1,1),:),' ','');
         else;
            deterout0 = [deterout0 ' ' strrep(detervec(keepvars(i,1),:),' ','')];
         end;
      end;
      for i=1:size(deletevars,1);
         if i==1;
            deterdel0 = strrep(detervec(deletevars(1,1),:),' ','');
         else;
            deterdel0 = [deterdel0 ' ' strrep(detervec(deletevars(i,1),:),' ','')];
         end;
      end;
   else;
      deterout0 = deter;
   end;
end;

if isempty(x1out)==1;
   x1out = [];
end;

if nargout>=2;
   deterout = deterout0;
   if nargout==3;
      deterdel = deterdel0;
   end;
end;

%
% end of checkdeter.m
%