function [pos,bplot,x_n,y_n,n1] = dist2d_plot(pos,fig_tag,fig_name,p_title,x_label,y_label,tm,curr_ini,my_structure,as_mat_fixed,x_lim,y_lim,fix_ax_pos,numcells)

cdf_value = get(my_structure.cdf,'Value');

bplot = figure('Units','pixels', ...
   'Position',[pos 600 400], ...
   'NumberTitle','off', ...
   'Menubar','none', ...
   'Toolbar','none', ...
   'Tag',fig_tag, ...
   'Visible','off', ...
   'Name',fig_name);
%
pos = [pos(1)+22 pos(2)-22];
if pos(1,1)>(tm.realscrsz(3)-600);
   pos = [0 tm.realscrsz(4)-470];
end;
if pos(1,2)>(tm.realscrsz(4)-470);
   pos = [0 tm.realscrsz(4)-470];
elseif pos(1,2)<32;
   pos = [0 tm.realscrsz(4)-470];
end;
%
% obey centering and filling defaults
%
setfigureproperties(bplot);
%
%
if (strcmp(tm.interpolate,'nearest')==1)|(strcmp(tm.interpolate,'linear')==1)|(strcmp(tm.interpolate,'spline')==1)|(strcmp(tm.interpolate,'cubic')==1);
   numx = ceil(numcells/2);
   x_e = linspace(x_lim(1,1),x_lim(1,2),numx+1);
   y_e = linspace(y_lim(1,1),y_lim(1,2),numx+1);
   %
   % count occurencies in each bin and form into numx x numx matrix
   %
   n1 = hist2d(as_mat_fixed,y_e,x_e);
   n1 = (1/(sum(sum(n1))))*n1;
   %
   % interpolate
   %
   % 1. find midpoint in x_e and y_e
   x_a = [];
   for i1=1:numx;
      x_a = [x_a;(x_e(1,i1)+x_e(1,i1+1))/2];
   end;
   x_a = ones(numx,1)*x_a';
   y_a = [];
   for i1=1:numx;
      y_a = [y_a;(y_e(1,i1)+y_e(1,i1+1))/2];
   end;
   y_a = y_a*ones(1,numx);
   %
   % 2. create new x and y grids
   %
   x_n = ones(100,1)*linspace(x_e(1,1),x_e(1,numx+1),100);
   y_n = linspace(y_e(1,1),y_e(1,numx+1),100)'*ones(1,100);
   %
   % 3. apply interpolation function
   %
   n1 = interp2(x_a,y_a,n1,x_n,y_n,tm.interpolate);
   %
   % replace any NaN's with 0
   %
   if sum(sum(isnan(n1)))>0;
      [r1 r2] = size(n1);
      for i=1:r1;
         for j=1:r2;
            if isnan(n1(i,j))==1;
               n1(i,j) = 0;
            end;
         end;
      end;
   end;
   %
   if cdf_value==1;
      n1 = cdf2d([x_n(1,1) y_n(1,1);x_n(1,2) y_n(2,1)],n1);
   else;
      n1 = (1/max(max(cumsum(cumsum((x_n(1,2)-x_n(1,1))*(y_n(2,1)-y_n(1,1))*n1)')')))*n1;
   end;
   this_surf = surf(x_n',y_n',n1','EdgeColor','none','LineWidth',1,'FaceLighting','gouraud','SpecularStrength',0.5);
   %
   % fixing values
   %
   n1 = n1';
   x_n = linspace(x_e(1,1),x_e(1,numx+1),100);
   y_n = linspace(y_e(1,1),y_e(1,numx+1),100);
else;
   %
   % we're dealing with kernel density stuff
   %
   if strcmp(tm.interpolate,'knorm')==1;
      h = 0;
   else;
      h = [hns(as_mat_fixed(:,2),tm.interpolate) hns(as_mat_fixed(:,1),tm.interpolate)];
   end;
   if get(my_structure.adaptive,'Value')==1;
      [x_n,y_n,n1,h,hl] = kdadapt([as_mat_fixed(:,2) as_mat_fixed(:,1)],tm.interpolate,128,h);
   else;
      [x_n,y_n,n1] = kdfft2([as_mat_fixed(:,2) as_mat_fixed(:,1)],tm.interpolate,256,h,0);
   end;
   if cdf_value==1;
      n1 = cdf2d([x_n' y_n'],n1);
   end;
   this_surf = surf(x_n,y_n,n1,'EdgeColor','none','LineWidth',1,'FaceLighting','gouraud','SpecularStrength',0.5);
end;
this_axes = gca;
this_zlim = get(this_axes,'Zlim');
if curr_ini.colors==1;
   colormap(jet);
   set(this_surf,'UserData','jet');
   gray_check = 'off';
   jet_check = 'on';
else;
   colormap(gray);
   set(this_surf,'UserData','gray');
   gray_check = 'on';
   jet_check = 'off';
end;
hold('on');
set(this_axes,'XLim',[min(x_n) max(x_n)]);
set(this_axes,'YLim',[min(y_n) max(y_n)]);
set(this_axes,'ZLim',[0 this_zlim(1,2)]);
if cdf_value==1;
   set(bplot,'Tag',strrep(get(bplot,'Tag'),'density-','cdf-'));
   set(bplot,'Name',strrep(get(bplot,'Name'),'density','distribution'));
   setaxesfonts('Title',strrep(p_title,'density','distribution'),'Xlabel',x_label,'YLabel',y_label,'ZLabel','Frequency');
else;
   setaxesfonts('Title',p_title,'Xlabel',x_label,'YLabel',y_label,'ZLabel','Density');
end;
%
% Add a light object
%
this_light = light('Position',[min(min(x_n)) min(min(y_n)) max(max(n1))],'Style','infinite');
%
% fix axes position
%
%if fix_ax_pos==1;
%   old_ax_units = get(this_axes,'Units');
%   set(this_axes,'Units','pixels');
%   ax_pos = get(this_axes,'Position');
%   set(this_axes,'Position',ax_pos-[0 0 0 10]);
%   set(this_axes,'Units',old_ax_units);
%end;
%
set(this_light,'UserData',this_surf);
toolbar_fcn(this_axes);
hold('off');

%
% end of dist2d_plot.m
%
