%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting values for certain    %
%          otpions used when preparing graphs of distributions   %
%          for the parameters in the Bayesian analysis           %
%                                                                %
%          Function: graphoptions_dlg                            %
%                                                                %
%          Input:                                                %
%                       selector: case value string              %
%                       curr_ini: var.ini settings               %
%                                                                %
%          Output:                                               %
%          	            h: handle to figure                      %
%                                                                %
%          This version:        March 16, 2006                   %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = graphoptions_dlg(selector,curr_ini)

if strcmp(selector,'init')==1;
   tm.ini = curr_ini;
   tm.interpolate = curr_ini.interpolate;
   tm.interpolate_value = curr_ini.interpolate_value;
   tm.cumdist = curr_ini.cumdist;
   tm.adaptivekde = curr_ini.adaptivekde;
   tm.numcells = curr_ini.numcells;
   tm.numcells_control = curr_ini.numcells_control;
   %   
   tm.old.interpolate = curr_ini.interpolate;
   tm.old.interpolate_value = curr_ini.interpolate_value;
   tm.old.cumdist = curr_ini.cumdist;
   tm.old.adaptivekde = curr_ini.adaptivekde;
   tm.old.numcells = curr_ini.numcells;
   tm.old.numcells_control = curr_ini.numcells_control;
   %
   tm.realscrsz = get(0,'ScreenSize');
   width = 500;
   height = 330;
else;
   graphoptions_gui = findobj('Type','figure','Tag','GraphOptionsDlg');
   graphoptions_controls = get(graphoptions_gui,'UserData');
   tm = get(graphoptions_controls.apply,'UserData');
   curr_ini = tm.ini;
end;

switch selector;
   case 'init';
      graphoptions_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','graphoptions_dlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-width)/2 (tm.realscrsz(4)-height)/2 width height], ...
         'Tag','GraphOptionsDlg', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Graphics Options', ...
         'NumberTitle','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','graphoptions_dlg done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(graphoptions_gui,'DockControl','off');
      end;

      axesbox([2 2 width-2 height-10],'Options',38,[0.5 1]);

      %
      % GUI Header
      %

      mycons = getstoredimages;
      header_txt = 'Options for Graphs of Parameter Distributions';
      desc_txt = 'You can change the default values for certain parameters that determine how Structural VAR creates graphs of parameter distributions. Press the "Apply" button to save your changes, the "Cancel" button to reset the values, and the "OK" button to finish.';
      graphoptions_controls.icon = dialog_header_fcn([16 height-109 width-30 85],mirrorimage(maketrans(mycons.figeditor_image,[160 160 164],[1 1 1])),header_txt,desc_txt);
      graphoptions_controls.icon = graphoptions_controls.icon(1,1);
      
      axesbox([16 55 width-30 height-180],'Graphics',43,[0.5 1]);
      
      %
      % create the header text and popup controls
      %
      
      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-170 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','Interpolation function:', ...
         'Tag','InterpolationText');

      graphoptions_controls.interpolate = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-230 height-165 200 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Visible','on', ...
         'Value',tm.interpolate_value, ...
         'Callback','graphoptions_dlg interpolate', ...
         'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
         'Tag','InterpolationPopup');

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-200 165 20], ...
         'Style','text', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'HorizontalAlignment','left', ...
         'String','Number of cells for histograms:', ...
         'Tag','NumcellsText');

      graphoptions_controls.cells = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-230 height-195 200 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Visible','on', ...
         'Value',tm.numcells_control, ...
         'Callback','graphoptions_dlg numcells', ...
         'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
         'Tag','NumCellsPopup');

      graphoptions_controls.cumdist = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-230 300 20], ...
         'Style','checkbox', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',tm.cumdist, ...
         'Callback','graphoptions_dlg cumdist', ...
         'HorizontalAlignment','left', ...
         'String','Cumulative distribution', ...
         'Tag','CumDistCheck');


      graphoptions_controls.adaptivekde = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 height-260 300 20], ...
         'Style','checkbox', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',tm.adaptivekde, ...
         'Enable','off', ...
         'Callback','graphoptions_dlg adaptivekde', ...
         'HorizontalAlignment','left', ...
         'String','Adaptive Kernel Density Estimation method', ...
         'Tag','AdaptiveKDECheck');

      if tm.interpolate_value>=5;
         set(graphoptions_controls.adaptivekde,'Enable','on');
      end;

      %
      % Buttons
      %

      graphoptions_controls.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-295 20 90 20], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','graphoptions_dlg done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      graphoptions_controls.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-200 20 90 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','graphoptions_dlg cancel', ...
         'Enable','on', ...
         'Tag','Cancel');

      graphoptions_controls.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-105 20 90 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','graphoptions_dlg apply', ...
         'UserData',tm, ...
         'Enable','off', ...
         'Tag','Apply');

      set(graphoptions_gui,'UserData',graphoptions_controls,...
         'HandleVisibility','callback');

   case 'interpolate'
      i_val = get(graphoptions_controls.interpolate,'Value');
      if abs(i_val-tm.interpolate_value)>0;
         tm.interpolate_value = i_val;
         interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
         tm.interpolate = strtrim(interpol_vec(i_val,:));
         if tm.interpolate_value<5;
            tm.adaptivekde = 0;
            set(graphoptions_controls.adaptivekde,'Enable','off','Value',tm.adaptivekde);
         end;
         set(graphoptions_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'numcells'
      c_val = get(graphoptions_controls.cells,'Value');
      c_str = get(graphoptions_controls.cells,'String');
      newnumcells = mystr2num(strtrim(c_str(c_val,:)));
      if abs(newnumcells-tm.numcells)>0;
         tm.numcells = newnumcells;
         tm.numcells_control = c_val;
         set(graphoptions_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'cumdist'
      newcumdist = get(graphoptions_controls.cumdist,'Value');
      if abs(newcumdist-tm.cumdist)>0;
         tm.cumdist = newcumdist;
         set(graphoptions_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'adaptivekde'
      newadaptivekde = get(graphoptions_controls.adaptivekde,'Value');
      if abs(newadaptivekde-tm.adaptivekde)>0;
         tm.adaptivekde = newadaptivekde;
         set(graphoptions_controls.apply,'Enable','on','UserData',tm);
      end;
   case 'cancel'
      tm.interpolate = tm.old.interpolate;
      tm.interpolate_value = tm.old.interpolate_value;
      tm.cumdist = tm.old.cumdist;
      tm.adaptivekde = tm.old.adaptivekde;
      tm.numcells = tm.old.numcells;
      tm.numcells_control = tm.old.numcells_control;
      curr_ini.interpolate = tm.interpolate;
      curr_ini.interpolate_value = tm.interpolate_value;
      curr_ini.cumdist = tm.cumdist;
      curr_ini.adaptivekde = tm.adaptivekde;
      curr_ini.numcells = tm.numcells;
      curr_ini.numcells_control = tm.numcells_control;
      tm.ini = curr_ini;
      set(graphoptions_controls.apply,'Enable','off','UserData',tm);
      %
      % Now we fix the controls
      %
      set(graphoptions_controls.interpolate,'Value',tm.interpolate_value);
      set(graphoptions_controls.cells,'Value',tm.numcells_control);
      set(graphoptions_controls.cumdist,'Value',tm.cumdist);
      set(graphoptions_controls.adaptivekde,'Value',tm.adaptivekde,'Enable','off');
      if tm.interpolate_value>=5;
         set(graphoptions_controls.adaptivekde,'Enable','on');
      end;
   case 'apply'
      curr_ini.interpolate = tm.interpolate;
      curr_ini.interpolate_value = tm.interpolate_value;
      curr_ini.cumdist = tm.cumdist;
      curr_ini.adaptivekde = tm.adaptivekde;
      curr_ini.numcells = tm.numcells;
      curr_ini.numcells_control = tm.numcells_control;
      tm.ini = curr_ini;
      set(graphoptions_controls.apply,'Enable','off','UserData',tm);
   case 'done'
      set(graphoptions_controls.done,'UserData','done');
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(graphoptions_gui,'Name') ' ' fix_filepath([pwd '\icons\preferences.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(graphoptions_controls.icon,'UserData',pid);
      end;
   end;
   %
   set(graphoptions_gui,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(graphoptions_gui,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(graphoptions_controls.done);
   end;
   waitfor(graphoptions_controls.done,'UserData','done');
end;

if nargout==1;
   h = graphoptions_gui;
end;

%
% end of graphoptions_dlg.m
%
