%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          Computes information criteria                         %
%                                                                %
%          Function: infocrit                                    %
%                                                                %
%          Input:                                                %
%                       epsilon: nxT matrix with residuals       %
%                       df: number of free parameters per        %
%                           equation                             %
%                                                                %
%          Output:                                               %
%          	            aic: Akaike Information criterion        %
%                       fpe: Akaike Final Prediction Error       %
%                           Criterion (natural logarithm)        %
%                       hq: Hannan-Quinn Criterion               %
%                       sc: Schwarz Criterion                    %
%                                                                %
%          This version:        October 6, 2004                  %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [aic,fpe,hq,sc] = infocrit(epsilon,df)

[n T] = size(epsilon);
Omega = (1/T)*epsilon*epsilon';

%
% Compute AIC
%

aic = log(det(Omega))+((2/T)*n*df);

%
% Compute FPE
%

fpe = ((T+df)/(T-df))*Omega;
fpe = log(det(fpe));

%
% Compute HQ
%

hq = log(det(Omega))+(((2*log(log(T)))/T)*n*df);

%
% Compute SC
%

sc = log(det(Omega))+((log(T)/T)*n*df);

%
% end of infocrit.m
%
