function [out,ts_type] = istimeseries(this_axes)

%
% checks if there is any yearly, quarterly or monthly time series data in the axes object
% optionally returns the type
%

if nargin==0;
   this_axes = gca;
end;

out = 0;

%
% looking for lines
%
linehandles = findobj(gca,'Type','line')';
if isempty(linehandles)==0;
   %
   % Remove zero lines from linehandles
   %
   fixhandles = [];
   for j=1:size(linehandles,2);
      checkvec = get(linehandles(1,j),'YData');
      checkvec2 = sum(get(linehandles(1,j),'XData'));
      checkstyle = get(linehandles(1,j),'LineStyle');
      %
      % need to remove those with nolegend-, varline-, 2dlines-, 3dlines- tags
      %
      checktag = get(linehandles(1,j),'Tag');
      if size(checktag,2)>8;
         checktag = checktag(1,1:8);
      end;
      if (isalmostequal(checkvec,get(linehandles(1,j),'XData'))==1)|(((checkvec==zeros(size(checkvec,1),1))|(checkvec2==zeros(size(checkvec2,1),1)))&((strcmp(checkstyle,'none')==0)|(isempty(get(linehandles(1,j),'UserData'))==0))|(strcmp(get(linehandles(1,j),'Tag'),'light')==1))|(strcmp(checktag,'varline-')==1)|(strcmp(checktag,'nolegend')==1)|(strcmp(checktag,'2dlines-')==1)|(strcmp(checktag,'3dlines-')==1)|(min(checkvec)==max(checkvec));
         fixhandles = [fixhandles 0];
      else;
         fixhandles = [fixhandles 1];
      end;
   end;
   linehandles = linehandles(fixhandles==1);
end;

if (size(linehandles,1)==0)|(size(linehandles,2)==0);
   linehandles = [];
end;

%
% Looking for patches
%

patchhandles = findobj(gca,'Type','patch')';
if isempty(patchhandles)==0;
   %
   % remove rectangles and confidence intervals
   %
   fixhandles = [];
   for i=1:size(patchhandles,2);
      if (strcmp(get(patchhandles(1,i),'Tag'),'confpatch')==1)|(strcmp(get(patchhandles(1,i),'Tag'),'confpatch-new')==1)|(strcmp(lower(get(patchhandles(1,i),'Tag')),'rectpatch')==1)|(strcmp(lower(get(patchhandles(1,i),'Tag')),'rectpatch-new')==1)|(strcmp(get(patchhandles(1,i),'Tag'),'distpatch')==1)|(strcmp(get(patchhandles(1,i),'Tag'),'distpatch-new')==1)|(strcmp(get(patchhandles(1,i),'Tag'),'autopatch')==1)|(strcmp(get(patchhandles(1,i),'Tag'),'autopatch-new')==1);
         fixhandles = [fixhandles 0];
      else;
         fixhandles = [fixhandles 1];
      end;
   end;
   patchhandles = patchhandles(fixhandles==1);
end;

if (size(patchhandles,1)==0)|(size(patchhandles,2)==0);
   patchhandles = [];
end;

%
% now check the data for the lines and the patches
%

if isempty(linehandles)==0;
   for i=1:size(linehandles,2);
      x_data = get(linehandles(1,i),'XData');
      %
      % Try to figure out frequency and if we have an interesting line
      %
      if size(x_data,1)>1;
         x_data = x_data';
      end;
      l_freq = '';
      if size(x_data,2)>1;
         ch_freq = x_data(1,2)-x_data(1,1);
         if isalmostequal(ch_freq,1)==1;
            l_freq = 'y';
         elseif isalmostequal(ch_freq,1/4)==1;
            l_freq = 'q';
         elseif isalmostequal(ch_freq,1/12)==1;
            l_freq = 'm';
         end;
         if strcmp(l_freq,'')==0;
            out = 1;
            if nargout==2;
               ts_type = l_freq;
            end;
            return;
         end;
      end;
   end;
end;

if isempty(patchhandles)==0;
   for i=1:size(patchhandles,2);
      x_data = get(patchhandles(1,i),'XData');
      if size(x_data,1)>4;
         x_data = x_data';
      end;
      if size(x_data,1)==4;
         l_freq = '';
         %
         % checking the frequency for bars
         %
         x_data = (1/2)*(x_data(2,:)+x_data(3,:));
         if size(x_data,2)>1;
            ch_freq = x_data(1,2)-x_data(1,1);
            if isalmostequal(ch_freq,1)==1;
               l_freq = 'y';
            elseif isalmostequal(ch_freq,1/4)==1;
               l_freq = 'q';
            elseif isalmostequal(ch_freq,1/12)==1;
               l_freq = 'm';
            end;
            if strcmp(l_freq,'')==0;
               out = 1;
               if nargout==2;
                  ts_type = l_freq;
               end;
               return;
            end;
         end;
      end;
   end;
end;

if nargout==2;
   ts_type = 'none';
end;

%
% end of istimeseries.m
%
