function moveaxis_fcn(arg)
%MOVEAXIS_FCN Used to grab and move axis.
%   To use, click and hold down a mouse button while
%   the cursor is near the lower left corner of the
%   axis you want to move. Wait for the cursor to change
%   to a fleur (4 way arrows), then drag the legend or axis
%   to the desired location and release the mouse button.
%
%   To enable, set the figure window's WINDOWBUTTONDOWNFCN
%   property to 'moveaxis'. For example,
%
%            set(gcf,'WindowButtonDownFcn','moveaxis')

%   10/5/93  D.Thomas
%   Copyright (c) 1984-98 by The MathWorks, Inc.
%   $Revision: 5.10 $  $Date: 1998/05/12 22:40:34 $

this_fig = findobj('Type','figure','Tag','StructuralVAR');
model = get(this_fig,'UserData');

if nargin==0,
    fig = gcf;
    st=get(fig,'SelectionType');
    if (strcmp(st,'normal'))
        moveaxis_fcn(1);
    elseif strcmp(st,'open'),
        if strcmp(get(gco,'Type'),'text') & ...
             strcmp(get(get(gco,'parent'),'tag'),'legend')
            legend_fcn('EditLegend',gco)
        end
    end
elseif arg==1,
    fig = gcf;
    ax_prop.figuts = get(fig,'units');
    if strcmp(ax_prop.figuts,'normalized'),
        pnt = get(fig,'currentpoint');
        set(fig,'units','pixels');  
        pos = get(fig,'position');
        pnt = [pnt(1) * pos(3) pnt(2) * pos(4)];
    else,
        set(fig,'units','pixels');
        pnt=get(fig,'currentpoint');
    end
    Kids = gca;
    [n,tmp]=size(Kids);
    mn=1e20;
    mi=1;
    for i=1:n,
        if strcmp(get(Kids(i),'type'),'axes');
            units=get(Kids(i),'units');
            set(Kids(i),'units','pixels')
            cap=get(Kids(i),'position');
            if sum((pnt-cap(1:2)).^2)<mn,
                mn=sum((pnt-cap(1:2)).^2);
                mi=i;
                ax_prop.delta=cap(1:2)-pnt;
            end
            set(Kids(i),'units',units);
        end
    end
    ud = get(Kids(mi),'userdata');
    ax_prop.oldca=gca;  
    set(fig,'currentobject',Kids(mi));          
    ax_prop.hl=[Kids(mi) abs(get(Kids(mi),'units'))];
    set(Kids(mi),'units','pixels');
    cp_fig = get(fig,'CurrentPoint');
    oldgca_units = get(gca,'Units');
    set(gca,'Units','pixels');
    pos = get(gca,'Position');
    set(gca,'Units',oldgca_units);
    y_lim = [pos(2) pos(4)+pos(2)];
    x_lim = [pos(1) pos(3)+pos(1)];
    fig_name = get(fig,'Name');
    if size(fig_name,2)>=10;
       fig_name = fig_name(1,1:10);
    end;
    if strcmp(fig_name,'Page Setup')==1;
       d_x = 10;
       d_y = 10;
    else;
       d_x = 5;
       d_y = 5;
    end;
    %
    % top-left
    %
    if ((cp_fig(1,1)<=x_lim(1,1)+d_x)&(cp_fig(1,1)>=x_lim(1,1)-d_x))&((cp_fig(1,2)<=y_lim(1,2)+d_y)&(cp_fig(1,2)>=y_lim(1,2)-d_y));
       set(fig,'pointer','topl');
    %
    % top-right
    %
    elseif ((cp_fig(1,2)<=y_lim(1,2)+d_y)&(cp_fig(1,2)>=y_lim(1,2)-d_y))&((cp_fig(1,1)<=x_lim(1,2)+d_x)&(cp_fig(1,1)>=x_lim(1,2)-d_x));
       set(fig,'pointer','topr')
    %
    % bottom-left
    %
    elseif ((cp_fig(1,2)<=y_lim(1,1)+d_y)&(cp_fig(1,2)>=y_lim(1,1)-d_y))&((cp_fig(1,1)<=x_lim(1,1)+d_x)&(cp_fig(1,1)>=x_lim(1,1)-d_x));
       set(fig,'pointer','botl');
    %
    % bottom-right
    %
    elseif ((cp_fig(1,2)<=y_lim(1,1)+d_y)&(cp_fig(1,2)>=y_lim(1,1)-d_y))&((cp_fig(1,1)<=x_lim(1,2)+d_x)&(cp_fig(1,1)>=x_lim(1,2)-d_x));
       set(fig,'pointer','botr');
    %
    % left
    %
    elseif (cp_fig(1,1)<=x_lim(1,1)+d_x)&(cp_fig(1,1)>=x_lim(1,1)-d_x);
       set(fig,'pointer','left');
    %
    % right
    %
    elseif (cp_fig(1,1)<=x_lim(1,2)+d_x)&(cp_fig(1,1)>=x_lim(1,2)-d_x);
       set(fig,'pointer','right');
    %
    % bottom
    %
    elseif (cp_fig(1,2)<=y_lim(1,1)+d_y)&(cp_fig(1,2)>=y_lim(1,1)-d_y);
       set(fig,'pointer','bottom');
    %
    % top
    %
    elseif (cp_fig(1,2)<=y_lim(1,2)+d_y)&(cp_fig(1,2)>=y_lim(1,2)-d_y);
       set(fig,'pointer','top');
    %
    % inside
    %
    else;
       set(fig,'pointer','fleur');
    end;
    set(fig,'windowbuttonmotionfcn','moveaxis_fcn(2)','windowbuttonupfcn','moveaxis_fcn(3)');
    set(model.filemenu,'UserData',ax_prop);
elseif arg==2,
    ax_prop = get(model.filemenu,'UserData');
    fig = gcf;
    oldu = get(gca,'Units');
    set(gca,'Units','pixels');
    pos=get(gca,'Position');
    fig_cp = get(fig,'currentpoint');
    if (pos(3)>10)&(pos(4)>10);
       if strcmp(get(fig,'pointer'),'left')==1;
          if pos(3)+(pos(1)-fig_cp(1,1))>10;
             set(gca,'units','pixels','drawmode','fast',...
                'position',[fig_cp(1,1) pos(2) pos(3)+(pos(1)-fig_cp(1,1)) pos(4)]);
          end;
       elseif strcmp(get(fig,'pointer'),'right')==1;
          if fig_cp(1,1)-pos(1)>10;
             set(gca,'units','pixels','drawmode','fast',...
                'position',[pos(1) pos(2) fig_cp(1,1)-pos(1) pos(4)]);
          end;
       elseif strcmp(get(fig,'pointer'),'top')==1;
          if fig_cp(1,2)-pos(2)>10;
             set(gca,'units','pixels','drawmode','fast',...
                'position',[pos(1) pos(2) pos(3) fig_cp(1,2)-pos(2)]);
          end;
       elseif strcmp(get(fig,'pointer'),'bottom')==1;
          if pos(4)+(pos(2)-fig_cp(1,2))>10;
             set(gca,'units','pixels','drawmode','fast',...
                'position',[pos(1) fig_cp(1,2) pos(3) pos(4)+(pos(2)-fig_cp(1,2))]);
          end;
       elseif strcmp(get(fig,'pointer'),'topl')==1;
          if (pos(3)+(pos(1)-fig_cp(1,1))>10)&(fig_cp(1,2)-pos(2)>10);
             set(gca,'units','pixels','drawmode','fast',...
                'position',[fig_cp(1,1) pos(2) pos(3)+(pos(1)-fig_cp(1,1)) fig_cp(1,2)-pos(2)]);
          end;
       elseif strcmp(get(fig,'pointer'),'topr')==1;
          if (fig_cp(1,1)-pos(1)>10)&(fig_cp(1,2)-pos(2)>10);
             set(gca,'units','pixels','drawmode','fast',...
                'position',[pos(1) pos(2) fig_cp(1,1)-pos(1) fig_cp(1,2)-pos(2)]);
          end;
       elseif strcmp(get(fig,'pointer'),'botl')==1;
          if (pos(3)+(pos(1)-fig_cp(1,1))>10)&(pos(4)+(pos(2)-fig_cp(1,2))>10);
             set(gca,'units','pixels','drawmode','fast',...
                'position',[fig_cp(1,1) fig_cp(1,2) pos(3)+(pos(1)-fig_cp(1,1)) pos(4)+(pos(2)-fig_cp(1,2))]);
          end;
       elseif strcmp(get(fig,'pointer'),'botr')==1;
          if (fig_cp(1,1)-pos(1)>10)&(pos(4)+(pos(2)-fig_cp(1,2))>10);
             set(gca,'units','pixels','drawmode','fast',...
                'position',[pos(1) fig_cp(1,2) fig_cp(1,1)-pos(1) pos(4)+(pos(2)-fig_cp(1,2))]);
          end;
       else;
          set(gca,'units','pixels','drawmode','fast',...
             'position',[fig_cp+ax_prop.delta pos(3:4)]);
       end;
    end;
    set(gca,'Units',oldu);
    set(model.filemenu,'UserData',ax_prop);
elseif arg==3,
    ax_prop = get(model.filemenu,'UserData');
    fig = gcf;
    set(fig,'WindowButtonMotionfcn','', ...
        'pointer','arrow','currentaxes',ax_prop.oldca, ...
        'windowbuttonupfcn','');
    set(gca,'DrawMode','normal');
    set(ax_prop.hl(1),'units',setstr(ax_prop.hl(2:length(ax_prop.hl))));
    set(fig,'units',ax_prop.figuts);
    if strcmp(get(gca,'tag'),'legend')
      legend_fcn('ShowLegendPlot')
    end
    set(model.filemenu,'UserData',[]);
end

%
% end of moveaxis_fcn.m
%

