function moveaxis_var(arg)
%MOVEAXIS_VAR Used to grab and move legend axis.
%   To use, click and hold down a mouse button while
%   the cursor is near the lower left corner of the
%   axis you want to move. Wait for the cursor to change
%   to a fleur (4 way arrows), then drag the legend or axis
%   to the desired location and release the mouse button.
%
%   To enable, set the figure window's WINDOWBUTTONDOWNFCN
%   property to 'moveaxis_var'. For example,
%
%            set(gcf,'WindowButtonDownFcn','moveaxis_var')

%   10/5/93  D.Thomas
%   Copyright (c) 1984-98 by The MathWorks, Inc.
%   $Revision: 5.10 $  $Date: 1998/05/12 22:40:34 $

this_fig = findobj('Type','figure','Tag','StructuralVAR');
model = get(this_fig,'UserData');

if nargin==0,
    fig = gcf;
    st=get(fig,'SelectionType');
    if (strcmp(st,'normal'))
        moveaxis_var(1);
    elseif strcmp(st,'open'),
        if strcmp(get(gco,'Type'),'text') & ...
             strcmp(get(get(gco,'parent'),'tag'),'legend')
            legend_fcn('EditLegend',gco)
        end
    end
elseif arg==1,
    fig = gcf;
    ax_prop.figuts = get(fig,'units');
    set(fig,'pointer','fleur');
    if strcmp(ax_prop.figuts,'normalized'),
        pnt = get(fig,'currentpoint');
        set(fig,'units','pixels');  
        pos = get(fig,'position');
        pnt = [pnt(1) * pos(3) pnt(2) * pos(4)];
    else,
        set(fig,'units','pixels');
        pnt=get(fig,'currentpoint');
    end
    Kids=get(fig,'children');
    [n,tmp]=size(Kids);
    mn=1e20;
    mi=1;
    for i=1:n,
        if strcmp(get(Kids(i),'type'),'axes') & ...
           strcmp(get(Kids(i),'tag'),'legend')
            units=get(Kids(i),'units');
            set(Kids(i),'units','pixels')
            cap=get(Kids(i),'position');
            if sum((pnt-cap(1:2)).^2)<mn,
                mn=sum((pnt-cap(1:2)).^2);
                mi=i;
                ax_prop.delta=cap(1:2)-pnt;
            end
            set(Kids(i),'units',units);
        end
    end
    ud = get(Kids(mi),'userdata');
    ax_prop.oldca=gca;  
    set(fig,'currentobject',Kids(mi));          
    ax_prop.hl=[Kids(mi) abs(get(Kids(mi),'units'))];
    set(Kids(mi),'units','pixels');
    set(fig,'windowbuttonmotionfcn','moveaxis_var(2)','windowbuttonupfcn','moveaxis_var(3)');
    set(model.filemenu,'UserData',ax_prop);
elseif arg==2,
    ax_prop = get(model.filemenu,'UserData');
    fig = gcf;
    pos=get(get(fig,'currentobject'),'position');
    set(get(fig,'currentobject'),'units','pixels','drawmode','fast',...
    'position',[get(fig,'currentpoint')+ax_prop.delta pos(3:4)]);
    set(model.filemenu,'UserData',ax_prop);
elseif arg==3,
    ax_prop = get(model.filemenu,'UserData');
    fig = gcf;
    set(fig,'WindowButtonMotionfcn','', ...
        'pointer','arrow','currentaxes',ax_prop.oldca, ...
        'windowbuttonupfcn','');
    set(gca,'DrawMode','normal');
    set(ax_prop.hl(1),'units',setstr(ax_prop.hl(2:length(ax_prop.hl))));
    set(fig,'units',ax_prop.figuts);
    if strcmp(get(gca,'tag'),'legend')
      legend_fcn('ShowLegendPlot')
    end
    set(model.filemenu,'UserData',[]);
end
