function res = posterior_mean(in,tm,r)

%
% Computes the posterior mean of all parameters in the reduced form model
% from the joint posterior distribution
%

res = [];
Omega = 0;
if r>0;
   alpha = 0;
   beta = 0;
end;
if tm.d>0;
   delta = 0;
end;
if size(tm.Z2,1)>tm.d;
   Gamma = 0;
end;
for i=1:tm.save_draws;
   Omega = Omega + ((1/tm.save_draws)*in.posterior(i).Omega);
   if r>0;
      alpha = alpha + ((1/tm.save_draws)*in.posterior(i).alpha);
      beta = beta + ((1/tm.save_draws)*in.posterior(i).beta);
   end;
   if tm.d>0;
      delta = delta + ((1/tm.save_draws)*in.posterior(i).delta);
   end;
   if size(tm.Z2,1)>tm.d;
      Gamma = Gamma + ((1/tm.save_draws)*in.posterior(i).Gamma);
   end;
end;
%
if (isfield(in.posterior(1),'alpha_n')==1)&(r>0);
   alpha_n = 0;
   beta_n = 0;
   for i=1:tm.save_draws;
      alpha_n = alpha_n + ((1/tm.save_draws)*in.posterior(i).alpha_n);
      beta_n = beta_n + ((1/tm.save_draws)*in.posterior(i).beta_n);
   end;
   res.alpha_n = alpha_n;
   res.beta_n = beta_n;
end;
%
res.Omega = Omega;
if r>0;
   res.alpha = alpha;
   res.beta = beta;
else;
   res.beta = [];
   res.alpha = [];
end;
if tm.d>0;
   res.delta = delta;
else;
   res.delta = [];
end;
if size(tm.Z2,1)>tm.d;
   res.Gamma = Gamma;
else;
   res.Gamma = [];
end;

%
% compute the maximum eigenvalue of the companion matrix
%

e_values = companionrest(res.alpha,[res.delta res.Gamma],res.beta,tm.p,tm.n,tm.d);
e_values = sort(abs(e_values));
for i1=1:size(e_values,1);
   max_evalue = e_values(size(e_values,1)-i1+1,1);
   if strcmp(num2str(max_evalue,'%1.10f'),'1.0000000000')==0;
      break;
   end;
end;
res.max_evalue = max_evalue;

%
% end of posterior_mean.m
%
