function print_bayes_rank(cm,curr_ini,out)

prt_tex = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
sp_str = spacestr(curr_ini.decimals-2);
fout = fopen(cm.outputfile,'at');
nse_marglike = zeros(cm.n+1,1);
for i=0:cm.n;
   if (i>0)&(i<cm.n);
      nse_marglike(i+1,1) = out.rank(i+1).posterior_mode.nse_marglike;
   else;
      nse_marglike(i+1,1) = NaN;
   end;
end;
if curr_ini.texoutputformat>=2;
   fprintf(fout,'\\ruler\n\n%%******************************************************************************\n\n');
   prt_str = ['%2.0f & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' & ' prt_tex ' \\\\ \n'];
   fprintf(fout,'\\header{Posterior Cointegration Rank Probabilities} \n\n');
   fprintf(fout,'\\begin{tabular}{rrrrr}\n');
   fprintf(fout,'Rank & $P(\\mbox{\\rm Rank}|\\mbox{\\rm Data})$ & $\\log [P(\\mbox{\\rm Data}|\\mbox{\\rm Rank})]$ & $P(\\mbox{\\rm Rank})$ & st.err. $\\log [P(\\mbox{\\rm Data}|\\mbox{\\rm Rank})]$ \\\\\n');
   fprintf(fout,prt_str,[cm.my_ranks cm.rankprob_ml cm.log_marglike cm.rankpriors nse_marglike]');
   fprintf(fout,'\\end{tabular}\n\n');
   fprintf(fout,'\\vspace*{2mm}\n\n\\noindent\n\\textbf{NOTE:} The calculations are based on the Marginal Likelihood (ML), given by\n$P(\\mbox{\\rm Data}|\\mbox{\\rm Rank})$. It has been computed from the basic marginal likelihood\nidentity with all parameters evaluated at the posterior mode.\n\n');
   fprintf(fout,'\\noindent\nNumerical standard errors of the log marginal likelihood are based on the\nNewey-West correction, taking potential autocorrelation of the $\\beta$ draws\ninto account. Requires that the partial Gibbs sampler has converged.\nStandard errors for the full rank and zero rank models do not exist as\nthese are exact.\n\n');
   %
   % print hyperparameters of the prior distribution
   %
   fprintf(fout,'\\vspace*{3mm}\n\n\\header{Hyperparameters for Prior Distribution} \n\n');
   fprintf(fout,'\\begin{tabular}{ll}\n');
   if cm.prior_inf_shortrun==1;
      fprintf(fout,'Baseline shrinkage ($\\lambda_{b}$): & %0.4f \\\\\n',cm.lambda_b);
      fprintf(fout,'Lag length shrinkage ($\\lambda_{l}$): & %0.4f \\\\\n',cm.lambda_l);
      fprintf(fout,'Off-diagonal/correlation shrinkage ($\\lambda_{\\rho}$): & %0.4f \\\\\n',cm.lambda_theta);
      if cm.q1+cm.q0>0;
         fprintf(fout,'Exogeneity shrinkage ($\\lambda_{e}$): & %0.4f \\\\\n',cm.lambda_e);
      end;
   else;
      fprintf(fout,'\\multicolumn{2}{l}{Improper prior for short-run parameters} \\\\\n');
   end;
   if cm.prior_inf_deter==1;
      fprintf(fout,'Deterministic shrinkage ($\\lambda_{d}$): & %0.4f \\\\\n',cm.lambda_d);
   else;
      fprintf(fout,'\\multicolumn{2}{l}{Improper prior for parameters on deterministic variables} \\\\\n');
   end;
   fprintf(fout,'$\\alpha$ shrinkage ($\\lambda_{\\alpha}$): & %0.4f \\\\\n',cm.lambda_alpha);
   if cm.amat_type==1;
      fprintf(fout,'$\\Omega$ prior type: & ML estimate of $\\Omega$ for full rank model \\\\\n');
      if cm.amat_lag>1;
         fprintf(fout,' & with %0.0f lags as $A$ matrix \\\\\n',cm.use_lag);
         Omega = cm.amat_val;
      else;
         fprintf(fout,' & with %0.0f lags as $A$ matrix \\\\\n',cm.p);
         Omega = cm.rank(cm.n+1).Omega;
      end;
      q_df = cm.n+2;
   else;
      fprintf(fout,'$\\Omega$ prior type: & $A$ matrix shrinkage times identity \\\\\n');
      fprintf(fout,'$A$ matrix shrinkage ($\\lambda_{A}$): & %0.4f \\\\\n',cm.lambda_a);
      %
      q_df = cm.n+2;
      if cm.q_df>=2;
         new_df = round(((cm.q_df-1)/10)*cm.T);
         q_df = max(q_df,new_df);
      end;
   end;
   %
   fprintf(fout,'q parameter: & %0.0f \\\\\n',q_df);
   fprintf(fout,'\\end{tabular}\n\n');
   if (cm.amat_type==1)&(cm.amat_lag>1);
      %
      % print the A matrix
      %
      prt_str = '%s & %0.6f';
      r_str = 'lr';
      for i=2:cm.n;
         prt_str = [prt_str ' & %0.6f'];
         r_str = [r_str 'r'];
      end;
      fprintf(fout,['\\begin{tabular}{' r_str '} \n']);
      fprintf(fout,['\\multicolumn{' num2str(cm.n+1,'%0.0f') '}{l}{A matrix:} \\\\\n']);
      fprintf(fout,['\\multicolumn{' num2str(cm.n+1,'%0.0f') '}{l}{ } \\\\\n']);
      for i=1:cm.n;
         fprintf(fout,[prt_str ' \\\\\n'],cm.myvars(i,:),Omega(i,:));
      end;
      fprintf(fout,'\\end{tabular}\n\n');
   end;
else;
   fprintf(fout,'*******************************************************************************\n\n');
   prt_str = ['  %2.0f        ' prt_tex '         ' prt_val '         ' prt_tex '          ' prt_val ' \n'];
   fprintf(fout,['Posterior Cointegration Rank Probabilities\n\n Rank    P(Rank|Data)' sp_str ' log[P(Data|Rank)] ' sp_str '  P(Rank) ' sp_str '   st.err. log[P(Data|Rank)] \n']);
   fprintf(fout,prt_str,[cm.my_ranks cm.rankprob_ml cm.log_marglike cm.rankpriors nse_marglike]');
   fprintf(fout,'\nNOTE: The calculations are based on the Marginal Likelihood (ML), given by\n      P(Data|Rank). It has been computed from the basic marginal likelihood\n      identity with all parameters evaluated at the posterior mode.\n\n');
   fprintf(fout,'      Numerical standard errors of the log marginal likelihood are based on the\n      Newey-West correction, taking potential autocorrelation of the beta draws\n      into account. Requires that the partial Gibbs sampler has converged.\n      Standard errors for the full rank and zero rank models do not exist as\n      these are exact.\n\n');
   %
   % print hyperparameters of the prior distribution
   %
   fprintf(fout,'Hyperparameters for Prior Distribution\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
   if cm.prior_inf_shortrun==1;
      fprintf(fout,'Baseline shrinkage:                      %0.4f \n',cm.lambda_b);
      fprintf(fout,'Lag length shrinkage:                    %0.4f \n',cm.lambda_l);
      fprintf(fout,'Off-diagonal/correlation shrinkage:      %0.4f \n',cm.lambda_theta);
      if cm.q1+cm.q0>0;
         fprintf(fout,'Exogeneity shrinkage:                    %0.4f \n',cm.lambda_e);
      end;
   else;
      fprintf(fout,'Improper prior for short-run parameters \n');
   end;
   if cm.prior_inf_deter==1;
      fprintf(fout,'Deterministic shrinkage:                 %0.4f \n',cm.lambda_d);
   else;
      fprintf(fout,'Improper prior for parameters on deterministic variables \n');
   end;
   fprintf(fout,'Alpha shrinkage:                         %0.4f \n',cm.lambda_alpha);
   if cm.amat_type==1;
      fprintf(fout,'Omega prior type:                        ML estimate of Omega for full rank model \n');
      if cm.amat_lag>1;
         fprintf(fout,'                                         with %0.0f lags as A matrix \n\n',cm.use_lag);
         Omega = cm.amat_val;
      else;
         fprintf(fout,'                                         with %0.0f lags as A matrix \n\n',cm.p);
         Omega = cm.rank(cm.n+1).Omega;
      end;
      %
      % print the A matrix
      %
      prt_str = '%s   %12.6f';
      for i=2:cm.n;
         prt_str = [prt_str '   %12.6f'];
      end;
      for i=1:cm.n;
         fprintf(fout,[prt_str ' \n'],cm.myvars(i,:),Omega(i,:));
      end;
      fprintf(fout,'\n');
      
      q_df = cm.n+2;
   else;
      fprintf(fout,'Omega prior type:                        A matrix shrinkage times identity \n');
      fprintf(fout,'A matrix shrinkage:                      %0.4f \n',cm.lambda_a);
      %
      q_df = cm.n+2;
      if cm.q_df>=2;
         new_df = round(((cm.q_df-1)/10)*cm.T);
         q_df = max(q_df,new_df);
      end;
   end;
   %
   fprintf(fout,'q parameter:                             %0.0f \n\n',q_df);
end;
for i=0:cm.n;
   %
   % Deal with individual ranks
   %
   if curr_ini.texoutputformat>=2;
      fprintf(fout,'\\halfruler\n\n');
      fprintf(fout,'\\subsection*{Cointegration rank %0.0f}\n\n',i);
      fprintf(fout,'\\header{Summary statistics from the Gibbs sampler} \n\n');
      fprintf(fout,'\\begin{tabular}{ll}\n');
      fprintf(fout,'Total draws & %0.0f \\\\\n',out.rank(i+1).gibbs.draws);
      fprintf(fout,'Burn-in draws & %0.0f \\\\\n',cm.burn_in);
      fprintf(fout,'Considered draws & %0.0f \\\\\n',out.rank(i+1).gibbs.real_draws);
      fprintf(fout,'Total discarded draws & %0.0f \\\\\n',out.rank(i+1).gibbs.discard_draws);
      fprintf(fout,'Discarded explosive draws & %0.0f \\\\\n',out.rank(i+1).gibbs.discard_explosive_draws);
      fprintf(fout,'Draw saving frequency & %0.1f\\%% \\\\\n',100/cm.save_freq);
      fprintf(fout,'Saved draws & %0.0f \\\\\n',cm.save_draws);
      fprintf(fout,'\\end{tabular}\n\n');
      if (i>0)&(i<cm.n);
         prt_str = '%0.0f';
         r_str = 'r';
         for j=1:size(out.rank(i+1).pmcs.beta,1);
            prt_str = [prt_str ' & ' prt_tex];
            r_str = [r_str 'r'];
         end;
         prt_str = [prt_str ' \\\\\n'];
         fprintf(fout,['\\vspace*{3mm}\n\n\\header{Posterior Mean Cointegration Space Estimator}\n\n\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,'relation & %s\n',text_latextable(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec])));
         fprintf(fout,prt_str,[(1:i)' out.rank(i+1).pmcs.beta']');
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{ } \\\\\n']);
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{with projective Frobenius span variation: ' prt_tex '} \\\\\n'],sqrt(out.rank(i+1).pmcs.variation));
         c_bar = cm.rank(i+1).c_mat*inverse(cm.rank(i+1).c_mat'*cm.rank(i+1).c_mat);
         beta = out.rank(i+1).pmcs.beta*inverse(c_bar'*out.rank(i+1).pmcs.beta);
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{ } \\\\\n']);
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Normalized $\\beta$ based on the Identifying Restrictions:} \\\\\n']);
         fprintf(fout,prt_str,[(1:i)' beta']');
         fprintf(fout,'\\end{tabular}\n\n');
         if isfield(out.rank(i+1).pmcs,'beta_n')==1;
            fprintf(fout,['\\vspace*{3mm}\n\n\\header{Partial Posterior Mean Cointegration Space Estimator}\n\n\\begin{tabular}{' r_str '}\n']);
            fprintf(fout,'relation & %s\n',text_latextable(strtrim([cm.evars ' ' cm.xvars1 ' ' cm.restvec])));
            fprintf(fout,prt_str,[(1:i)' out.rank(i+1).pmcs.beta_n']');
            fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{ } \\\\\n']);
            fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{with projective Frobenius span variation: ' prt_tex '} \\\\\n'],sqrt(out.rank(i+1).pmcs.variation_n));
            c_bar = cm.rank(i+1).c_mat*inverse(cm.rank(i+1).c_mat'*cm.rank(i+1).c_mat);
            beta = out.rank(i+1).pmcs.beta_n*inverse(c_bar'*out.rank(i+1).pmcs.beta_n);
            fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{ } \\\\\n']);
            fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Normalized $\\beta$ based on the Identifying Restrictions:} \\\\\n']);
            fprintf(fout,prt_str,[(1:i)' beta']');
            fprintf(fout,'\\end{tabular}\n\n');
         end;
         fprintf(fout,['\\vspace*{3mm}\n\n\\header{Posterior Mode Cointegration Space Estimator}\n\n\\begin{tabular}{' r_str '}\n']);
         fprintf(fout,prt_str,[(1:i)' out.rank(i+1).posterior_mode.beta_cs']');
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{ } \\\\\n']);
         fprintf(fout,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Normalized $\\beta$ based on the Identifying Restrictions:} \\\\\n']);
         fprintf(fout,prt_str,[(1:i)' out.rank(i+1).posterior_mode.beta']');
         fprintf(fout,'\\end{tabular}\n\n');
      end;
      %
      % Deal with some posterior mode features
      %
      fprintf(fout,'\\vspace*{3mm}\n\n\\header{Posterior Mode Properties} \n\n');
      fprintf(fout,'\\begin{tabular}{ll} \n');
      fprintf(fout,['Max absolute eigenvalue of companion matrix:  & ' prt_tex ' \\\\ \n'],out.rank(i+1).posterior_mode.max_evalue);
      fprintf(fout,['Value of log prior density: & ' prt_tex ' \\\\ \n'],out.rank(i+1).posterior_mode.log_prior);
      fprintf(fout,['Value of log data density: & ' prt_tex ' \\\\ \n'],out.rank(i+1).posterior_mode.log_like);
      fprintf(fout,['Value of log posterior density: & ' prt_tex ' \\\\ \n'],out.rank(i+1).posterior_mode.log_post);
      fprintf(fout,'\\end{tabular}\n\n');
   else;
      fprintf(fout,'-------------------------------------------------------------------------------\n\n');
      fprintf(fout,['    Cointegration rank ' num2str(i,'%0.0f') '\n']);
      fprintf(fout,'    ====================\n\n');
      fprintf(fout,['Summary statistics from the Gibbs sampler\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n    Total draws:               ' num2str(out.rank(i+1).gibbs.draws,'%8.0f') '\n    Burn-in draws:             ' num2str(cm.burn_in,'%8.0f') '\n    Considered draws:          ' num2str(out.rank(i+1).gibbs.real_draws,'%8.0f') '\n    Total discarded draws:     ' num2str(out.rank(i+1).gibbs.discard_draws,'%8.0f') '\n    Discarded explosive draws: ' num2str(out.rank(i+1).gibbs.discard_explosive_draws,'%8.0f') '\n    Draw saving frequency:     ' num2str(100/cm.save_freq,'%5.1f') '%% \n    Saved draws:               ' num2str(cm.save_draws,'%8.0f') '\n\n']);
      if (i>0)&(i<cm.n);
         %
         % Posterior Mean Cointegration Space point estimator
         %
         fprintf(fout,'Posterior Mean Cointegration Space Estimator\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         prt_str = '%2.0f';
         for j=1:size(out.rank(i+1).pmcs.beta,1);
            prt_str = [prt_str ' ' prt_val];
         end;
         fprintf(fout,[prt_str '\n'],[(1:i)' out.rank(i+1).pmcs.beta']');
         fprintf(fout,'\n');
         fprintf(fout,['with projective Frobenius span variation: ' prt_val ' \n\n'],sqrt(out.rank(i+1).pmcs.variation));
         c_bar = cm.rank(i+1).c_mat*inverse(cm.rank(i+1).c_mat'*cm.rank(i+1).c_mat);
         beta = out.rank(i+1).pmcs.beta*inverse(c_bar'*out.rank(i+1).pmcs.beta);
         fprintf(fout,'Normalized beta based on the Identifying Restrictions:\n\n');
         fprintf(fout,[prt_str '\n'],[(1:i)' beta']');
         fprintf(fout,'\n');
         if isfield(out.rank(i+1).pmcs,'beta_n')==1;
            fprintf(fout,'Partial Posterior Mean Cointegration Space Estimator\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
            fprintf(fout,[prt_str '\n'],[(1:i)' out.rank(i+1).pmcs.beta_n']');
            fprintf(fout,'\n');
            fprintf(fout,['with projective Frobenius span variation: ' prt_val ' \n\n'],sqrt(out.rank(i+1).pmcs.variation_n));
            c_bar = cm.rank(i+1).c_mat*inverse(cm.rank(i+1).c_mat'*cm.rank(i+1).c_mat);
            beta = out.rank(i+1).pmcs.beta_n*inverse(c_bar'*out.rank(i+1).pmcs.beta_n);
            fprintf(fout,'Normalized beta based on the Identifying Restrictions:\n\n');
            fprintf(fout,[prt_str '\n'],[(1:i)' beta']');
            fprintf(fout,'\n');
         end;
         fprintf(fout,'Posterior Mode Cointegration Space Estimator\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
         fprintf(fout,[prt_str '\n'],[(1:i)' out.rank(i+1).posterior_mode.beta_cs']');
         fprintf(fout,'\nNormalized beta based on the Identifying Restrictions:\n\n');
         fprintf(fout,[prt_str '\n'],[(1:i)' out.rank(i+1).posterior_mode.beta']');
         fprintf(fout,'\n');
      end;
      %
      % Deal with some posterior mode features
      %
      fprintf(fout,'Posterior Mode Properties\n~~~~~~~~~~~~~~~~~~~~~~~~~\n\n');
      fprintf(fout,['Max absolute eigenvalue of companion matrix: ' prt_val ' \n'],out.rank(i+1).posterior_mode.max_evalue);
      fprintf(fout,['Value of log prior density:                  ' prt_val ' \n'],out.rank(i+1).posterior_mode.log_prior);
      fprintf(fout,['Value of log data density:                   ' prt_val ' \n'],out.rank(i+1).posterior_mode.log_like);
      fprintf(fout,['Value of log posterior density:              ' prt_val ' \n'],out.rank(i+1).posterior_mode.log_post);
      fprintf(fout,'\n');
   end;
end;
fclose(fout);

%
% end of print_bayes_rank.m
%
