function print_exclude_dummies(tm,curr_ini)

setlogtext('Computing exlusion tests for additional deterministics...');
[tests,pvals,dfs] = exclude_dummies(tm.epsilon,tm.Z0,tm.Z1,tm.Z2,tm.deter,tm.r,tm.p,tm.pe,tm.q1,tm.q0,tm.df,tm.ad,tm.datad,tm.restrict,tm.modelsdir,tm.modelfile,tm.dcoint,curr_ini.reestbeta,curr_ini.sscorrect,0);
%
num_const = tm.ad;
num_dummies = tm.datad;
%
dummy_names = vecstr(tm.deter);
dummy_names = dummy_names(1+num_const:num_dummies+num_const,:);
%
fout = fopen(tm.outputfile,'at');
%
% check the output format
%
if curr_ini.texoutputformat>=2;
   fprintf(fout,['\\subsection*{Exclusion Restrictions on Deterministic Variables} \n\n\\header{For $r$=' num2str(tm.r) '}\n\n']);
   fprintf(fout,'\\header{LR-type test statistic}\n\n');
   fprintf(fout,'\\begin{tabular}{ll}\n');
   fprintf(fout,'$H_0$: & Row $i$ (variable $k$) of $\\delta_{3} = 0$ \\\\\n');
   fprintf(fout,'$H_A$: & Row $i$ (variable $k$) of $\\delta_{3} \\neq 0$ \\\\[2mm]\n');
   fprintf(fout,'\\end{tabular}\n\n\\begin{tabular}{rrrrr}\n');
   if curr_ini.sscorrect==0;
      fprintf(fout,'$i$ & $k$ & $LR$ & df & $p$-value \\\\\n');
      for i=1:num_dummies;
         fprintf(fout,['%0.0f & %s & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & %0.0f & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],i,txt2ltxmath(strtrim(dummy_names(i,:))),tests(i,1),dfs(i,1),pvals(i,1));
      end;
      fprintf(fout,'\\end{tabular}\n\n');
      if num_dummies>0;
         fprintf(fout,'\\vspace*{3mm}\n\n\\begin{tabular}{rrr}\n');
         fprintf(fout,'$H_{0}$: & \\multicolumn{2}{l}{$\\delta_{3} = 0$} \\\\\n');
         fprintf(fout,'$H_{0}$: & \\multicolumn{2}{l}{$\\delta_{3} \\neq 0$} \\\\\n');
         fprintf(fout,'\\multicolumn{3}{c}{ } \\\\\n');
         fprintf(fout,'$LR$ & df & $p$-value \\\\\n');
         fprintf(fout,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f & %0.0f & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],tests(num_dummies+1,1),dfs(num_dummies+1,1),pvals(num_dummies+1,1));
         fprintf(fout,'\\end{tabular}\n\n');
      end;
   else;
      fprintf(fout,'$i$ & $k$ & $F$ & df & $p$-value \\\\\n');
      for i=1:num_dummies;
         fprintf(fout,['%0.0f & %s & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & (%0.0f,%0.0f) & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],i,txt2ltxmath(strtrim(dummy_names(i,:))),tests(i,1),dfs(i,1),dfs(i,2),pvals(i,1));
      end;
      fprintf(fout,'\\end{tabular}\n\n');
      if num_dummies>0;
         fprintf(fout,'\\vspace*{3mm}\n\n\\begin{tabular}{rrr}\n');
         fprintf(fout,'$H_{0}$: & \\multicolumn{2}{l}{$\\delta_{3} = 0$} \\\\\n');
         fprintf(fout,'$H_{0}$: & \\multicolumn{2}{l}{$\\delta_{3} \\neq 0$} \\\\\n');
         fprintf(fout,'\\multicolumn{3}{c}{ } \\\\\n');
         fprintf(fout,'$F$ & df & $p$-value \\\\\n');
         fprintf(fout,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f & (%0.0f,%0.0f) & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],tests(num_dummies+1,1),dfs(num_dummies+1,1),dfs(num_dummies+1,2),pvals(num_dummies+1,1));
         fprintf(fout,'\\end{tabular}\n\n');
      end;
   end;
   fprintf(fout,'\\ruler\n\n%%==============================================================================\n\n');
else;
   sp_str = spacestr(curr_ini.decimals-2);
   fprintf(fout,['TESTING EXCLUSION RESTRICTIONS ON DETERMINISTIC VARIABLES (for rank=' num2str(tm.r) ') \n\n']);
   fprintf(fout,'  LR-type test statistic\n  ~~~~~~~~~~~~~~~~~~~~~~ \n\n');
   fprintf(fout,'Null Hypothesis:        Dummy k has zero coefficients \n');
   fprintf(fout,'Alternative Hypothesis: Dummy k does not have zero coefficients \n\n');
   if curr_ini.sscorrect==0;
      fprintf(fout,['  k         LR  ' sp_str '   df       p-value \n']);
      prt_str = [' %s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    %2.0f       %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'];
      for i=1:num_dummies;
         fprintf(fout,prt_str,dummy_names(i,:),tests(i,1),dfs(i,1),pvals(i,1));
      end;
      if num_dummies>1;
         fprintf(fout,'\nNull Hypothesis:        All dummies have zero coefficients \n');
         fprintf(fout,'Alternative Hypothesis: All dummies do not have zero coefficients \n\n');
         fprintf(fout,['LR(%0.0f)  = %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'],dfs(num_dummies+1,1),tests(num_dummies+1,1));
         fprintf(fout,['p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'],pvals(num_dummies+1,1));
      end;
   else;
      fprintf(fout,['  k          F    ' sp_str '    df          p-value \n']);
      prt_str = [' %s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    (%2.0f,%3.0f)       %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'];
      for i=1:num_dummies;
         fprintf(fout,prt_str,dummy_names(i,:),tests(i,1),dfs(i,1),dfs(i,2),pvals(i,1));
      end;
      if num_dummies>1;
         fprintf(fout,'\nNull Hypothesis:        All dummies have zero coefficients \n');
         fprintf(fout,'Alternative Hypothesis: All dummies do not have zero coefficients \n\n');
         fprintf(fout,['F(%0.0f,%0.0f) = %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'],dfs(num_dummies+1,1),dfs(num_dummies+1,2),tests(num_dummies+1,1));
         fprintf(fout,['p-value  = %0.' num2str(curr_ini.decimals,'%0.0f') 'f \n'],pvals(num_dummies+1,1));
      end;
   end;
   fprintf(fout,'\n===============================================================================\n\n');
end;
%
fclose(fout);
%
% end of print_exclude_dummies.m
%
