function print_exclusion(tm,curr_ini)

%
% compute the tests
%
[tests,deg_free,pvals] = coint_exclusion(tm.S_00,tm.S_01,tm.S_10,tm.S_11,tm.M_02,tm.M_22,tm.M_12,tm.Z0,tm.Z1,tm.Z2,tm.epsilon,tm.r,tm.q1,tm.dcoint,tm.df,curr_ini.sscorrect);
%
% setting up variable names
%
myvars = tm.myvars;
if tm.q1>0;
   myvars = strvcat(myvars,vecstr(tm.xvars1));
end;
if tm.dcoint>0;
   myvars = strvcat(myvars,vecstr(tm.restvec));
end;
%
fout = fopen(tm.outputfile,'at');
%
% check the output format
%
if curr_ini.texoutputformat>=2;
   fprintf(fout,['\\subsection*{Exclusion Restrictions}\n\n\\header{For $r$=' num2str(tm.r) '}\n\n']);
   fprintf(fout,'\\header{LR-type test statistic}\n');
   fprintf(fout,'\\begin{tabular}{ll}\n');
   fprintf(fout,'$H_0$: & row $k$ (variable $k$) of $\\beta = 0$ \\\\\n');
   fprintf(fout,'$H_A$: & row $k$ (variable $k$) of $\\beta \\neq 0$ \\\\[2mm]\n');
   fprintf(fout,'\\end{tabular}\n\n\\begin{tabular}{rrrr}\n');
   if curr_ini.sscorrect==0;
      fprintf(fout,'$k$ & $LR$ & df & $p$-value \\\\\n');
      for i=1:size(tests,1);
         fprintf(fout,['%s & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & %0.0f & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],txt2ltxmath(strtrim(myvars(i,:))),tests(i,1),deg_free(i,1),pvals(i,1));
      end;
   else;
      fprintf(fout,'$k$ & $F$ & df & $p$-value \\\\\n');
      for i=1:size(tests,1);
         fprintf(fout,['%s & %0.' num2str(curr_ini.decimals,'%0.0f') 'f & (%0.0f,%0.0f) & %0.' num2str(curr_ini.decimals,'%0.0f') 'f \\\\\n'],txt2ltxmath(strtrim(myvars(i,:))),tests(i,1),deg_free(i,1),deg_free(i,2),pvals(i,1));
      end;
   end;
   fprintf(fout,'\\end{tabular}\n\n\\ruler\n\n%%==============================================================================\n\n');
else;
   fprintf(fout,['EXCLUSION RESTRICTIONS (for rank=' num2str(tm.r,'%0.0f') ') \n\n']);
   fprintf(fout,'  LR-type test statistic\n  ~~~~~~~~~~~~~~~~~~~~~~\n\n');
   fprintf(fout,'Null Hypothesis:        row k (variable k) of beta is zero\n');
   fprintf(fout,'Alternative Hypothesis: row k (variable k) of beta is not zero\n\n');
   if curr_ini.sscorrect==0;
      fprintf(fout,' k       LR      df      p-value\n');
      prt_str = ['%s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    %2.0f       %0.' num2str(curr_ini.decimals,'%0.0f') 'f\n'];
      for i=1:size(tests,1);
         fprintf(fout,prt_str,myvars(i,:),tests(i,1),deg_free(i,1),pvals(i,1));
      end;
   else;
      fprintf(fout,' k       F        df         p-value\n');
      prt_str = ['%s   %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f    (%0.0f,%0.0f)       %0.' num2str(curr_ini.decimals,'%0.0f') 'f\n'];
      for i=1:size(tests,1);
         fprintf(fout,prt_str,myvars(i,:),tests(i,1),deg_free(i,1),deg_free(i,2),pvals(i,1));
      end;
   end;
   fprintf(fout,'\n===============================================================================\n\n');
end;

fclose(fout);

%
% end of print_exclusion.m
%
