%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          Computes statistics for residuals                     %
%                                                                %
%          Function: residstat                                   %
%                                                                %
%          Input:                                                %
%                       epsilon: nxT matrix with residuals       %
%                       y: nxT matrix with endogenous variables  %
%                                                                %
%          Output:                                               %
%          	            stats: nx7 matrix with statistics        %
%                           for the residuals                    %
%                       corrmat: nxn correlation matrix for      %
%                           the residuals                        %
%                                                                %
%          This version:        June 1, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [stats,corrmat] = residstat(epsilon,y)

[n T] = size(epsilon);

corrmat = (1/T)*epsilon*epsilon';
stddev = sqrt(diag(diag(corrmat)));

for i=1:n;
   for j=1:n;
      corrmat(i,j) = corrmat(i,j)/(stddev(i,i)*stddev(j,j));
   end;
end;

%
% mean errors
%

stats = (1/T)*sum(epsilon,2);

%
% standard deviations
%

stats = [stats sqrt((1/T)*sum(epsilon.*epsilon,2))];

%
% skewness
%

mynorm = stats(:,2);
normeps = epsilon./(mynorm*ones(1,T));

stats = [stats (1/T)*sum(normeps.*normeps.*normeps,2)];

%
% kurtosis
%

stats = [stats (1/T)*sum(normeps.*normeps.*normeps.*normeps,2)];

%
% min and max
%

stats = [stats min(epsilon')' max(epsilon')'];

%
% R2 for each variable
%

y = y-((1/T)*sum(y,2)*ones(1,T));
stats = [stats 1-diag(epsilon*epsilon')./diag(y*y')];

%
% end of residstat.m
%
