%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for showing spreadsheet choices     %
%                                                                %
%          Function: scatter_dlg                                 %
%                                                                %
%          Input:                                                %
%                       text_vars: string matrix                 %
%                                                                %
%          Output:                                               %
%          	            action: OK or Cancel                     %
%                       x_val: variable number for X-axis        %
%                       y_val: variable number for Y-axis        %
%                       mark_type: string with marker style      %
%                       bool_fd: 1 if in first difference, 0 if  %
%                           in levels.                           %
%                                                                %
%          This version:        June 14, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [action,x_val,y_val,mark_type,bool_fd] = scatter_dlg(text_vars)

%
% initialize
%

scrsz = get(0,'ScreenSize');
curr_ini = find_inisettings;

scatter_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'FileName','scatter_dlg.m', ...
   'MenuBar','none', ...
   'Units','pixels', ...
   'Position',[(scrsz(3)/2)-200 (scrsz(4)/2)-95 400 190], ...
   'Tag','ScatterDlg', ...
   'Resize','off', ...
   'Name','Scatter Plot Options', ...
   'Visible','off', ...
   'NumberTitle','off', ...
   'WindowStyle','modal', ...
   'CloseRequestFcn','closegui', ...
   'ToolBar','none');

if matlabnumber>=7.0;
   set(scatter_gui,'DockControl','off');
end;

axesbox([2 2 398 180],'Options',35,[0.5 1]);

uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[12 140 88 20], ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Style','text', ...
   'HorizontalAlignment','left', ...
   'String','X-axis variable:', ...
   'Tag','XText');

edits.x_val = uicontrol('Units','pixels', ...
   'BackgroundColor',[1 1 1], ...
   'Position',[150 145 238 20], ...
   'Value',1, ...
   'String',text_vars, ...
   'Style','popupmenu', ...
   'HorizontalAlignment','left', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Enable','on', ...
   'Tag','XValue');

uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[12 110 88 20], ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Style','text', ...
   'HorizontalAlignment','left', ...
   'String','Y-axis variable:', ...
   'Tag','XText');

edits.y_val = uicontrol('Units','pixels', ...
   'BackgroundColor',[1 1 1], ...
   'Position',[150 115 238 20], ...
   'Value',2, ...
   'String',text_vars, ...
   'Style','popupmenu', ...
   'HorizontalAlignment','left', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Enable','on', ...
   'Tag','YValue');

uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[12 80 88 20], ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Style','text', ...
   'HorizontalAlignment','left', ...
   'String','Marker style:', ...
   'Tag','MarkerText');

edits.marker = uicontrol('Units','pixels', ...
   'BackgroundColor',[1 1 1], ...
   'Position',[150 85 238 20], ...
   'Value',1, ...
   'String','plus sign|circle|asterisk|point|cross|square|diamond|up triangle|down triangle|right triangle|left triangle|pentagram|hexagram', ...
   'Style','popupmenu', ...
   'HorizontalAlignment','left', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Enable','on', ...
   'Tag','MarkerValue');

edits.first_diffs = uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[12 50 300 20], ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Style','checkbox', ...
   'HorizontalAlignment','left', ...
   'Value',0, ...
   'String','Take the first differences of both variables', ...
   'Tag','MarkerText');

%
% Two buttons to select action
%

edits.ok = uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[107.5 12 90 20], ...
   'String','OK', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Enable','on', ...
   'Callback','closegui', ...
   'UserData','waiting', ...
   'Tag','ButtonOK');

edits.cancel = uicontrol('Units','pixels', ...
   'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[202.5 12 90 20], ...
   'String','Cancel', ...
   'FontSize',curr_ini.gui_fontsize, ...
   'FontName',curr_ini.gui_fontname, ...
   'FontWeight',curr_ini.gui_fontweight, ...
   'FontAngle',curr_ini.gui_fontangle, ...
   'Enable','on', ...
   'Callback','closegui', ...
   'Tag','ButtonCancel');

pid = [];
if (iswinnt==1)&(iscompiled==1);
   if curr_ini.loadguiicon==1;
      drawnow;
      set(scatter_gui,'WindowStyle','modal');
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(scatter_gui,'Name') ' ' fix_filepath([pwd '\icons\preferences.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
      end;
   end;
   set(scatter_gui,'Visible','on');
   drawnow;
   if matlabnumber<7;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(scatter_gui,'Name') ' 2'];
      dos(prog);
      drawnow;
   else;
      uicontrol(edits.ok);
   end;
else;
   if matlabnumber>=7;
      uicontrol(edits.ok);
   end;
   set(scatter_gui,'Visible','on');
   drawnow;
end;
waitfor(scatter_gui,'waitstatus','inactive');
%uiwait(scatter_gui);

action = get(get(scatter_gui,'CurrentObject'),'String');

if isempty(action)==1;
   action = 'Cancel';
end;


if strcmp(action,'Cancel')==0;
   x_val = get(edits.x_val,'Value');
   y_val = get(edits.y_val,'Value');
   mark_val = get(edits.marker,'Value');
   mark_str = strvcat('+','o','*','.','x','s','d','^','v','>','<','p','h');
   mark_type = strtrim(mark_str(mark_val,:));
   bool_fd = get(edits.first_diffs,'Value');
else;
   x_val = 0;
   y_val = 0;
   mark_type = '';
   bool_fd = 0;
end;

delete(scatter_gui);
drawnow;

if (isempty(pid)==0)&(pid>-1)&(ispid('seticon',pid)==1);
   pid_prog = ['bin\runwindow.exe ' fix_path([curr_ini.pstoolsdir 'pskill.exe']) ' ' num2str(pid,'%0.0f') '>' fix_path([curr_ini.tempdir 'killpid.txt'])];
   dos(pid_prog);
   if ispid('seticon',pid)==1;
      pid_prog = ['bin\runwindow.exe ' fix_path([curr_ini.pstoolsdir 'pskill.exe']) ' ' num2str(pid,'%0.0f')];
      dos(pid_prog);
   end;
end;

%
% end of scatter_dlg.m
%
