%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for selecting variables to perform  %
%          multi-step Granger causality tests                    %
%                                                                %
%          Function: select_mgc                                  %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       c_mod: structure with model info         %
%                       beta: the cointegration vectors          %
%                       Sigma_theta: covariance matrix for the   %
%                          estimated parameters (may be empty)   %
%                       ind: 0-1 indicator for restrictions on   %
%                          alpha                                 %
%                       b_ind: 0-1 indicator for restrictions on %
%                          beta                                  %
%                       c_ind: 0-1 indicator for restrictions on %
%                          the C matrix                          %
%                                                                %
%          Output:                                               %
%                       h: handle                                %
%                                                                %
%          This version:        May 3, 2006                      %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = select_mgc(selector,c_mod,beta,Sigma_theta,ind,b_ind,c_ind)

if strcmp(selector,'init')==1;
   t_m = c_mod;
   thisexit = 0;
   curr_ini = find_inisettings;
   t_m.beta = beta;
   t_m.Sigma_theta = Sigma_theta;
   t_m.ind = ind;
   t_m.b_ind = b_ind;
   t_m.c_ind = c_ind;
else;
   thisexit = 1;
   mgcgui = get(0,'CurrentFigure');
   mgc = get(mgcgui,'UserData');
   curr_ini = get(mgc.popup_i,'UserData');
   t_m = curr_ini.models;
end;

%
% Set screen size directly instead of using
% get(0,'ScreenSize')!
%

realscrsz = get(0,'ScreenSize');

switch selector;
   case 'init';
      mgcgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','select_mgc.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-441)/2 (realscrsz(4)-140)/2 441 140], ...
         'Tag','FigParent', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name','Multi-Step Granger Causality', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','select_mgc done', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(mgcgui,'DockControl','off');
      end;

      %
      % Outer axis
      %

      axesbox([2 2 439 130],'Tests',25,[0.5 1]);

      imageaxes = axes('Units','pixels', ...
         'Box','on', ...
         'TickLength',[0 0], ...
         'CameraUpVector',[0 1 0], ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 85 39 39], ...
         'XTickLabelMode','manual', ...
         'YTickLabelMode','manual', ...
         'Tag','AxisLogo', ...
         'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

      mycons = getstoredimages;
      if curr_ini.use_toolbar_bgcolor==1;
         bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
         bgcolor(1) = max(0,bgcolor(1));
         bgcolor(2) = max(0,bgcolor(2));
         bgcolor(3) = max(0,bgcolor(3));
      else;
         bgcolor = get(0,'defaultuicontrolbackgroundcolor');
      end;
      %
      image('CData',mirrorimage(maketrans(mycons.gcbig_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

      mgc.icon = show_text([80 85 200 30],[0 0 0],strvcat('H_0: y_i is h-step Granger non-causal for y_j','H_A: y_i is h-step Granger causal for y_j'),[0 0.5],9);

      %
      % Select variable
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 46 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Select Variable i:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');

      mgc.popup_i = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[144 50 150 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',t_m.myvars, ...
         'Tag','GraphListbox',...
         'Value',1);

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[24 16 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'String','Select Variable j:', ...
         'HorizontalAlignment','left', ...
         'Tag','VariableText');

      mgc.popup_j = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[144 20 150 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'String',t_m.myvars, ...
         'Tag','GraphListbox',...
         'Value',2);

      %
      % Create graph button
      %

      mgc.show = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[336 55 90 20], ...
         'String','Display', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','select_mgc showgraph', ...
         'UserData','working', ...
         'Enable','on', ...
         'Tag','Done');

      %
      %  Done button
      %

      mgc.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[336 20 90 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','select_mgc done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','Done');

      set(mgcgui,'UserData',mgc,...
         'HandleVisibility','callback');
   case 'showgraph'
      val_i = get(mgc.popup_i,'Value');
      val_j = get(mgc.popup_j,'Value');
      new_val_i = val_i+1;
      new_val_j = val_j;
      if new_val_i==val_j;
         new_val_i = val_i+2;
      end;
      if new_val_i>t_m.n;
         new_val_i = 1;
         new_val_j = new_val_j+1;
         if new_val_j>t_m.n;
            new_val_j = 1;
         end;
         if new_val_i==new_val_j;
            new_val_i = 2;
         end;
      end;
      set(mgc.popup_i,'Value',new_val_i);
      set(mgc.popup_j,'Value',new_val_j);
      set(mgcgui,'Visible','off');
      drawnow;
      %
      % we're now ready to compute the multi-step Granger causality tests
      %
      [tests,df,pvals] = waldmgctest(t_m.Psi,t_m.alpha,t_m.beta,t_m.p,t_m.pe,t_m.epsilon,t_m.Z1,t_m.Z2,t_m.q1,t_m.q0,t_m.d,t_m.T-t_m.df,t_m.ind,t_m.Sigma_theta,t_m.c_ind,curr_ini.sscorrect,curr_ini.noise_parm,val_i,val_j);
      %
      res_str = '';
      if t_m.b_ind==1;
         res_str = ' restricted';
      end;
      %
      gctext = strvcat(' ',['MULTI-STEP GRANGER CAUSALITY TESTS (for' res_str ' rank=' num2str(t_m.r,'%1.0f') ')']);
      numchar = size(gctext,2);
      addcorr = '';
      for i=1:numchar;
         addcorr = strcat(addcorr,'=');
      end;
      sp_str = spacestr(curr_ini.decimals-2);
      gctext = strvcat(gctext,addcorr,' ');
      gctext = strvcat(gctext,'  Wald-type test statistic','  ~~~~~~~~~~~~~~~~~~~~~~~~',' ');
      gctext = strvcat(gctext,['Null Hypothesis:        ' strtrim(t_m.myvars(val_i,:)) ' is h-step Granger noncausal for ' strtrim(t_m.myvars(val_j,:))]);
      gctext = strvcat(gctext,['Alternative Hypothesis: ' strtrim(t_m.myvars(val_i,:)) ' is h-step Granger causal for ' strtrim(t_m.myvars(val_j,:))],' ');
      if curr_ini.sscorrect==0;
         gctext = strvcat(gctext,['horizon        W    ' sp_str '   df        p-value']);
         for i=1:size(tests,1);
            if isequal(tests(i,1),0)==0;
               if i>1;
                  gctext = strvcat(gctext,sprintf(['  1-%2.0f      %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f     %2.0f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],i,tests(i,1),df(i,1),pvals(i,1)));
               else;
                  gctext = strvcat(gctext,sprintf(['    %2.0f      %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f     %2.0f        %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],i,tests(i,1),df(i,1),pvals(i,1)));
               end;
            else;
               if i>1;
                  gctext = strvcat(gctext,sprintf('  1-%2.0f      Not computed',i));
               else;
                  gctext = strvcat(gctext,sprintf('    %2.0f      Not computed',i));
               end;
            end;
         end;
      else;
         gctext = strvcat(gctext,['horizon        F    ' sp_str '      df           p-value']);
         for i=1:size(tests,1);
            if isequal(tests(i,1),0)==0;
               if i>1;
                  gctext = strvcat(gctext,sprintf(['  1-%2.0f      %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f     (%2.0f,%3.0f)        %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],i,tests(i,1),df(i,1),df(i,2),pvals(i,1)));
               else;
                  gctext = strvcat(gctext,sprintf(['    %2.0f      %' num2str(4+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f     (%2.0f,%3.0f)        %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],i,tests(i,1),df(i,1),df(i,2),pvals(i,1)));
               end;
            else;
               if i>1;
                  gctext = strvcat(gctext,sprintf('  1-%2.0f      Not computed',i));
               else;
                  gctext = strvcat(gctext,sprintf('    %2.0f      Not computed',i));
               end;
            end;
         end;
      end;
      gctext = strvcat(gctext,' ',['NOTE: Horizon 1-' num2str(size(tests,1),'%0.0f') ' implies infinite-step Granger noncausality'],'      (causality) under the null (alternative) hypothesis.','      Furthermore, horizon 1 is identical to the usual Granger','      causality test.',' ');
      %
      textgui(gctext,'Multi-Step Granger Causality Tests',[(realscrsz(3)-600)/2 (realscrsz(4)-450)/2 600 450],'Results',38);
      set(mgcgui,'Visible','on');
      drawnow;
   case 'done'
      set(mgc.done,'UserData','done');
end;

if nargout==1;
   h = mgcgui;
end;

if strcmp(selector,'done')==0;
   curr_ini.models = t_m;
   set(mgc.popup_i,'UserData',curr_ini);
   set(mgcgui,'UserData',mgc);
end;

if thisexit==0;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(mgcgui,'Name') ' ' fix_filepath([pwd '\icons\gc.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(mgc.icon,'UserData',pid);
      end;
   end;
   %
   set(mgcgui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(mgcgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(mgc.done);
   end;
   waitfor(mgc.done,'UserData','done');
end;

%
% end of select_mgc.m
%
