%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI for editing graphs in the stand-alone      %
%          release.                                              %
%                                                                %
%          Function: toolbar_edit_fcn                            %
%                                                                %
%          Input:                                                %
%                        selector: optional case string          %
%                        simclick: simulated click on tab        %
%                                                                %
%          Output:                                               %
%          		           Axes properties dialog                  %
%                                                                %
%          This version: 	    March 28, 2006                     %
%          Written by: 		    Anders Warne                       %
%          			              Copyright (c) 2001-2006            %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function toolbar_edit_fcn(selector,simclick)

if nargin==0;
   selector = 'init';
   fe.basefig = get(0,'CurrentFigure');
   toolbar = get(fe.basefig,'UserData');
   fe.myaxes = get(toolbar.print,'UserData');
   basepos = get(fe.basefig,'Position');
   basepos = [(basepos(1,1)+(basepos(1,3)-500)/2) (basepos(1,2)+(basepos(1,4)+22-470)/2)];
   if (basepos(1,1)<0)|(basepos(1,2)<0);
      basepos = [100 100];
   end;
   fe.basepos2D = basepos;
   %
   % remember that fe.myaxes may not be a scalar handle, but
   % a vector of handles
   %
   if size(fe.myaxes,2)>1;
      axesenable = 'on';
   else;
      axesenable = 'off';
   end;
   %
   fe.axestitle = strrep(get(get(fe.myaxes(1,1),'Title'),'string'),'|',' \bar ');
   if size(fe.myaxes,2)>1;
      for i=2:size(fe.myaxes,2);
         fe.axestitle = [fe.axestitle '|' strrep(get(get(fe.myaxes(1,i),'Title'),'string'),'|',' \bar ')];
      end;
   end;
   if isempty(fe.axestitle)==1;
      fe.axestitle = ' ';
   end;
   fe.axesvalue = 1;
   fe.curraxes = fe.myaxes(1,1);
   %
   % reading all the axes info
   %

   for i=1:size(fe.myaxes,2);
      fe.myeditgraph(i).title = get(get(fe.myaxes(1,i),'Title'),'string');
      fe.myeditgraph(i).xlabel = get(get(fe.myaxes(1,i),'XLabel'),'string');
      fe.myeditgraph(i).ylabel = get(get(fe.myaxes(1,i),'YLabel'),'string');
      fe.myeditgraph(i).xlim = get(fe.myaxes(1,i),'XLim');
      fe.myeditgraph(i).ylim = get(fe.myaxes(1,i),'YLim');
      fe.myeditgraph(i).xlimmode = get(fe.myaxes(1,i),'XLimMode');
      fe.myeditgraph(i).ylimmode = get(fe.myaxes(1,i),'YLimMode');
      fe.myeditgraph(i).xgrid = get(fe.myaxes(1,i),'XGrid');
      fe.myeditgraph(i).ygrid = get(fe.myaxes(1,i),'YGrid');
      fe.myeditgraph(i).xtickmode = get(fe.myaxes(1,i),'XTickMode');
      fe.myeditgraph(i).ytickmode = get(fe.myaxes(1,i),'YTickMode');
      fe.myeditgraph(i).xtick = get(fe.myaxes(1,i),'XTick');
      fe.myeditgraph(i).ytick = get(fe.myaxes(1,i),'YTick');
      fe.myeditgraph(i).xdir = get(fe.myaxes(1,i),'XDir');
      fe.myeditgraph(i).ydir = get(fe.myaxes(1,i),'YDir');
      fe.myeditgraph(i).xscale = get(fe.myaxes(1,i),'XScale');
      fe.myeditgraph(i).yscale = get(fe.myaxes(1,i),'YScale');
      fe.myeditgraph(i).xaxislocation = get(fe.myaxes(1,i),'XAxisLocation');
      fe.myeditgraph(i).yaxislocation = get(fe.myaxes(1,i),'YAxisLocation');
      fe.myeditgraph(i).applyenable = 'off';
      %
      % Checking for 3-D graph (i.e., if there are surfaces)
      %
      fe.myeditgraph(i).surfhandles = (findobj(fe.myaxes(1,i),'Type','surface')');
      if isempty(fe.myeditgraph(i).surfhandles)==0;
         fe.myeditgraph(i).zlabel = get(get(fe.myaxes(1,i),'ZLabel'),'string');
         fe.myeditgraph(i).zlim = get(fe.myaxes(1,i),'ZLim');
         fe.myeditgraph(i).zlimmode = get(fe.myaxes(1,i),'ZLimMode');
         fe.myeditgraph(i).zgrid = get(fe.myaxes(1,i),'ZGrid');
         fe.myeditgraph(i).ztickmode = get(fe.myaxes(1,i),'ZTickMode');
         fe.myeditgraph(i).ztick = get(fe.myaxes(1,i),'ZTick');
         fe.myeditgraph(i).zdir = get(fe.myaxes(1,i),'ZDir');
         fe.myeditgraph(i).zscale = get(fe.myaxes(1,i),'ZScale');
      else;
         fe.myeditgraph(i).zlabel = '';
         fe.myeditgraph(i).zlim = [0 1];
         fe.myeditgraph(i).zlimmode = 'auto';
         fe.myeditgraph(i).zgrid = 'off';
         fe.myeditgraph(i).ztickmode = 'auto';
         fe.myeditgraph(i).ztick = [];
         fe.myeditgraph(i).zdir = 'normal';
         fe.myeditgraph(i).zscale = 'linear';
      end;
   end;
   %
   % backup
   %
   fe.oldmyeditgraph = fe.myeditgraph;
   %
   % Setting grid defaults
   %
   if strcmp(fe.myeditgraph(1).xgrid,'on')==1;
      xgridvalue = 1;
   else;
      xgridvalue = 0;
   end;
   if strcmp(fe.myeditgraph(1).ygrid,'on')==1;
      ygridvalue = 1;
   else;
      ygridvalue = 0;
   end;
   %
   % Setting tick step defaults
   %
   if strcmp(fe.myeditgraph(1).xtickmode,'manual')==1;
      xtickmodevalue = 1;
      xtickenable = 'on';
   else;
      xtickmodevalue = 0;
      xtickenable = 'off';
   end;
   if strcmp(fe.myeditgraph(1).ytickmode,'manual')==1;
      ytickmodevalue = 1;
      ytickenable = 'on';
   else;
      ytickmodevalue = 0;
      ytickenable = 'off';
   end;
   if size(fe.myeditgraph(1).xtick,2)>1;
      xtickstr = num2str((fe.myeditgraph(1).xtick(1,2)-fe.myeditgraph(1).xtick(1,1)));
   else;
      xtickstr = '';
   end;
   if size(fe.myeditgraph(1).ytick,2)>1;
      ytickstr = num2str((fe.myeditgraph(1).ytick(1,2)-fe.myeditgraph(1).ytick(1,1)));
   else;
      ytickstr = '';
   end;
   if strcmp(fe.myeditgraph(1).zgrid,'on')==1;
      zgridvalue = 1;
   else;
      zgridvalue = 0;
   end;
   if strcmp(fe.myeditgraph(1).ztickmode,'manual')==1;
      ztickmodevalue = 1;
      ztickenable = 'on';
   else;
      ztickmodevalue = 0;
      ztickenable = 'off';
   end;
   if size(fe.myeditgraph(1).ztick,2)>1;
      ztickstr = num2str((fe.myeditgraph(1).ztick(1,2)-fe.myeditgraph(1).ztick(1,1)));
   else;
      ztickstr = '';
   end;
   %
   % scale value
   %
   if strcmp(fe.myeditgraph(1).xscale,'linear')==1;
      xscalevalue = 1;
   else;
      xscalevalue = 0;
   end;
   if strcmp(fe.myeditgraph(1).yscale,'linear')==1;
      yscalevalue = 1;
   else;
      yscalevalue = 0;
   end;
   if strcmp(fe.myeditgraph(1).zscale,'linear')==1;
      zscalevalue = 1;
   else;
      zscalevalue = 0;
   end;
   %
   % direction defaults
   %
   if strcmp(fe.myeditgraph(1).xdir,'normal')==1;
      xdirvalue = 1;
   else;
      xdirvalue = 0;
   end;
   if strcmp(fe.myeditgraph(1).ydir,'normal')==1;
      ydirvalue = 1;
   else;
      ydirvalue = 0;
   end;
   if strcmp(fe.myeditgraph(1).zdir,'normal')==1;
      zdirvalue = 1;
   else;
      zdirvalue = 0;
   end;
   %
   % axis locations
   %
   if strcmp(fe.myeditgraph(1).xaxislocation,'top')==1;
      xlocvalue = 1;
   else;
      xlocvalue = 0;
   end;
   if strcmp(fe.myeditgraph(1).yaxislocation,'right')==1;
      ylocvalue = 1;
   else;
      ylocvalue = 0;
   end;
   %
   % limit modes
   %
   if strcmp(fe.myeditgraph(1).xlimmode,'auto')==1;
      xlimmodevalue = 0;
      xlimenable = 'off';
   else;
      xlimmodevalue = 1;
      xlimenable = 'on';
   end;
   if strcmp(fe.myeditgraph(1).ylimmode,'auto')==1;
      ylimmodevalue = 0;
      ylimenable = 'off';
   else;
      ylimmodevalue = 1;
      ylimenable = 'on';
   end;
   if strcmp(fe.myeditgraph(1).zlimmode,'auto')==1;
      zlimmodevalue = 0;
      zlimenable = 'off';
   else;
      zlimmodevalue = 1;
      zlimenable = 'on';
   end;
   %
   if fe.myeditgraph(1).xlim(1,1)<=0;
      xscaleenable = 'off';
   else;
      xscaleenable = 'on';
   end;
   if fe.myeditgraph(1).ylim(1,1)<=0;
      yscaleenable = 'off';
   else;
      yscaleenable = 'on';
   end;
   if fe.myeditgraph(1).zlim(1,1)<=0;
      zscaleenable = 'off';
   else;
      zscaleenable = 'on';
   end;
   %
   % Add pixels to window width
   %
   if isempty(fe.myeditgraph(1).surfhandles)==1
      addwidth = 0;
      xlocenable = 'on';
      ylocenable = 'on';
      z_show_enable = 'off';
   else;
      addwidth = 207;
      basepos(1) = basepos(1)-(207/2);
      basepos(2) = basepos(2)+20;
      xlocenable = 'off';
      ylocenable = 'off';
      z_show_enable = 'on';
   end;
   fe.basepos3D = [fe.basepos2D(1)-(207/2) fe.basepos2D(2)+20];
   addwidth3D = 207;
   fe.figpos2D = [fe.basepos2D 500 470];
   fe.figpos3D = [fe.basepos3D 707 470];
   fe.title2D = [80 410 404 40];
   fe.title3D = [80 410 611 40];
   fe.change2D = [125 55 360 20];
   fe.change3D = [125 55 567 20];
   fe.ok2D = [127.5 14 75 20];
   fe.ok3D = [127.5+addwidth3D/2 14 75 20];
   fe.cancel2D = [212.5 14 75 20];
   fe.cancel3D = [212.5+addwidth3D/2 14 75 20];
   fe.apply2D = [297.5 14 75 20];
   fe.apply3D = [297.5+addwidth3D/2 14 75 20];
   fe.axesbox2D = [2 2 498 463];
   fe.axesbox3D = [2 2 705 463];
   realscrsz = get(0,'ScreenSize');
   curr_ini = find_inisettings;
else;
   editfig = findobj('Type','figure','Tag','FigEdit');
   if isempty(editfig)==0;
      editgraph = get(editfig,'UserData');
      fe = get(editgraph.mytitle,'UserData');
   end;
end;

if nargin<2;
   simclick = [];
end;

%
% The various switch string options
%

switch selector
   case 'init'
      editfig = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','toolbar_edit_fcn.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-450)/2 (realscrsz(4)-530)/2 450 530], ...
         'Tag','FigEdit', ...
         'Resize','off', ...
         'Visible','off', ...
         'Name',['Axes Properties - ' get(fe.basefig,'Name')], ...
         'NumberTitle','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','toolbar_edit_fcn wayout', ...
         'Toolbar','none');

      if matlabnumber>=7.0;
         set(editfig,'DockControl','off');
      end;

      %
      % Title controls
      %

      editgraph.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[10 498 50 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight','bold', ...
         'Style','text', ...
         'String','Title:', ...
         'HorizontalAlignment','left', ...
         'Tag','TitleText');

      editgraph.mytitle = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[10 470 430 30], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable','on', ...
         'String',fe.myeditgraph(1).title, ...
         'Callback','toolbar_edit_fcn title', ...
         'HorizontalAlignment','center', ...
         'Tag','TitleEdit');

      %
      % settings up the tabs
      %

      input_var.fldnames = {'tab1' 'tab2' 'tab3'};
      input_var.tags = {'tab1' 'tab2' 'tab3'};
      input_var.strings = {'X Axis' 'Y Axis' 'Z Axis'};
      input_var.visible = {'on' 'on' z_show_enable};
      input_var.callbackstr = {'toolbar_edit_fcn tab' 'toolbar_edit_fcn tab' 'toolbar_edit_fcn tab'};
      cu_ini = find_inisettings;
      editgraph = tabbed_dialog(editgraph,cu_ini,[10 80 430 350],3,input_var,[76.4 74.4]);

      %
      % Setting up a properties frame
      %

      editgraph.axesbox = axesbox([24 94 402 322],'Properties',50,[0.5 1]);

      %
      % Label Controls
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[38 380 50 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'FontWeight','normal', ...
         'Style','text', ...
         'String','Label:', ...
         'HorizontalAlignment','left', ...
         'Tag','LabelText');

      editgraph.myxlabel = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[38 360 372 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable','on', ...
         'Visible','on', ...
         'String',fe.myeditgraph(1).xlabel, ...
         'Callback','toolbar_edit_fcn labels', ...
         'HorizontalAlignment','center', ...
         'Tag','XLabelEdit');

      editgraph.myylabel = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[38 360 372 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable','on', ...
         'Visible','off', ...
         'String',fe.myeditgraph(1).ylabel, ...
         'Callback','toolbar_edit_fcn labels', ...
         'HorizontalAlignment','center', ...
         'Tag','YLabelEdit');

      editgraph.myzlabel = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[38 360 372 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable','on', ...
         'Visible','off', ...
         'String',fe.myeditgraph(1).zlabel, ...
         'Callback','toolbar_edit_fcn labels', ...
         'HorizontalAlignment','center', ...
         'Tag','ZLabelEdit');

      %
      % Limit controls
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[38 320 50 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'FontWeight','normal', ...
         'Style','text', ...
         'String','Limits:', ...
         'HorizontalAlignment','left', ...
         'Tag','LimitText');

      editgraph.myxlimmode = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 300 90 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','checkbox', ...
         'Value',xlimmodevalue, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','toolbar_edit_fcn xlimmode', ...
         'HorizontalAlignment','left', ...
      	 'String','Manual limits', ...
      	 'Tag','XLimModeCheck');

      editgraph.myxlimlow = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[140 305 130 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',xlimenable, ...
         'Visible','on', ...
         'String',num2str(fe.myeditgraph(1).xlim(1,1)), ...
         'Callback','toolbar_edit_fcn limits', ...
         'HorizontalAlignment','center', ...
         'Tag','XLimitLowEdit');

      editgraph.myxlimhigh = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[280 305 130 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',xlimenable, ...
         'Visible','on', ...
         'String',num2str(fe.myeditgraph(1).xlim(1,2)), ...
         'Callback','toolbar_edit_fcn limits', ...
         'HorizontalAlignment','center', ...
         'Tag','XLimitHighEdit');



      editgraph.myylimmode = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 300 90 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','checkbox', ...
         'Value',ylimmodevalue, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn ylimmode', ...
         'HorizontalAlignment','left', ...
      	 'String','Manual limits', ...
      	 'Tag','YLimModeCheck');

      editgraph.myylimlow = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[140 305 130 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',ylimenable, ...
         'Visible','off', ...
         'String',num2str(fe.myeditgraph(1).ylim(1,1)), ...
         'Callback','toolbar_edit_fcn limits', ...
         'HorizontalAlignment','center', ...
         'Tag','YLimitLowEdit');

      editgraph.myylimhigh = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[280 305 130 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',ylimenable, ...
         'Visible','off', ...
         'String',num2str(fe.myeditgraph(1).ylim(1,2)), ...
         'Callback','toolbar_edit_fcn limits', ...
         'HorizontalAlignment','center', ...
         'Tag','YLimitHighEdit');



      editgraph.myzlimmode = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 300 90 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','checkbox', ...
         'Value',zlimmodevalue, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn zlimmode', ...
         'HorizontalAlignment','left', ...
      	 'String','Manual limits', ...
      	 'Tag','ZLimModeCheck');

      editgraph.myzlimlow = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[140 305 130 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',zlimenable, ...
         'Visible','off', ...
         'String',num2str(fe.myeditgraph(1).zlim(1,1)), ...
         'Callback','toolbar_edit_fcn limits', ...
         'HorizontalAlignment','center', ...
         'Tag','ZLimitLowEdit');

      editgraph.myzlimhigh = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[280 305 130 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',zlimenable, ...
         'Visible','off', ...
         'String',num2str(fe.myeditgraph(1).zlim(1,2)), ...
         'Callback','toolbar_edit_fcn limits', ...
         'HorizontalAlignment','center', ...
         'Tag','ZLimitHighEdit');

      %
      % Tick step controls
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[38 260 60 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'FontWeight','normal', ...
         'Style','text', ...
         'String','Tick step:', ...
         'HorizontalAlignment','left', ...
         'Tag','TickStepText');

      editgraph.myxtickmode = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 240 150 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','checkbox', ...
         'Value',xtickmodevalue, ...
         'Enable','on', ...
         'Visible','on', ...
         'Callback','toolbar_edit_fcn tick', ...
         'HorizontalAlignment','right', ...
      	 'String','Manual spacing', ...
      	 'Tag','XTickModeCheck');

      editgraph.myxtick = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[140 245 270 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',xtickenable, ... 
         'String',xtickstr, ...
         'Visible','on', ...
         'Callback','toolbar_edit_fcn fixtick', ...
         'HorizontalAlignment','center', ...
         'Tag','XTickEdit');

      editgraph.myytickmode = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 240 150 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','checkbox', ...
         'Value',ytickmodevalue, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn tick', ...
         'HorizontalAlignment','right', ...
      	 'String','Manual spacing', ...
      	 'Tag','YTickModeCheck');

      editgraph.myytick = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[140 245 270 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',ytickenable, ...
         'String',ytickstr, ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn fixtick', ...
         'HorizontalAlignment','center', ...
         'Tag','YTickEdit');

      editgraph.myztickmode = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[38 240 150 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',ztickmodevalue, ...
         'Enable','on', ...
         'Callback','toolbar_edit_fcn tick', ...
         'HorizontalAlignment','right', ...
         'Visible','off', ...
         'String','Manual spacing', ...
         'Tag','ZTickModeCheck');

      editgraph.myztick = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'BackgroundColor',[1 1 1], ...
         'Position',[140 245 270 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','edit', ...
         'Enable',ztickenable, ...
         'String',ztickstr, ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn fixtick', ...
         'HorizontalAlignment','center', ...
         'Tag','ZTickEdit');

      %
      % scale controls
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[38 205 50 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'FontWeight','normal', ...
         'Style','text', ...
         'String','Scale:', ...
         'HorizontalAlignment','left', ...
         'Tag','ScaleText');


      editgraph.myxdirnormal = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',xdirvalue, ...
         'Enable','on', ...
         'Visible','on', ...
         'String','Normal', ...
         'Callback','toolbar_edit_fcn xdir', ...
         'HorizontalAlignment','left', ...
      	 'Tag','XDirNormalRaion');

      editgraph.myxdirreverse = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[38 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(xdirvalue-1), ...
         'Enable','on', ... 
         'Visible','on', ...
         'String','Reverse', ...
         'Callback','toolbar_edit_fcn xdir', ...
         'HorizontalAlignment','left', ...
         'Tag','XDirReverseRadio');

      editgraph.myxscalelinear = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[165 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',xscalevalue, ...
         'Enable',xscaleenable, ...
         'String','Linear', ...
         'Visible','on', ...
         'Callback','toolbar_edit_fcn xscale', ...
         'HorizontalAlignment','left', ...
      	 'Tag','XScaleLinearRadio');

      editgraph.myxscalelog = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[165 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(xscalevalue-1), ...
         'Enable',xscaleenable, ... 
         'String','Logarithm', ...
         'Visible','on', ...
         'Callback','toolbar_edit_fcn xscale', ...
         'HorizontalAlignment','left', ...
         'Tag','XScaleLogRadio');

      editgraph.myxlocationtop = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[292 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',xlocvalue, ...
         'Enable',xlocenable, ...
         'String','Top', ...
         'Visible','on', ...
         'Callback','toolbar_edit_fcn xlocation', ...
         'HorizontalAlignment','left', ...
      	 'Tag','XLocationTopRadio');

      editgraph.myxlocationbottom = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[292 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(xlocvalue-1), ...
         'Enable',xlocenable, ... 
         'String','Bottom', ...
         'Visible','on', ...
         'Callback','toolbar_edit_fcn xlocation', ...
         'HorizontalAlignment','left', ...
         'Tag','XLocationBottomRadio');






      editgraph.myydirnormal = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',ydirvalue, ...
         'Enable','on', ...
         'String','Normal', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn ydir', ...
         'HorizontalAlignment','left', ...
      	 'Tag','YDirNormalRaion');

      editgraph.myydirreverse = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[38 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(ydirvalue-1), ...
         'Enable','on', ... 
         'String','Reverse', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn ydir', ...
         'HorizontalAlignment','left', ...
         'Tag','YDirReverseRadio');

      editgraph.myyscalelinear = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[165 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',yscalevalue, ...
         'Enable',yscaleenable, ...
         'String','Linear', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn yscale', ...
         'HorizontalAlignment','left', ...
      	 'Tag','YScaleLinearRadio');

      editgraph.myyscalelog = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[165 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(yscalevalue-1), ...
         'Enable',yscaleenable, ... 
         'String','Logarithm', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn yscale', ...
         'HorizontalAlignment','left', ...
         'Tag','YScaleLogRadio');

      editgraph.myylocationright = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[292 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',ylocvalue, ...
         'Enable',ylocenable, ...
         'String','Right', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn ylocation', ...
         'HorizontalAlignment','left', ...
      	 'Tag','YLocationRightRadio');

      editgraph.myylocationleft = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[292 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(ylocvalue-1), ...
         'Enable',ylocenable, ... 
         'String','Left', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn ylocation', ...
         'HorizontalAlignment','left', ...
         'Tag','YLocationLeftRadio');





      editgraph.myzdirnormal = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',zdirvalue, ...
         'Enable','on', ...
         'Visible','off', ...
         'String','Normal', ...
         'Callback','toolbar_edit_fcn zdir', ...
         'HorizontalAlignment','left', ...
      	 'Tag','ZDirNormalRaion');

      editgraph.myzdirreverse = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[38 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(zdirvalue-1), ...
         'Enable','on', ... 
         'Visible','off', ...
         'String','Reverse', ...
         'Callback','toolbar_edit_fcn zdir', ...
         'HorizontalAlignment','left', ...
         'Tag','ZDirReverseRadio');

      editgraph.myzscalelinear = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[225 185 117 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',zscalevalue, ...
         'Enable',zscaleenable, ...
         'Visible','off', ...
         'String','Linear', ...
         'Callback','toolbar_edit_fcn zscale', ...
         'HorizontalAlignment','left', ...
      	 'Tag','ZScaleLinearRadio');

      editgraph.myzscalelog = uicontrol('Units','pixels', ...
         'Parent',editfig, ...
         'Position',[225 165 117 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','radiobutton', ...
         'Value',abs(zscalevalue-1), ...
         'Enable',zscaleenable, ... 
         'Visible','off', ...
         'String','Logarithm', ...
         'Callback','toolbar_edit_fcn zscale', ...
         'HorizontalAlignment','left', ...
         'Tag','ZScaleLogRadio');

      %
      % Grid controls
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[38 130 50 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'FontWeight','normal', ...
         'Style','text', ...
         'String','Grid:', ...
         'HorizontalAlignment','left', ...
         'Tag','GridText');

      editgraph.myxgrid = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 110 200 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','checkbox', ...
         'Value',xgridvalue, ...
         'Enable','on', ...
         'Callback','toolbar_edit_fcn grid', ...
         'HorizontalAlignment','right', ...
      	 'String','Display vertical grid lines', ...
      	 'Tag','XGridCheck');

      editgraph.myygrid = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[38 110 200 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','checkbox', ...
         'Value',ygridvalue, ...
         'Enable','on', ...
         'Visible','off', ...
         'Callback','toolbar_edit_fcn grid', ...
         'HorizontalAlignment','right', ...
      	 'String','Display horizontal grid lines', ...
      	 'Tag','YGridCheck');

      editgraph.myzgrid = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[38 110 200 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','checkbox', ...
         'Value',zgridvalue, ...
         'Visible','off', ...
         'Enable','on', ...
         'Callback','toolbar_edit_fcn grid', ...
         'HorizontalAlignment','right', ...
         'String','Display depth grid lines', ...
         'Tag','ZGridCheck');

      %
      % Changing graph
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[16 40 100 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight','bold', ...
         'Style','text', ...
         'String','Select graph:', ...
         'Enable',axesenable, ...
         'HorizontalAlignment','left', ...
         'Tag','ChangeGraphText');

      editgraph.change = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[100 45 340 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable',axesenable, ...
         'Value',1, ...
         'String',fe.axestitle, ...
         'CallBack','toolbar_edit_fcn changes', ...
         'Tag','ChangeGraphPopup');

      %
      % OK button
      %

      editgraph.ok = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[205 14 75 20], ...
         'String','OK', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable','on', ...
         'Callback','toolbar_edit_fcn wayout', ...
         'Tag','OKButton');

      %
      % Cancel button
      %

      editgraph.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[285 14 75 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable','on', ...
         'Callback','toolbar_edit_fcn cancel', ...
         'Tag','CancelButton');

      %
      % Apply control
      %

      editgraph.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[365 14 75 20], ...
         'String','Apply', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Enable','off', ...
         'Callback','toolbar_edit_fcn apply', ...
         'Tag','CancelButton');

      set(editfig,'UserData',editgraph,...
         'HandleVisibility','callback');

   case 'tab'
      oldtab = get(editgraph.tab1,'UserData');
      if isempty(simclick)==1;
         newtab = get(gcbo,'Tag');
         newtab = strrep(newtab,'tab','');
         newtab = mystr2num(newtab);
      else;
         newtab = simclick;
      end;
      if abs(oldtab-newtab)>0;
         if (iswinxp==1)&(matlabnumber>=7);
            fixtabs(editgraph,oldtab,newtab);
         end;
         set(editgraph.tab1,'UserData',newtab);
         if newtab==1;
            set(editgraph.frame3tab1,'Visible','off');
            set(editgraph.frame3tab2,'Visible','on');
            set(editgraph.frame3tab3,'Visible','on');
            set(editgraph.frame1tab2,'Position',[86.4 420 74.4 11]);
            set(editgraph.frame1tab3,'Position',[161.8 420 74.4 11]);
            set(editgraph.tab1,'Position',[10 428 76.4 25]);
            set(editgraph.tab2,'Position',[86.4 428 74.4 23]);
            set(editgraph.tab3,'Position',[161.8 428 74.4 23]);
            set(editgraph.myxlabel,'Visible','on');
            set(editgraph.myylabel,'Visible','off');
            set(editgraph.myzlabel,'Visible','off');
            set(editgraph.myxlimmode,'Visible','on');
            set(editgraph.myxlimlow,'Visible','on');
            set(editgraph.myxlimhigh,'Visible','on');
            set(editgraph.myylimmode,'Visible','off');
            set(editgraph.myylimlow,'Visible','off');
            set(editgraph.myylimhigh,'Visible','off');
            set(editgraph.myzlimmode,'Visible','off');
            set(editgraph.myzlimlow,'Visible','off');
            set(editgraph.myzlimhigh,'Visible','off');
            set(editgraph.myxtickmode,'Visible','on');
            set(editgraph.myxtick,'Visible','on');
            set(editgraph.myytickmode,'Visible','off');
            set(editgraph.myytick,'Visible','off');
            set(editgraph.myztickmode,'Visible','off');
            set(editgraph.myztick,'Visible','off');
            set(editgraph.myxdirnormal,'Visible','on');
            set(editgraph.myxdirreverse,'Visible','on');
            set(editgraph.myxscalelinear,'Visible','on');
            set(editgraph.myxscalelog,'Visible','on');
            set(editgraph.myxlocationtop,'Visible','on');
            set(editgraph.myxlocationbottom,'Visible','on');
            set(editgraph.myydirnormal,'Visible','off');
            set(editgraph.myydirreverse,'Visible','off');
            set(editgraph.myyscalelinear,'Visible','off');
            set(editgraph.myyscalelog,'Visible','off');
            set(editgraph.myylocationright,'Visible','off');
            set(editgraph.myylocationleft,'Visible','off');
            set(editgraph.myzdirnormal,'Visible','off');
            set(editgraph.myzdirreverse,'Visible','off');
            set(editgraph.myzscalelinear,'Visible','off');
            set(editgraph.myzscalelog,'Visible','off');
            set(editgraph.myxgrid,'Visible','on');
            set(editgraph.myygrid,'Visible','off');
            set(editgraph.myzgrid,'Visible','off');
         elseif newtab==2;
            set(editgraph.frame3tab1,'Visible','on');
            set(editgraph.frame3tab2,'Visible','off');
            set(editgraph.frame3tab3,'Visible','on');
            set(editgraph.frame1tab2,'Position',[85.4 420 76.4 11]);
            set(editgraph.frame1tab3,'Position',[161.8 420 74.4 11]);
            set(editgraph.tab1,'Position',[11 428 74.4 23]);
            set(editgraph.tab2,'Position',[85.4 428 76.4 25]);
            set(editgraph.tab3,'Position',[161.8 428 74.4 23]);
            set(editgraph.myxlabel,'Visible','off');
            set(editgraph.myylabel,'Visible','on');
            set(editgraph.myzlabel,'Visible','off');
            set(editgraph.myxlimmode,'Visible','off');
            set(editgraph.myxlimlow,'Visible','off');
            set(editgraph.myxlimhigh,'Visible','off');
            set(editgraph.myylimmode,'Visible','on');
            set(editgraph.myylimlow,'Visible','on');
            set(editgraph.myylimhigh,'Visible','on');
            set(editgraph.myzlimmode,'Visible','off');
            set(editgraph.myzlimlow,'Visible','off');
            set(editgraph.myzlimhigh,'Visible','off');
            set(editgraph.myxtickmode,'Visible','off');
            set(editgraph.myxtick,'Visible','off');
            set(editgraph.myytickmode,'Visible','on');
            set(editgraph.myytick,'Visible','on');
            set(editgraph.myztickmode,'Visible','off');
            set(editgraph.myztick,'Visible','off');
            set(editgraph.myxdirnormal,'Visible','off');
            set(editgraph.myxdirreverse,'Visible','off');
            set(editgraph.myxscalelinear,'Visible','off');
            set(editgraph.myxscalelog,'Visible','off');
            set(editgraph.myxlocationtop,'Visible','off');
            set(editgraph.myxlocationbottom,'Visible','off');
            set(editgraph.myydirnormal,'Visible','on');
            set(editgraph.myydirreverse,'Visible','on');
            set(editgraph.myyscalelinear,'Visible','on');
            set(editgraph.myyscalelog,'Visible','on');
            set(editgraph.myylocationright,'Visible','on');
            set(editgraph.myylocationleft,'Visible','on');
            set(editgraph.myzdirnormal,'Visible','off');
            set(editgraph.myzdirreverse,'Visible','off');
            set(editgraph.myzscalelinear,'Visible','off');
            set(editgraph.myzscalelog,'Visible','off');
            set(editgraph.myxgrid,'Visible','off');
            set(editgraph.myygrid,'Visible','on');
            set(editgraph.myzgrid,'Visible','off');
         elseif newtab==3;
            set(editgraph.frame3tab1,'Visible','on');
            set(editgraph.frame3tab2,'Visible','on');
            set(editgraph.frame3tab3,'Visible','off');
            set(editgraph.frame1tab2,'Position',[86.4 420 74.4 11]);
            set(editgraph.frame1tab3,'Position',[160.8 420 76.4 11]);
            set(editgraph.tab1,'Position',[11 428 74.4 23]);
            set(editgraph.tab2,'Position',[86.4 428 74.4 23]);
            set(editgraph.tab3,'Position',[160.8 428 76.4 25]);
            set(editgraph.myxlabel,'Visible','off');
            set(editgraph.myylabel,'Visible','off');
            set(editgraph.myzlabel,'Visible','on');
            set(editgraph.myxlimmode,'Visible','off');
            set(editgraph.myxlimlow,'Visible','off');
            set(editgraph.myxlimhigh,'Visible','off');
            set(editgraph.myylimmode,'Visible','off');
            set(editgraph.myylimlow,'Visible','off');
            set(editgraph.myylimhigh,'Visible','off');
            set(editgraph.myzlimmode,'Visible','on');
            set(editgraph.myzlimlow,'Visible','on');
            set(editgraph.myzlimhigh,'Visible','on');
            set(editgraph.myxtickmode,'Visible','off');
            set(editgraph.myxtick,'Visible','off');
            set(editgraph.myytickmode,'Visible','off');
            set(editgraph.myytick,'Visible','off');
            set(editgraph.myztickmode,'Visible','on');
            set(editgraph.myztick,'Visible','on');
            set(editgraph.myxdirnormal,'Visible','off');
            set(editgraph.myxdirreverse,'Visible','off');
            set(editgraph.myxscalelinear,'Visible','off');
            set(editgraph.myxscalelog,'Visible','off');
            set(editgraph.myxlocationtop,'Visible','off');
            set(editgraph.myxlocationbottom,'Visible','off');
            set(editgraph.myydirnormal,'Visible','off');
            set(editgraph.myydirreverse,'Visible','off');
            set(editgraph.myyscalelinear,'Visible','off');
            set(editgraph.myyscalelog,'Visible','off');
            set(editgraph.myylocationright,'Visible','off');
            set(editgraph.myylocationleft,'Visible','off');
            set(editgraph.myzdirnormal,'Visible','on');
            set(editgraph.myzdirreverse,'Visible','on');
            set(editgraph.myzscalelinear,'Visible','on');
            set(editgraph.myzscalelog,'Visible','on');
            set(editgraph.myxgrid,'Visible','off');
            set(editgraph.myygrid,'Visible','off');
            set(editgraph.myzgrid,'Visible','on');
         end;
      end;
   case 'changes'
      changeval = get(editgraph.change,'Value');
      %
      % check if value has changed, then act accordingly
      %
      if abs(fe.axesvalue-changeval)>0;
         fe.axesvalue = changeval;
         fe.curraxes = fe.myaxes(1,changeval);
         if strcmp(fe.myeditgraph(fe.axesvalue).xgrid,'on')==1;
            xgridvalue = 1;
         else;
            xgridvalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).ygrid,'on')==1;
            ygridvalue = 1;
         else;
            ygridvalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).zgrid,'on')==1;
            zgridvalue = 1;
         else;
            zgridvalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).xdir,'normal')==1;
            xdirvalue = 1;
         else;
            xdirvalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).ydir,'normal')==1;
            ydirvalue = 1;
         else;
            ydirvalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).zdir,'normal')==1;
            zdirvalue = 1;
         else;
            zdirvalue = 0;
         end;
         %
         % scale value
         %
         if strcmp(fe.myeditgraph(fe.axesvalue).xscale,'linear')==1;
            xscalevalue = 1;
         else;
            xscalevalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).yscale,'linear')==1;
            yscalevalue = 1;
         else;
            yscalevalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).zscale,'linear')==1;
            zscalevalue = 1;
         else;
            zscalevalue = 0;
         end;
         if fe.myeditgraph(fe.axesvalue).xlim(1,1)<=0;
            xscaleenable = 'off';
         else;
            xscaleenable = 'on';
         end;
         if fe.myeditgraph(fe.axesvalue).ylim(1,1)<=0;
            yscaleenable = 'off';
         else;
            yscaleenable = 'on';
         end;
         if fe.myeditgraph(fe.axesvalue).zlim(1,1)<=0;
            zscaleenable = 'off';
         else;
            zscaleenable = 'on';
         end;
         %
         % axis locations
         %
         if strcmp(fe.myeditgraph(fe.axesvalue).xaxislocation,'top')==1;
            xlocvalue = 1;
         else;
            xlocvalue = 0;
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).yaxislocation,'right')==1;
            ylocvalue = 1;
         else;
            ylocvalue = 0;
         end;
         %
         if isempty(fe.myeditgraph(fe.axesvalue).surfhandles)==1;
            xlocenable = 'on';
            ylocenable = 'on';
            z_show_enable = 'off';
         else;
            xlocenable = 'off';
            ylocenable = 'off';
            z_show_enable = 'on';
         end;
         %
         % limit modes
         %
         if strcmp(fe.myeditgraph(fe.axesvalue).xlimmode,'auto')==1;
            xlimmodevalue = 0;
            xlimenable = 'off';
         else;
            xlimmodevalue = 1;
            xlimenable = 'on';
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).ylimmode,'auto')==1;
            ylimmodevalue = 0;
            ylimenable = 'off';
         else;
            ylimmodevalue = 1;
            ylimenable = 'on';
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).zlimmode,'auto')==1;
            zlimmodevalue = 0;
            zlimenable = 'off';
         else;
            zlimmodevalue = 1;
            zlimenable = 'on';
         end;
         %
         % Inserting values
         %
         set(editgraph.mytitle,'String',fe.myeditgraph(fe.axesvalue).title);
         set(editgraph.myxlabel,'String',fe.myeditgraph(fe.axesvalue).xlabel);
         set(editgraph.myylabel,'String',fe.myeditgraph(fe.axesvalue).ylabel);
         set(editgraph.myzlabel,'String',fe.myeditgraph(fe.axesvalue).zlabel);
         set(editgraph.myxlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,1)),'Enable',xlimenable);
         set(editgraph.myxlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,2)),'Enable',xlimenable);
         set(editgraph.myylimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,1)),'Enable',ylimenable);
         set(editgraph.myylimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,2)),'Enable',ylimenable);
         set(editgraph.myzlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,1)),'Enable',zlimenable);
         set(editgraph.myzlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,2)),'Enable',zlimenable);
         set(editgraph.myxgrid,'Value',xgridvalue);
         set(editgraph.myygrid,'Value',ygridvalue);
         set(editgraph.myzgrid,'Value',zgridvalue);
         set(editgraph.myxdirnormal,'Value',xdirvalue);
         set(editgraph.myxdirreverse,'Value',abs(xdirvalue-1));
         set(editgraph.myydirnormal,'Value',ydirvalue);
         set(editgraph.myydirreverse,'Value',abs(ydirvalue-1));
         set(editgraph.myzdirnormal,'Value',zdirvalue);
         set(editgraph.myzdirreverse,'Value',abs(zdirvalue-1));
         set(editgraph.myxlocationtop,'Value',xlocvalue,'Enable',xlocenable);
         set(editgraph.myxlocationbottom,'Value',abs(xlocvalue-1),'Enable',xlocenable);
         set(editgraph.myylocationright,'Value',ylocvalue,'Enable',ylocenable);
         set(editgraph.myylocationleft,'Value',abs(ylocvalue-1),'Enable',ylocenable);
         set(editgraph.myxlimmode,'Value',xlimmodevalue);
         set(editgraph.myylimmode,'Value',ylimmodevalue);
         set(editgraph.myzlimmode,'Value',zlimmodevalue);
         set(editgraph.myxscalelinear,'Value',xscalevalue,'Enable',xscaleenable);
         set(editgraph.myxscalelog,'Value',abs(xscalevalue-1),'Enable',xscaleenable);
         set(editgraph.myyscalelinear,'Value',yscalevalue,'Enable',yscaleenable);
         set(editgraph.myyscalelog,'Value',abs(yscalevalue-1),'Enable',yscaleenable);
         set(editgraph.myzscalelinear,'Value',zscalevalue,'Enable',zscaleenable);
         set(editgraph.myzscalelog,'Value',abs(zscalevalue-1),'Enable',zscaleenable);
         set(editgraph.tab3,'Visible',z_show_enable);
         %
         % Dealing with tick step defaults
         %
         if strcmp(fe.myeditgraph(fe.axesvalue).xtickmode,'manual')==1;
            xtickmodevalue = 1;
            xtickenable = 'on';
         else;
            xtickmodevalue = 0;
            xtickenable = 'off';
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).ytickmode,'manual')==1;
            ytickmodevalue = 1;
            ytickenable = 'on';
         else;
            ytickmodevalue = 0;
            ytickenable = 'off';
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).ztickmode,'manual')==1;
            ztickmodevalue = 1;
            ztickenable = 'on';
         else;
            ztickmodevalue = 0;
            ztickenable = 'off';
         end;
         if size(fe.myeditgraph(fe.axesvalue).xtick,2)>1;
            xtickstr = num2str((fe.myeditgraph(fe.axesvalue).xtick(1,2)-fe.myeditgraph(fe.axesvalue).xtick(1,1)));
         else;
            xtickstr = '';
         end;
         if size(fe.myeditgraph(fe.axesvalue).ytick,2)>1;
            ytickstr = num2str((fe.myeditgraph(fe.axesvalue).ytick(1,2)-fe.myeditgraph(fe.axesvalue).ytick(1,1)));
         else;
            ytickstr = '';
         end;
         if size(fe.myeditgraph(fe.axesvalue).ztick,2)>1;
            ztickstr = num2str((fe.myeditgraph(fe.axesvalue).ztick(1,2)-fe.myeditgraph(fe.axesvalue).ztick(1,1)));
         else;
            ztickstr = '';
         end;
         set(editgraph.myxtickmode,'Value',xtickmodevalue);
         set(editgraph.myxtick,'Enable',xtickenable);
         set(editgraph.myxtick,'String',xtickstr);
         set(editgraph.myytickmode,'Value',ytickmodevalue);
         set(editgraph.myytick,'Enable',ytickenable);
         set(editgraph.myytick,'String',ytickstr);
         set(editgraph.myztickmode,'Value',ztickmodevalue);
         set(editgraph.myztick,'Enable',ztickenable);
         set(editgraph.myztick,'String',ztickstr);
         set(editgraph.apply,'Enable',fe.myeditgraph(fe.axesvalue).applyenable);
         set(editgraph.mytitle,'UserData',fe);
         if get(editgraph.tab1,'UserData')==3;
            toolbar_edit_fcn('tab',1);
         end;
      end;
      set(editfig,'UserData',editgraph);
   case 'zlimmode'
      newvalue = get(editgraph.myzlimmode,'Value');
      if newvalue==0;
         z_lim_mode = 'auto';
         lim_enable = 'off';
      else;
         z_lim_mode = 'manual';
         lim_enable = 'on';
      end;
      set(editgraph.myzlimlow,'Enable',lim_enable);
      set(editgraph.myzlimhigh,'Enable',lim_enable);
      if strcmp(fe.myeditgraph(fe.axesvalue).zlimmode,z_lim_mode)==0;
         fe.myeditgraph(fe.axesvalue).zlimmode = z_lim_mode;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'ylimmode'
      newvalue = get(editgraph.myylimmode,'Value');
      if newvalue==0;
         y_lim_mode = 'auto';
         lim_enable = 'off';
      else;
         y_lim_mode = 'manual';
         lim_enable = 'on';
      end;
      set(editgraph.myylimlow,'Enable',lim_enable);
      set(editgraph.myylimhigh,'Enable',lim_enable);
      if strcmp(fe.myeditgraph(fe.axesvalue).ylimmode,y_lim_mode)==0;
         fe.myeditgraph(fe.axesvalue).ylimmode = y_lim_mode;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'xlimmode'
      newvalue = get(editgraph.myxlimmode,'Value');
      if newvalue==0;
         x_lim_mode = 'auto';
         lim_enable = 'off';
      else;
         x_lim_mode = 'manual';
         lim_enable = 'on';
      end;
      set(editgraph.myxlimlow,'Enable',lim_enable);
      set(editgraph.myxlimhigh,'Enable',lim_enable);
      if strcmp(fe.myeditgraph(fe.axesvalue).xlimmode,x_lim_mode)==0;
         fe.myeditgraph(fe.axesvalue).xlimmode = x_lim_mode;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'ylocation'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myylocationright;
         set(editgraph.myylocationleft,'Value',0);
         newvalue = 'right';
      else;
         set(editgraph.myylocationright,'Value',0);
         newvalue = 'left';
      end;
      if strcmp(newvalue,fe.myeditgraph(fe.axesvalue).yaxislocation)==0;
         fe.myeditgraph(fe.axesvalue).yaxislocation = newvalue;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'xlocation'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myxlocationtop;
         set(editgraph.myxlocationbottom,'Value',0);
         newvalue = 'top';
      else;
         set(editgraph.myxlocationtop,'Value',0);
         newvalue = 'bottom';
      end;
      if strcmp(newvalue,fe.myeditgraph(fe.axesvalue).xaxislocation)==0;
         fe.myeditgraph(fe.axesvalue).xaxislocation = newvalue;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'zdir'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myzdirnormal;
         set(editgraph.myzdirreverse,'Value',0);
         newdir = 'normal';
      else;
         set(editgraph.myzdirnormal,'Value',0);
         newdir = 'reverse';
      end;
      if strcmp(newdir,fe.myeditgraph(fe.axesvalue).zdir)==0;
         fe.myeditgraph(fe.axesvalue).zdir = newdir;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'ydir'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myydirnormal;
         set(editgraph.myydirreverse,'Value',0);
         newdir = 'normal';
      else;
         set(editgraph.myydirnormal,'Value',0);
         newdir = 'reverse';
      end;
      if strcmp(newdir,fe.myeditgraph(fe.axesvalue).ydir)==0;
         fe.myeditgraph(fe.axesvalue).ydir = newdir;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'xdir'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myxdirnormal;
         set(editgraph.myxdirreverse,'Value',0);
         newdir = 'normal';
      else;
         set(editgraph.myxdirnormal,'Value',0);
         newdir = 'reverse';
      end;
      if strcmp(newdir,fe.myeditgraph(fe.axesvalue).xdir)==0;
         fe.myeditgraph(fe.axesvalue).xdir = newdir;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'zscale'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myzscalelinear;
         set(editgraph.myzscalelog,'Value',0);
         newvalue = 'linear';
      else;
         set(editgraph.myzscalelinear,'Value',0);
         newvalue = 'log';
      end;
      if strcmp(newvalue,fe.myeditgraph(fe.axesvalue).zscale)==0;
         fe.myeditgraph(fe.axesvalue).zscale = newvalue;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'yscale'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myyscalelinear;
         set(editgraph.myyscalelog,'Value',0);
         newvalue = 'linear';
      else;
         set(editgraph.myyscalelinear,'Value',0);
         newvalue = 'log';
      end;
      if strcmp(newvalue,fe.myeditgraph(fe.axesvalue).yscale)==0;
         fe.myeditgraph(fe.axesvalue).yscale = newvalue;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'xscale'
      whichobj = gco;
      set(whichobj,'Value',1);
      if whichobj==editgraph.myxscalelinear;
         set(editgraph.myxscalelog,'Value',0);
         newvalue = 'linear';
      else;
         set(editgraph.myxscalelinear,'Value',0);
         newvalue = 'log';
      end;
      if strcmp(newvalue,fe.myeditgraph(fe.axesvalue).xscale)==0;
         fe.myeditgraph(fe.axesvalue).xscale = newvalue;
         set(editgraph.apply,'Enable','on');
         set(editgraph.mytitle,'UserData',fe);
      end;
   case 'labels'
      %
      % Checking the x-label
      %
      newxlabel = get(editgraph.myxlabel,'String');
      if isempty(newxlabel)==0;
         newxlabel = strtrim(newxlabel(1,:));
      end;
      if strcmp(fe.myeditgraph(fe.axesvalue).xlabel,newxlabel)==0;
         fe.myeditgraph(fe.axesvalue).xlabel = newxlabel;
         set(editgraph.apply,'Enable','on');
      end;
      %
      % Checking the y-label
      %
      newylabel = get(editgraph.myylabel,'String');
      if isempty(newylabel)==0;
         newylabel = strtrim(newylabel(1,:));
      end;
      if strcmp(fe.myeditgraph(fe.axesvalue).ylabel,newylabel)==0;
         fe.myeditgraph(fe.axesvalue).ylabel = newylabel;
         set(editgraph.apply,'Enable','on');
      end;
      %
      % checking the z-label
      %
      if isempty(fe.myeditgraph(fe.axesvalue).surfhandles)==0;
         newzlabel = get(editgraph.myzlabel,'String');
         if isempty(newzlabel)==0;
            newzlabel = strtrim(newzlabel(1,:));
         end;
         if strcmp(fe.myeditgraph(fe.axesvalue).zlabel,newzlabel)==0;
            fe.myeditgraph(fe.axesvalue).zlabel = newzlabel;
            set(editgraph.apply,'Enable','on');
         end;
      end;
      set(editgraph.mytitle,'UserData',fe);
      set(editfig,'UserData',editgraph);
   case 'limits'
      %
      % Checking x-limits
      %
      x1 = get(editgraph.myxlimlow,'String');
      if isempty(x1)==0;
         x1 = strtrim(x1(1,:));
         x1 = str2double(x1);
         x2 = get(editgraph.myxlimhigh,'String');
         x2 = strtrim(x2);
         x2 = str2double(x2(1,:));
         if (isnumeric(x1))&(isnumeric(x2));
            if x2>x1;
               if max(abs([x1 x2]-fe.myeditgraph(fe.axesvalue).xlim))>0;
                  fe.myeditgraph(fe.axesvalue).xlim = [x1 x2];
                  set(editgraph.myxlimlow,'String',num2str(x1));
                  set(editgraph.myxlimhigh,'String',num2str(x2));
                  set(editgraph.apply,'Enable','on');
               end;
            else;
               set(editgraph.myxlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,1)));
               set(editgraph.myxlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,2)));
            end;
         else;
            set(editgraph.myxlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,1)));
            set(editgraph.myxlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,2)));
         end;
      else;
         set(editgraph.myxlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,1)));
         set(editgraph.myxlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).xlim(1,2)));
      end;
      %
      % Checking y-limits
      %
      y1 = get(editgraph.myylimlow,'String');
      if isempty(y1)==0;
         y1 = strtrim(y1(1,:));
         y1 = str2double(y1);
         y2 = get(editgraph.myylimhigh,'String');
         y2 = strtrim(y2);
         y2 = str2double(y2(1,:));
         if (isnumeric(y1))&(isnumeric(y2));
            if y2>y1;
               if max(abs([y1 y2]-fe.myeditgraph(fe.axesvalue).ylim))>0;
                  fe.myeditgraph(fe.axesvalue).ylim = [y1 y2];
                  set(editgraph.myylimlow,'String',num2str(y1));
                  set(editgraph.myylimhigh,'String',num2str(y2));
                  set(editgraph.apply,'Enable','on');
               end;
            else;
               set(editgraph.myylimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,1)));
               set(editgraph.myylimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,2)));
            end;
         else;
            set(editgraph.myylimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,1)));
            set(editgraph.myylimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,2)));
         end;
      else;
         set(editgraph.myylimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,1)));
         set(editgraph.myylimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).ylim(1,2)));
      end;
      %
      % Checking z-limits
      %
      if isempty(fe.myeditgraph(fe.axesvalue).surfhandles)==0;
         z1 = get(editgraph.myzlimlow,'String');
         if isempty(z1)==0;
            z1 = strtrim(z1(1,:));
            z1 = str2double(z1);
            z2 = get(editgraph.myzlimhigh,'String');
            z2 = strtrim(z2);
            z2 = str2double(z2(1,:));
            if (isnumeric(z1))&(isnumeric(z2));
               if z2>z1;
                  if max(abs([z1 z2]-fe.myeditgraph(fe.axesvalue).zlim))>0;
                     fe.myeditgraph(fe.axesvalue).zlim = [z1 z2];
                     set(editgraph.myzlimlow,'String',num2str(z1));
                     set(editgraph.myzlimhigh,'String',num2str(z2));
                     set(editgraph.apply,'Enable','on');
                  end;
               else;
                  set(editgraph.myzlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,1)));
                  set(editgraph.myzlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,2)));
               end;
            else;
               set(editgraph.myzlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,1)));
               set(editgraph.myzlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,2)));
            end;
         else;
            set(editgraph.myzlimlow,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,1)));
            set(editgraph.myzlimhigh,'String',num2str(fe.myeditgraph(fe.axesvalue).zlim(1,2)));
         end;
      end;
      %
      if fe.myeditgraph(fe.axesvalue).xlim(1,1)<=0;
         set(editgraph.myxscalelinear,'Enable','off');
         set(editgraph.myxscalelog,'Enable','off');
      else;
         set(editgraph.myxscalelinear,'Enable','on');
         set(editgraph.myxscalelog,'Enable','on');
      end;
      %
      if fe.myeditgraph(fe.axesvalue).ylim(1,1)<=0;
         set(editgraph.myyscalelinear,'Enable','off');
         set(editgraph.myyscalelog,'Enable','off');
      else;
         set(editgraph.myyscalelinear,'Enable','on');
         set(editgraph.myyscalelog,'Enable','on');
      end;
      %
      if fe.myeditgraph(fe.axesvalue).zlim(1,1)<=0;
         set(editgraph.myzscalelinear,'Enable','off');
         set(editgraph.myzscalelog,'Enable','off');
      else;
         set(editgraph.myzscalelinear,'Enable','on');
         set(editgraph.myzscalelog,'Enable','on');
      end;
      %
      set(editgraph.mytitle,'UserData',fe);
      set(editfig,'UserData',editgraph);
      toolbar_edit_fcn('fixtick');
      %
      fe = get(editgraph.mytitle,'UserData');
      set(editgraph.mytitle,'UserData',fe);
   case 'title'
      newtitle = get(editgraph.mytitle,'String');
      if size(newtitle,1)>=1;
         newtitle = strtrim(newtitle(1,:));
         if strcmp(newtitle,fe.myeditgraph(fe.axesvalue).title)==0;
            fe.myeditgraph(fe.axesvalue).title = newtitle;
            set(editgraph.apply,'Enable','on');
         end;
      else;
         set(editgraph.mytitle,'String',fe.myeditgraph(fe.axesvalue).title);
      end;
      set(editgraph.mytitle,'UserData',fe);
      set(editfig,'UserData',editgraph);
   case 'tick'
      xtickmodevalue = get(editgraph.myxtickmode,'Value');
      ytickmodevalue = get(editgraph.myytickmode,'Value');
      if xtickmodevalue==1;
         set(editgraph.myxtick,'Enable','on');
         fe.myeditgraph(fe.axesvalue).xtickmode = 'manual';
      else;
         set(editgraph.myxtick,'Enable','off');
         fe.myeditgraph(fe.axesvalue).xtickmode = 'auto';
      end;
      if ytickmodevalue==1;
         set(editgraph.myytick,'Enable','on');
         fe.myeditgraph(fe.axesvalue).ytickmode = 'manual';
      else;
         set(editgraph.myytick,'Enable','off');
         fe.myeditgraph(fe.axesvalue).ytickmode = 'auto';
      end;
      if isempty(fe.myeditgraph(fe.axesvalue).surfhandles)==0;
         ztickmodevalue = get(editgraph.myztickmode,'Value');
         if ztickmodevalue==1;
            set(editgraph.myztick,'Enable','on');
            fe.myeditgraph(fe.axesvalue).ztickmode = 'manual';
         else;
            set(editgraph.myztick,'Enable','off');
            fe.myeditgraph(fe.axesvalue).ztickmode = 'auto';
         end;
      end;
      set(editgraph.mytitle,'UserData',fe);
      set(editgraph.apply,'Enable','on');
      set(editfig,'UserData',editgraph);
   case 'fixtick'
      newxtick = mystr2num(strtrim(get(editgraph.myxtick,'String')));
      newytick = mystr2num(strtrim(get(editgraph.myytick,'String')));
      if (isempty(newxtick)==1)|(newxtick<=0);
         if size(fe.myeditgraph(fe.axesvalue).xtick,2)>1;
            xtickstr = num2str((fe.myeditgraph(fe.axesvalue).xtick(1,2)-fe.myeditgraph(fe.axesvalue).xtick(1,1)));
         else;
            xtickstr = '';
         end;
         set(editgraph.myxtick,'String',xtickstr);
      else;
         newxlim = fe.myeditgraph(fe.axesvalue).xlim;
         if (newxlim(1,2)-newxlim(1,1))>newxtick;
            if newxtick<1;
               myloop = 'run';
               j = 1;
               check = newxtick;
               while strcmp(myloop,'run')==1;
                  check = 10*check;
                  if check>=1
                     myloop = 'done';
                     break;
                  else;
                     j = j+1;
                  end;
               end;
               newxvec = mystr2num(num2str(newxlim(1,1),['%0.' num2str(j) 'f']));
               if newxvec==newxlim(1,1);
                  newxvec = newxvec+newxtick;
               end;
            else;
               newxvec = ceil(newxlim(1,1));
            end;
            addxvec = newxvec;
            j = 2;
            while addxvec<newxlim(1,2);
               addxvec = newxvec(j-1)+newxtick;
               if addxvec<newxlim(1,2);
                  newxvec = [newxvec addxvec];
                  j = j+1;
               else;
                  break;
               end;
            end;
            fe.myeditgraph(fe.axesvalue).xtick = newxvec;
            set(editgraph.apply,'Enable','on');
         else;
            if size(fe.myeditgraph(fe.axesvalue).xtick,2)>1;
               xtickstr = num2str((fe.myeditgraph(fe.axesvalue).xtick(1,2)-fe.myeditgraph(fe.axesvalue).xtick(1,1)));
            else;
               xtickstr = '';
            end;
            set(editgraph.myxtick,'String',xtickstr);
         end;
      end;
      if (isempty(newytick)==1)|(newytick<=0);
         if size(fe.myeditgraph(fe.axesvalue).ytick,2)>1;
            ytickstr = num2str((fe.myeditgraph(fe.axesvalue).ytick(1,2)-fe.myeditgraph(fe.axesvalue).ytick(1,1)));
         else;
            ytickstr = '';
         end;
         set(editgraph.myytick,'String',ytickstr);
      else;
         newylim = fe.myeditgraph(fe.axesvalue).ylim;
         if (newylim(1,2)-newylim(1,1))>newytick;
            if newytick<1;
               myloop = 'run';
               j = 1;
               check = newytick;
               while strcmp(myloop,'run')==1;
                  check = 10*check;
                  if check>=1
                     myloop = 'done';
                     break;
                  else;
                     j = j+1;
                  end;
               end;
               newyvec = mystr2num(num2str(newylim(1,1),['%0.' num2str(j) 'f']));
%               if newyvec==newylim(1,1);
%                  newyvec = newyvec+newytick;
%               end;
            else;
               newyvec = ceil(newylim(1,1));
            end;
            addyvec = newyvec;
            j = 2;
%            while addyvec<newylim(1,2);
            while addyvec<=newylim(1,2);
               addyvec = newyvec(j-1)+newytick;
%               if addyvec<newylim(1,2);
               if addyvec<=newylim(1,2);
                  newyvec = [newyvec addyvec];
                  j = j+1;
               else;
                  break;
               end;
            end;
            fe.myeditgraph(fe.axesvalue).ytick = newyvec;
            set(editgraph.apply,'Enable','on');
         else;
            if size(fe.myeditgraph(fe.axesvalue).ytick,2)>1;
               ytickstr = num2str((fe.myeditgraph(fe.axesvalue).ytick(1,2)-fe.myeditgraph(fe.axesvalue).ytick(1,1)));
            else;
               ytickstr = '';
            end;
            set(editgraph.myytick,'String',ytickstr);
         end;
         set(editgraph.apply,'Enable','on');
      end;
      if isempty(fe.myeditgraph(fe.axesvalue).surfhandles)==0;
         newztick = mystr2num(strtrim(get(editgraph.myztick,'String')));
         if (isempty(newztick)==1)|(newztick<=0);
            if size(fe.myeditgraph(fe.axesvalue).ztick,2)>1;
               ztickstr = num2str((fe.myeditgraph(fe.axesvalue).ztick(1,2)-fe.myeditgraph(fe.axesvalue).ztick(1,1)));
            else;
               ztickstr = '';
            end;
            set(editgraph.myztick,'String',ztickstr);
         else;
            newzlim = fe.myeditgraph(fe.axesvalue).zlim;
            if (newzlim(1,2)-newzlim(1,1))>newztick;
               if newztick<1;
                  myloop = 'run';
                  j = 1;
                  check = newztick;
                  while strcmp(myloop,'run')==1;
                     check = 10*check;
                     if check>=1
                        myloop = 'done';
                        break;
                     else;
                        j = j+1;
                     end;
                  end;
                  newzvec = mystr2num(num2str(newzlim(1,1),['%0.' num2str(j) 'f']));
                  if newzvec==newzlim(1,1);
                     newzvec = newzvec+newztick;
                  end;
               else;
                  newzvec = ceil(newzlim(1,1));
               end;
               addzvec = newzvec;
               j = 2;
               while addzvec<newzlim(1,2);
                  addzvec = newzvec(j-1)+newztick;
                  if addzvec<newzlim(1,2);
                     newzvec = [newzvec addzvec];
                     j = j+1;
                  else;
                     break;
                  end;
               end;
               fe.myeditgraph(fe.axesvalue).ztick = newzvec;
               set(editgraph.apply,'Enable','on');
            else;
               if size(fe.myeditgraph(fe.axesvalue).ztick,2)>1;
                  ztickstr = num2str((fe.myeditgraph(fe.axesvalue).ztick(1,2)-fe.myeditgraph(fe.axesvalue).ztick(1,1)));
               else;
                  ztickstr = '';
               end;
               set(editgraph.myytick,'String',ztickstr);
            end;
            set(editgraph.apply,'Enable','on');
         end;
      end;
      set(editgraph.mytitle,'UserData',fe);
      set(editfig,'UserData',editgraph);
   case 'grid'
      xgridvalue = get(editgraph.myxgrid,'Value');
      ygridvalue = get(editgraph.myygrid,'Value');
      if xgridvalue==1;
         fe.myeditgraph(fe.axesvalue).xgrid = 'on';
      else;
         fe.myeditgraph(fe.axesvalue).xgrid = 'off';
      end;
      if ygridvalue==1;
         fe.myeditgraph(fe.axesvalue).ygrid = 'on';
      else;
         fe.myeditgraph(fe.axesvalue).ygrid = 'off';
      end;
      if isempty(fe.myeditgraph(fe.axesvalue).surfhandles)==0;
         zgridvalue = get(editgraph.myzgrid,'Value');
         if zgridvalue==1;
            fe.myeditgraph(fe.axesvalue).zgrid = 'on';
         else;
            fe.myeditgraph(fe.axesvalue).zgrid = 'off';
         end;
      end;
      set(editgraph.apply,'Enable','on');
      set(editgraph.mytitle,'UserData',fe);
      set(editfig,'UserData',editgraph);
   case 'apply'
      fe.axesvalue = get(editgraph.change,'Value');
      %
      % find lines which represent zero axes lines
      %
      linehandles = sort(findobj(fe.curraxes,'Type','line')');
      xlines = [];
      ylines = [];
      if isempty(linehandles)==0;
         %
         % Find constant lines
         %
         for j=1:size(linehandles,2);
            checkvecy = get(linehandles(1,j),'YData');
            checkvecx = get(linehandles(1,j),'XData');
            if checkvecx==zeros(size(checkvecx,1),1);
               xlines = [xlines linehandles(1,j)];
            elseif checkvecy==zeros(size(checkvecy,1),1);
               ylines = [ylines linehandles(1,j)];
            elseif (min(checkvecx)==max(checkvecx))&(isempty(get(linehandles(1,j),'ZData'))==1);
               xlines = [xlines linehandles(1,j)];
            elseif (min(checkvecy)==max(checkvecy))&(isempty(get(linehandles(1,j),'ZData'))==1);
               ylines = [ylines linehandles(1,j)];
            end;
         end;
      end;
      set(fe.curraxes,'XLimMode','auto');
      set(fe.curraxes,'YLimMode','auto');
      set(fe.curraxes,'ZLimMode','auto');
      set(fe.curraxes,'XScale',fe.myeditgraph(fe.axesvalue).xscale);
      set(fe.curraxes,'YScale',fe.myeditgraph(fe.axesvalue).yscale);
      set(fe.curraxes,'ZScale',fe.myeditgraph(fe.axesvalue).zscale);
      %
      % Setting major axes objects
      %
      set(get(fe.curraxes,'Title'),'string',fe.myeditgraph(fe.axesvalue).title);
      set(get(fe.curraxes,'XLabel'),'string',fe.myeditgraph(fe.axesvalue).xlabel);
      set(get(fe.curraxes,'YLabel'),'string',fe.myeditgraph(fe.axesvalue).ylabel);
      set(get(fe.curraxes,'ZLabel'),'string',fe.myeditgraph(fe.axesvalue).zlabel);
      set(fe.curraxes,'XLimMode',fe.myeditgraph(fe.axesvalue).xlimmode);
      if strcmp(fe.myeditgraph(fe.axesvalue).xlimmode,'auto')==0;
         set(fe.curraxes,'XLim',fe.myeditgraph(fe.axesvalue).xlim);
      end;
      set(fe.curraxes,'YLimMode',fe.myeditgraph(fe.axesvalue).ylimmode);
      if strcmp(fe.myeditgraph(fe.axesvalue).ylimmode,'auto')==0;
         set(fe.curraxes,'YLim',fe.myeditgraph(fe.axesvalue).ylim);
      end;
      set(fe.curraxes,'ZLimMode',fe.myeditgraph(fe.axesvalue).zlimmode);
      if strcmp(fe.myeditgraph(fe.axesvalue).zlimmode,'auto')==0;
         set(fe.curraxes,'ZLim',fe.myeditgraph(fe.axesvalue).zlim);
      end;
      %
      set(fe.curraxes,'XGrid',fe.myeditgraph(fe.axesvalue).xgrid);
      set(fe.curraxes,'YGrid',fe.myeditgraph(fe.axesvalue).ygrid);
      set(fe.curraxes,'ZGrid',fe.myeditgraph(fe.axesvalue).zgrid);
      set(fe.curraxes,'XTick',fe.myeditgraph(fe.axesvalue).xtick);
      set(fe.curraxes,'YTick',fe.myeditgraph(fe.axesvalue).ytick);
      set(fe.curraxes,'ZTick',fe.myeditgraph(fe.axesvalue).ztick);
      set(fe.curraxes,'XTickMode',fe.myeditgraph(fe.axesvalue).xtickmode);
      set(fe.curraxes,'YTickMode',fe.myeditgraph(fe.axesvalue).ytickmode);
      set(fe.curraxes,'ZTickMode',fe.myeditgraph(fe.axesvalue).ztickmode);
      set(fe.curraxes,'XDir',fe.myeditgraph(fe.axesvalue).xdir);
      set(fe.curraxes,'YDir',fe.myeditgraph(fe.axesvalue).ydir);
      set(fe.curraxes,'ZDir',fe.myeditgraph(fe.axesvalue).zdir);
      set(fe.curraxes,'XAxisLocation',fe.myeditgraph(fe.axesvalue).xaxislocation);
      set(fe.curraxes,'YAxisLocation',fe.myeditgraph(fe.axesvalue).yaxislocation);
      %
      % making sure that correct spacings between ticks are shown on dialog
      %
      local_xtick = get(fe.curraxes,'XTick');
      local_ytick = get(fe.curraxes,'YTick');
      local_ztick = get(fe.curraxes,'ZTick');
      if size(local_xtick,2)>1;
         xtickstr = num2str((local_xtick(1,2)-local_xtick(1,1)));
      else;
         xtickstr = '';
      end;
      if size(local_ytick,2)>1;
         ytickstr = num2str((local_ytick(1,2)-local_ytick(1,1)));
      else;
         ytickstr = '';
      end;
      if size(local_ztick,2)>1;
         ztickstr = num2str((local_ztick(1,2)-local_ztick(1,1)));
      else;
         ztickstr = '';
      end;
      set(editgraph.myxtick,'String',xtickstr);
      set(editgraph.myytick,'String',ytickstr);
      set(editgraph.myztick,'String',ztickstr);
      %
      %
      x_lim = get(fe.curraxes,'XLim');
      y_lim = get(fe.curraxes,'YLim');
      z_lim = get(fe.curraxes,'ZLim');
      set(editgraph.myxlimlow,'String',num2str(x_lim(1,1)));
      set(editgraph.myxlimhigh,'String',num2str(x_lim(1,2)));
      fe.myeditgraph(fe.axesvalue).xlim = x_lim;
      set(editgraph.myylimlow,'String',num2str(y_lim(1,1)));
      set(editgraph.myylimhigh,'String',num2str(y_lim(1,2)));
      fe.myeditgraph(fe.axesvalue).ylim = y_lim;
      set(editgraph.myzlimlow,'String',num2str(z_lim(1,1)));
      set(editgraph.myzlimhigh,'String',num2str(z_lim(1,2)));
      fe.myeditgraph(fe.axesvalue).zlim = z_lim;
      %
      if fe.myeditgraph(fe.axesvalue).xlim(1,1)<=0;
         set(editgraph.myxscalelinear,'Enable','off');
         set(editgraph.myxscalelog,'Enable','off');
      else;
         set(editgraph.myxscalelinear,'Enable','on');
         set(editgraph.myxscalelog,'Enable','on');
      end;
      %
      if fe.myeditgraph(fe.axesvalue).ylim(1,1)<=0;
         set(editgraph.myyscalelinear,'Enable','off');
         set(editgraph.myyscalelog,'Enable','off');
      else;
         set(editgraph.myyscalelinear,'Enable','on');
         set(editgraph.myyscalelog,'Enable','on');
      end;
      %
      if fe.myeditgraph(fe.axesvalue).zlim(1,1)<=0;
         set(editgraph.myzscalelinear,'Enable','off');
         set(editgraph.myzscalelog,'Enable','off');
      else;
         set(editgraph.myzscalelinear,'Enable','on');
         set(editgraph.myzscalelog,'Enable','on');
      end;
      %
      %
      if isempty(ylines)==0;
         for j=1:size(ylines,2);
            y_data = get(ylines(1,j),'YData');
            y_data = [min(y_data) max(y_data)];
            set(ylines(1,j),'XData',x_lim','YData',y_data');
         end;
      end;
      %
      if isempty(xlines)==0;
         for j=1:size(xlines,2);
            x_data = get(xlines(1,j),'XData');
            x_data = [min(x_data) max(x_data)];
            set(xlines(1,j),'YData',y_lim','XData',x_data');
         end;
      end;
      %
      curr_ini = find_inisettings;
      if curr_ini.ytick==1;
         fixytix(fe.curraxes);
      end;
      if curr_ini.xtick==1;
         fixxtix(fe.curraxes);
      end;
      %
      set(editgraph.mytitle,'UserData',fe);
      set(editgraph.apply,'Enable','off');
      set(editfig,'UserData',editgraph);
   case 'cancel'
      fe.axesvalue = get(editgraph.change,'Value');
      %
      % Resetting current graph to original values
      %
      fe.myeditgraph(fe.axesvalue).title = fe.oldmyeditgraph(fe.axesvalue).title;
      fe.myeditgraph(fe.axesvalue).xlabel = fe.oldmyeditgraph(fe.axesvalue).xlabel;
      fe.myeditgraph(fe.axesvalue).ylabel = fe.oldmyeditgraph(fe.axesvalue).ylabel;
      fe.myeditgraph(fe.axesvalue).zlabel = fe.oldmyeditgraph(fe.axesvalue).zlabel;
      fe.myeditgraph(fe.axesvalue).xlim = fe.oldmyeditgraph(fe.axesvalue).xlim;
      fe.myeditgraph(fe.axesvalue).ylim = fe.oldmyeditgraph(fe.axesvalue).ylim;
      fe.myeditgraph(fe.axesvalue).zlim = fe.oldmyeditgraph(fe.axesvalue).zlim;
      fe.myeditgraph(fe.axesvalue).xlimmode = fe.oldmyeditgraph(fe.axesvalue).xlimmode;
      fe.myeditgraph(fe.axesvalue).ylimmode = fe.oldmyeditgraph(fe.axesvalue).ylimmode;
      fe.myeditgraph(fe.axesvalue).zlimmode = fe.oldmyeditgraph(fe.axesvalue).zlimmode;
      %
      fe.myeditgraph(fe.axesvalue).xgrid = fe.oldmyeditgraph(fe.axesvalue).xgrid;
      fe.myeditgraph(fe.axesvalue).ygrid = fe.oldmyeditgraph(fe.axesvalue).ygrid;
      fe.myeditgraph(fe.axesvalue).zgrid = fe.oldmyeditgraph(fe.axesvalue).zgrid;
      fe.myeditgraph(fe.axesvalue).xtickmode = fe.oldmyeditgraph(fe.axesvalue).xtickmode;
      fe.myeditgraph(fe.axesvalue).ytickmode = fe.oldmyeditgraph(fe.axesvalue).ytickmode;
      fe.myeditgraph(fe.axesvalue).ztickmode = fe.oldmyeditgraph(fe.axesvalue).ztickmode;
      fe.myeditgraph(fe.axesvalue).xtick = fe.oldmyeditgraph(fe.axesvalue).xtick;
      fe.myeditgraph(fe.axesvalue).ytick = fe.oldmyeditgraph(fe.axesvalue).ytick;
      fe.myeditgraph(fe.axesvalue).ztick = fe.oldmyeditgraph(fe.axesvalue).ztick;
      fe.myeditgraph(fe.axesvalue).xdir = fe.oldmyeditgraph(fe.axesvalue).xdir;
      fe.myeditgraph(fe.axesvalue).ydir = fe.oldmyeditgraph(fe.axesvalue).ydir;
      fe.myeditgraph(fe.axesvalue).zdir = fe.oldmyeditgraph(fe.axesvalue).zdir;
      %
      fe.myeditgraph(fe.axesvalue).xscale = fe.oldmyeditgraph(fe.axesvalue).xscale;
      fe.myeditgraph(fe.axesvalue).yscale = fe.oldmyeditgraph(fe.axesvalue).yscale;
      fe.myeditgraph(fe.axesvalue).zscale = fe.oldmyeditgraph(fe.axesvalue).zscale;
      %
      fe.myeditgraph(fe.axesvalue).xaxislocation = fe.oldmyeditgraph(fe.axesvalue).xaxislocation;
      fe.myeditgraph(fe.axesvalue).yaxislocation = fe.oldmyeditgraph(fe.axesvalue).yaxislocation;
      %
      % resetting controls with old values
      %
      set(editgraph.mytitle,'String',fe.oldmyeditgraph(fe.axesvalue).title);
      set(editgraph.myxlabel,'String',fe.oldmyeditgraph(fe.axesvalue).xlabel);
      set(editgraph.myylabel,'String',fe.oldmyeditgraph(fe.axesvalue).ylabel);
      set(editgraph.myzlabel,'String',fe.oldmyeditgraph(fe.axesvalue).zlabel);
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).xgrid,'on')==1;
         xgridvalue = 1;
      else;
         xgridvalue = 0;
      end;
      set(editgraph.myxgrid,'Value',xgridvalue);
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).ygrid,'on')==1;
         ygridvalue = 1;
      else;
         ygridvalue = 0;
      end;
      set(editgraph.myygrid,'Value',ygridvalue);
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).zgrid,'on')==1;
         zgridvalue = 1;
      else;
         zgridvalue = 0;
      end;
      set(editgraph.myzgrid,'Value',zgridvalue);
      %
      % Fixing the tick step controls
      %
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).xtickmode,'manual')==1;
         set(editgraph.myxtick,'Enable','on');
         set(editgraph.myxtickmode,'Value',1);
      else;
         set(editgraph.myxtick,'Enable','off');
         set(editgraph.myxtickmode,'Value',0);
      end;
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).ytickmode,'manual')==1;
         set(editgraph.myytick,'Enable','on');
         set(editgraph.myytickmode,'Value',1);
      else;
         set(editgraph.myytick,'Enable','off');
         set(editgraph.myytickmode,'Value',0);
      end;
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).ztickmode,'manual')==1;
         set(editgraph.myztick,'Enable','on');
         set(editgraph.myztickmode,'Value',1);
      else;
         set(editgraph.myztick,'Enable','off');
         set(editgraph.myztickmode,'Value',0);
      end;
      %
      if size(fe.oldmyeditgraph(fe.axesvalue).xtick,2)>1;
         xtickstr = num2str((fe.oldmyeditgraph(fe.axesvalue).xtick(1,2)-fe.oldmyeditgraph(fe.axesvalue).xtick(1,1)));
      else;
         xtickstr = '';
      end;
      if size(fe.oldmyeditgraph(fe.axesvalue).ytick,2)>1;
         ytickstr = num2str((fe.oldmyeditgraph(fe.axesvalue).ytick(1,2)-fe.oldmyeditgraph(fe.axesvalue).ytick(1,1)));
      else;
         ytickstr = '';
      end;
      if size(fe.oldmyeditgraph(fe.axesvalue).ztick,2)>1;
         ztickstr = num2str((fe.oldmyeditgraph(fe.axesvalue).ztick(1,2)-fe.oldmyeditgraph(fe.axesvalue).ztick(1,1)));
      else;
         ztickstr = '';
      end;
      set(editgraph.myxtick,'String',xtickstr);
      set(editgraph.myytick,'String',ytickstr);
      set(editgraph.myztick,'String',ztickstr);
      %
      %
      % direction values
      %
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).xdir,'normal')==1;
         xdirvalue = 1;
      else;
         xdirvalue = 0;
      end;
      set(editgraph.myxdirnormal,'Value',xdirvalue);
      set(editgraph.myxdirreverse,'Value',abs(xdirvalue-1));
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).ydir,'normal')==1;
         ydirvalue = 1;
      else;
         ydirvalue = 0;
      end;
      set(editgraph.myydirnormal,'Value',ydirvalue);
      set(editgraph.myydirreverse,'Value',abs(ydirvalue-1));
      if strcmp(fe.oldmyeditgraph(fe.axesvalue).zdir,'normal')==1;
         zdirvalue = 1;
      else;
         zdirvalue = 0;
      end;
      set(editgraph.myzdirnormal,'Value',zdirvalue);
      set(editgraph.myzdirreverse,'Value',abs(zdirvalue-1));
      %
      % axis locations
      %
      if strcmp(fe.myeditgraph(fe.axesvalue).xaxislocation,'top')==1;
         xlocvalue = 1;
      else;
         xlocvalue = 0;
      end;
      if strcmp(fe.myeditgraph(fe.axesvalue).yaxislocation,'right')==1;
         ylocvalue = 1;
      else;
         ylocvalue = 0;
      end;
      set(editgraph.myxlocationtop,'Value',xlocvalue);
      set(editgraph.myxlocationbottom,'Value',abs(xlocvalue-1));
      set(editgraph.myylocationright,'Value',ylocvalue);
      set(editgraph.myylocationleft,'Value',abs(ylocvalue-1));
      %
      % Limit modes
      %
      if strcmp(fe.myeditgraph(fe.axesvalue).xlimmode,'auto')==1;
         xlimmodevalue = 0;
         xlimenable = 'off';
      else;
         xlimmodevalue = 1;
         xlimenable = 'on';
      end;
      set(editgraph.myxlimmode,'Value',xlimmodevalue);
      set(editgraph.myxlimlow,'String',num2str(fe.oldmyeditgraph(fe.axesvalue).xlim(1,1)),'Enable',xlimenable);
      set(editgraph.myxlimhigh,'String',num2str(fe.oldmyeditgraph(fe.axesvalue).xlim(1,2)),'Enable',xlimenable);
      if strcmp(fe.myeditgraph(fe.axesvalue).ylimmode,'auto')==1;
         ylimmodevalue = 0;
         ylimenable = 'off';
      else;
         ylimmodevalue = 1;
         ylimenable = 'on';
      end;
      set(editgraph.myylimmode,'Value',ylimmodevalue);
      set(editgraph.myylimlow,'String',num2str(fe.oldmyeditgraph(fe.axesvalue).ylim(1,1)),'Enable',ylimenable);
      set(editgraph.myylimhigh,'String',num2str(fe.oldmyeditgraph(fe.axesvalue).ylim(1,2)),'Enable',ylimenable);
      if strcmp(fe.myeditgraph(fe.axesvalue).zlimmode,'auto')==1;
         zlimmodevalue = 0;
         zlimenable = 'off';
      else;
         zlimmodevalue = 1;
         zlimenable = 'on';
      end;
      set(editgraph.myzlimmode,'Value',zlimmodevalue);
      set(editgraph.myzlimlow,'String',num2str(fe.oldmyeditgraph(fe.axesvalue).zlim(1,1)),'Enable',zlimenable);
      set(editgraph.myzlimhigh,'String',num2str(fe.oldmyeditgraph(fe.axesvalue).zlim(1,2)),'Enable',zlimenable);
      %
      % scale variables
      %
      if fe.myeditgraph(fe.axesvalue).xlim(1,1)<=0;
         xscaleenable = 'off';
      else;
         xscaleenable = 'on';
      end;
      if fe.myeditgraph(fe.axesvalue).ylim(1,1)<=0;
         yscaleenable = 'off';
      else;
         yscaleenable = 'on';
      end;
      if fe.myeditgraph(fe.axesvalue).zlim(1,1)<=0;
         zscaleenable = 'off';
      else;
         zscaleenable = 'on';
      end;
      if strcmp(fe.myeditgraph(fe.axesvalue).xscale,'linear')==1;
         xscalevalue = 1;
      else;
         xscalevalue = 0;
      end;
      if strcmp(fe.myeditgraph(fe.axesvalue).yscale,'linear')==1;
         yscalevalue = 1;
      else;
         yscalevalue = 0;
      end;
      if strcmp(fe.myeditgraph(fe.axesvalue).zscale,'linear')==1;
         zscalevalue = 1;
      else;
         zscalevalue = 0;
      end;
      set(editgraph.myxscalelinear,'Value',xscalevalue,'Enable',xscaleenable);
      set(editgraph.myxscalelog,'Value',abs(xscalevalue-1),'Enable',xscaleenable);
      set(editgraph.myyscalelinear,'Value',yscalevalue,'Enable',yscaleenable);
      set(editgraph.myyscalelog,'Value',abs(yscalevalue-1),'Enable',yscaleenable);
      set(editgraph.myzscalelinear,'Value',zscalevalue,'Enable',zscaleenable);
      set(editgraph.myzscalelog,'Value',abs(zscalevalue-1),'Enable',zscaleenable);
      %
      % and that's all folks!
      %
      set(editgraph.mytitle,'UserData',fe);
      set(editfig,'UserData',editgraph);
      toolbar_edit_fcn('apply');
   case 'wayout'
      killguipid(editfig);
      drawnow;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(cu_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(editfig,'Name') ' ' fix_filepath([pwd '\icons\axesprop.ico'])];
      dos(prog);
      if (strcmp(cu_ini.pstoolsdir,'')==0)&(appexist([cu_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(editgraph.icon,'UserData',pid);
      end;
   end;
   set(editfig,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(editfig,'Name') ' 3'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(editgraph.ok);
   end;
end;

if strcmp(selector,'wayout')==0;
   fe.myeditgraph(fe.axesvalue).applyenable = get(editgraph.apply,'Enable');
   set(editgraph.mytitle,'UserData',fe);
end;

%
% end of toolbar_edit_fcn.m
%
