%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for bootstrapping the trace test    %
%          for the number of cointegration vectors               %
%                                                                %
%          Function: trace_bootstrap                             %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        July 5, 2006                     %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function trace_bootstrap(varargin)

%
% GUI for bootstrapping the LR trace distributions
%

selector = varargin{1};
if (nargin==0)|(strcmp(selector,'init')==1);
   tm = varargin{2};
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   selector = 'init';
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.trace_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = tm.T;
   rep = curr_ini.nRep;
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i);
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if strcmp(computer,'PCWIN')==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   if ((tm.q1+tm.q0==0)&(curr_ini.tracebart==1)&(tm.dd-tm.ds<2));
      tm.bc = 'bart-';
   else;
      tm.bc = '';
   end;
   if curr_ini.parametric==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(curr_ini.blocksize) '-'];
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
%      if tm.r<tm.n;
         view_enable = 'on';
%      else;
%         view_enable = 'off';
%      end;
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      trace_mat = load(full_mat);
      trace_results = trace_mat.trace_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      trace_results = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      mod_type = 'noconst';
      model_type = 'No Constant';
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      mod_type = 'resconst';
      model_type = 'Restricted Constant';
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      mod_type = 'const';
      model_type = 'Constant';
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      mod_type = 'restrend';
      model_type = 'Restricted Linear Trend';
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      mod_type = 'trend';
      model_type = 'Linear Trend';
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   %
   % check if file with bootstrapped residuals exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' tm.bc 'trace-data.mat']);
   if fileexist(epsfile)==1;
      boot_enable = 'on';;
   else;
      epsfile = '';
      testfile = '';
      boot_enable = 'off';
   end;
   %
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   trace_boot_gui = findobj('Type','figure','Tag','TraceBoot')';
   boot_trace = get(trace_boot_gui,'UserData');
   curr_ini = get(boot_trace.matfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   trace_boot_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','trace_bootstrap.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-385)/2 560 385], ...
         'Tag','TraceBoot', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Bootstrap Distributions for LR Trace Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','trace_bootstrap done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(trace_boot_gui,'DockControl','off');
   end;

   if strcmp(curr_ini.helpexe,'')==1;
      helpenable = 'off';
   else;
      helpenable = 'on';
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',trace_boot_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   boot_trace.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Bootstrap', ...
         'Callback','trace_bootstrap simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   boot_trace.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Separator','on', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','trace_bootstrap matfile', ...
         'Tag','MatFileMenu');

   boot_trace.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','trace_bootstrap summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   boot_trace.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','trace_bootstrap full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');

   if curr_ini.noprint==0;
      boot_trace.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','trace_bootstrap output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','SummaryMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   boot_trace.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','trace_bootstrap done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   boot_trace.filemenu = filemenu;

   %
   % Tools Menu
   %

   toolsmenu = uimenu('Parent',trace_boot_gui, ...
      'Label','&Tools', ...
      'Tag','ToolsMenu');

   boot_trace.probrankmenu = uimenu('Parent',toolsmenu, ...
         'Label','&Rank Probabilities...', ...
         'Callback','trace_bootstrap probrank', ...
         'Accelerator','P', ...
         'Enable','off', ...
         'Tag','ProbRankMenu');

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',trace_boot_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   boot_trace.bootstrapgraphmenu = uimenu('Parent',graphmenu, ...
         'Label','Graph &Bootstrap Sample', ...
         'Callback','trace_bootstrap display_bootstrap', ...
         'Accelerator','B', ...
         'UserData',testfile, ...
         'Enable',boot_enable, ...
         'Tag','BootstrapGraphMenu');

   boot_trace.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','trace_bootstrap display', ...
         'Separator','on', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   boot_trace.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','trace_bootstrap display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   %
   % Help Menu
   %

   helpmenu = uimenu('Parent',trace_boot_gui, ...
      'Label','&Help', ...
      'Tag','HelpMenu');

   boot_trace.helpmenu = uimenu('Parent',helpmenu, ...
         'Label','&Help Topics', ...
         'Callback','help_fcn(''bootstrapping'')', ...
         'Accelerator','H', ...
         'Enable',helpenable, ...
         'Tag','HelpMenu');

   %
   % The toolbar
   %

   boot_trace.toolbar = uitoolbar('Parent',trace_boot_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

   if (iswinxp==0)|(matlabnumber<7);
      xline([1 384 560],[0.5 1]);
   end;

   boot_trace.simulate = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Run Bootstrap', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','trace_bootstrap simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');


   boot_trace.matfilebutton = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','trace_bootstrap matfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   boot_trace.summary = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','trace_bootstrap summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   boot_trace.full = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','trace_bootstrap full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   boot_trace.probrank = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Rank Probabilities', ...
                      'CData',button_images.probrank, ...
                      'ClickedCallback','trace_bootstrap probrank', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','off', ...
                      'Tag','ProbRankButton');

   boot_trace.bootstrapgraph = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Graph Bootstrap Sample', ...
                      'CData',button_images.bootstrapsmall, ...
                      'ClickedCallback','trace_bootstrap display_bootstrap', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',epsfile, ...
                      'Clipping','on', ...
                      'Enable',boot_enable, ...
                      'Tag','ViewBootstrapButton');

   boot_trace.display = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','trace_bootstrap display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',trace_results, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   boot_trace.histogram = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','trace_bootstrap display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   boot_trace.help = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Help Topics', ...
                      'CData',button_images.help, ...
                      'ClickedCallback','help_fcn(''bootstrapping'')', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',helpenable, ...
                      'Tag','HelpButton');

   boot_trace.done = uipushtool('Parent',boot_trace.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','trace_bootstrap done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 370],'LR Trace Tests',75,[0.5 1]);

   %
   % GUI Header
   %

   if ((tm.q1+tm.q0==0)&(curr_ini.tracebart==1)&(tm.dd-tm.ds<2));
      header_txt = ['Bootstrap Bartlett Corrected LR Trace Tests (' model_type ')'];
   else;
      header_txt = ['Bootstrap LR Trace Tests (' model_type ')'];
   end;
   desc_txt = 'Select the type of bootstrap you wish to perform, the number of observations and replications. Press the "Run Bootstrap" button when you''re satisfied with your choices and wait for the computations to finish.';
   dialog_header_fcn([16 286 530 70],button_images.bootstrap,header_txt,desc_txt);

   %
   % Options
   %

   axesbox([16 110 155 160],'Options',35,[0.5 1]);

   boot_trace.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 235 130 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   boot_trace.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 215 130 20], ...
      'Value',1, ...
      'String','Show progress dialog', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   boot_trace.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 195 130 20], ...
      'Value',1, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   boot_trace.parametric = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 175 130 20], ...
      'Value',curr_ini.parametric, ...
      'String','Parametric bootstrap', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'Callback','trace_bootstrap fixobscontrol', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ParametricCheck');

   boot_trace.blocktext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[45 145 100 20], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Style','text', ...
      'HorizontalAlignment','left', ...
      'String','Block size:', ...
      'Enable','off', ...
      'Tag','BlockText');

   boot_trace.block = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[105 150 50 20], ...
      'Value',1, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Value',curr_ini.blocksize, ...
      'Enable','off', ...
      'Callback','trace_bootstrap check', ...
      'Tag','BlockPopup');
   
   if curr_ini.parametric==0;
      set(boot_trace.blocktext,'Enable','on');
      set(boot_trace.block,'Enable','on');
   end;

   boot_trace.bootstrap = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 125 130 20], ...
      'Value',curr_ini.reuse_bootstrap, ...
      'String','Reuse/save residuals', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ReuseBootstrapCheck');

   axesbox([185 110 361 160],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   boot_trace.obstext = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 229 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'HorizontalAlignment','left', ...
      'String','Number of observations:', ...
      'Tag','ObsText');

   boot_trace.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 234 168 20], ...
      'Value',1, ...
      'String',[num2str(my_T) '|100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000'], ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','trace_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','ObsPopup');

   if (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_trace.obstext,'Enable','on');
      set(boot_trace.obs,'Enable','on');
   end;

   %
   % number of replications
   %


   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 176.5 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   boot_trace.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 181.5 168 20], ...
      'Value',nRep_value, ...
      'String','99|999|1,999|2,999|3,999|4,999|9,999|19,999|29,999|39,999|49,999|99,999|199,999|299,999|399,999|499,999|999,999', ...
      'Style','popupmenu', ...
      'Callback','trace_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of cointegration relations
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 124 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'HorizontalAlignment','left', ...
      'String','Number of cointegration relations:', ...
      'Tag','CointText');

   r_str = '0';
   for i=1:tm.n;
      r_str = [r_str '|' num2str(i)];
   end;

   boot_trace.my_r = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 129 168 20], ...
      'Value',tm.r+1, ...
      'String',r_str, ...
      'Style','popupmenu', ...
      'UserData',tm.r, ...
      'Callback','trace_bootstrap check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CointPopup');

   %
   % Select interpolation function
   %

   axesbox([16 16 530 80],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 54 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   boot_trace.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 59 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','trace_bootstrap interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 29 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   boot_trace.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 34 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   boot_trace.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 64.5 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   boot_trace.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 44.5 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   boot_trace.pqplot = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 24.5 140 20], ...
      'Value',0, ...
      'String','P-value plots, etc.', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','PQPlotCheckbox');

   checktype = 0;
   if tm.q1>0;
      if (tm.deterselect(1,1)==1)|(tm.deterselect(1,3)==1);
         checktype = 1;
      end;
   end;

   if ((tm.dummies==0)&(tm.q0==0)&(tm.q1<12)&(tm.n<=12)&(checktype==0))|((tm.dummies==0)&(tm.q0>0)&(tm.q1==0));
      set(boot_trace.pqplot,'Enable','on');
   end;

   if tm.interpolate_value>=5;
      set(boot_trace.adaptive,'Enable','on');
   end;

   probrank_str = 'on';
   for i=0:tm.n;
      full_mat = '';
      if tm.const_model(1)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      elseif tm.const_model(2)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      elseif tm.const_model(3)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      elseif tm.const_model(4)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      elseif tm.const_model(5)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      end;
      if fileexist(full_mat)==0;
         probrank_str = 'off';
         break;
      end;
   end;
   set(boot_trace.probrank,'Enable',probrank_str);
   set(boot_trace.probrankmenu,'Enable',probrank_str);

   set(trace_boot_gui,'UserData',boot_trace,...
         'HandleVisibility','callback');

case 'probrank'
   set(trace_boot_gui,'Visible','off');
   drawnow;
   %
   if get(boot_trace.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_trace.block,'Value')) '-'];
   end;
   %
   % selecting weights for the different conditional distributions
   %
%   rw_dlg = rank_weights('init',tm);
%   rw = get(rw_dlg,'UserData');
%   t_m = get(rw.variables,'UserData');
%   action = t_m.action;
%   r_weights = t_m.r_weights;
%   killguipid(rw_dlg);
   %
   action = 'ok';
   if strcmp(action,'cancel')==0;
      %
      % now we can get to work
      %
      % 1. load all the data
      %
      my_T = get(boot_trace.obs,'UserData');
      rep = get(boot_trace.rep,'UserData');
      data_s = [];
      for i=0:tm.n;
         full_mat = '';
         if tm.const_model(1)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         a = load(full_mat);
         data_s(i+1).trace_sorted = a.trace_sorted;
         clear('a');
      end;
      %
      % 2. asymptotic critical values
      %
      res_asymp_times = [];
      if (tm.dummies==0)&(( (tm.q1+tm.q0==0)&(tm.n<=12) )|( (tm.n<=12)&(tm.q1>0)&(tm.q1<12)&(tm.q0==0)&((tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1)) )|( (tm.q1==0)&(tm.q0>0) ));
         res_asymp_times = zeros(tm.n,tm.n+1);
         if (tm.q1+tm.q0==0)&(tm.n<=12);
            my_cv = reverse(trace_quant(tm.n,tm.deterselect,tm.cbs));
         elseif (tm.n<=12)&(tm.q1>0)&(tm.q1<12)&(tm.q0==0)&((tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1));
            my_cv = reverse(trace_quant_exo(tm.n,tm.q1,tm.deterselect,tm.cbs));
         elseif (tm.q1==0)&(tm.q0>0);
            my_cv = trace_exoi0_dist(tm.n,tm.p,tm.pe,tm.q0,tm.cbs,tm.deterselect,tm.d,tm.beta,tm.S_01,tm.M_02,tm.M_12,tm.M_22,tm.Z0,tm.Z1,tm.Z2);
         end;
         %
         % record the number of times the bootrapped values are less than the asymptotic critical values
         %
         for i=1:tm.n;
            for j=1:tm.n+1;
               my_dist = data_s(j).trace_sorted(:,i);
               res_asymp_times(i,j) = size(my_dist(my_dist<=my_cv(i,1)),1);
            end;
         end;
         res_asymp_times = (1/(rep+1))*(res_asymp_times+1);
%         w_asymp_times = res_asymp_times .* (ones(tm.n,1)*r_weights);
%         w_asymp_times = w_asymp_times ./ (sum(w_asymp_times,2)*ones(1,tm.n+1));
      end;
      %
      % 3. bootstrapped critical values
      %
      res_boot_times = zeros(tm.n,tm.n+1);
      my_bcv = zeros(tm.n,1);
      for i=1:tm.n;
         val = floor((tm.cbs/100)*rep);
         my_bcv(i,1) = data_s(i).trace_sorted(val,i);
      end;
      %
      % record the number of times the bootrapped values are less than the bootstrapped critical values
      %
      for i=1:tm.n;
         for j=1:tm.n+1;
            my_dist = data_s(j).trace_sorted(:,i);
            res_boot_times(i,j) = size(my_dist(my_dist<=my_bcv(i,1)),1);
         end;
      end;
      res_boot_times = (1/(rep+1))*(res_boot_times+1);
%      w_boot_times = res_boot_times .* (ones(tm.n,1)*r_weights);
%      w_boot_times = w_boot_times ./ (sum(w_boot_times,2)*ones(1,tm.n+1));
      %
      % 4. observed test values
      %
      res_trace_times = zeros(tm.n,tm.n+1);
      %
      % record the number of times the bootrapped values are less than the observed trace test values
      %
      for i=1:tm.n;
         for j=1:tm.n+1;
            my_dist = data_s(j).trace_sorted(:,i);
            res_trace_times(i,j) = size(my_dist(my_dist<=tm.trace(i,1)),1);
         end;
      end;
      res_trace_times = (1/(rep+1))*(res_trace_times+1);
%      w_trace_times = res_trace_times .* (ones(tm.n,1)*r_weights);
%      w_trace_times = w_trace_times ./ (sum(w_trace_times,2)*ones(1,tm.n+1));
      %
      % setup text for displaying the results
      %
      if tm.const_model(2)==1;
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         my_mod = 'Linear trend';
      end;
      %
      txt = strvcat(' ','ESTIMATION OF RANK PROBABILITIES USING BOOTSTRAPPING','====================================================',' ');
      txt = strvcat(txt,['   Number of replications:         ' num2str(rep,'%0.0f')]);
      txt = strvcat(txt,['   Model:                          ' my_mod]);
      txt = strvcat(txt,['   Number of endogenous variables: ' num2str(tm.n,'%0.0f')]);
      if tm.q1+tm.q0>0;
         txt = strvcat(txt,['   Number of exogenous variables:  ' num2str(tm.q1+tm.q0,'%0.0f')]);
      end;
      txt = strvcat(txt,' ');
      my_fmt = [' %' num2str(5+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      for i=1:tm.n+1;
         my_fmt = [my_fmt '    %0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      end;
      my_fmt = [my_fmt ' \n'];
      add_stars = '***********************************************************************************';
      sp_str = spacestr(curr_ini.decimals-2);
      add_txt = ['     cv   ' sp_str '   r*=0'];
      for i=1:tm.n;
         add_txt = [add_txt '  ' sp_str '  r*=' num2str(i,'%0.0f')];
      end;
      if isempty(res_asymp_times)==0;
         txt = strvcat(txt,'Bootstrapped frequencies when simulated trace test is less than or equal',['to asymptotic ' num2str(tm.cbs,'%0.0f') '% critical value'],' ','               Prob(trace<=cv|r=r*)');
         txt = strvcat(txt,'               True Rank');
         txt = strvcat(txt,add_txt,sprintf(my_fmt,[my_cv res_asymp_times]'),' ');
         txt = strvcat(txt,add_stars,' ');
      end;
      %
      txt = strvcat(txt,'Bootstrapped frequencies when simulated trace test is less than or equal',['to bootstrapped ' num2str(tm.cbs,'%0.0f') '% critical value'],' ','               Prob(trace<=cv|r=r*)');
      txt = strvcat(txt,'               True Rank');
      txt = strvcat(txt,add_txt,sprintf(my_fmt,[my_bcv res_boot_times]'),' ');
      txt = strvcat(txt,add_stars,' ');
      %
      txt = strvcat(txt,'Bootstrapped frequencies when simulated trace test is less than or equal','to observed value',' ','               Prob(trace<=ov|r=r*)');
      txt = strvcat(txt,'               True Rank');
      txt = strvcat(txt,strrep(add_txt,' cv ',' ov '),sprintf(my_fmt,[tm.trace res_trace_times]'),' ');
      %
      % write to file
      %
      if tm.const_model(1)==1;
         file = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-rank-' tm.bc bootstyle num2str(tm.n) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         file = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-rank-' tm.bc bootstyle num2str(tm.n) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-rank-' tm.bc bootstyle num2str(tm.n) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-rank-' tm.bc bootstyle num2str(tm.n) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-rank-' tm.bc bootstyle num2str(tm.n) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      %
      realscrsz = get(0,'ScreenSize');
      ftxt = fopen(file,'wt');
      for i=1:size(txt,1);
         txt_str = deblank(txt(i,:));
         if strcmp(txt_str,'')==0;
            fprintf(ftxt,'%s \n',txt_str);
         else;
            fprintf(ftxt,'\n');
         end;
      end;
      fclose(ftxt);
      %
      prtgui = printgui('init',file,'Structural VAR - Rank Probabilities Summary',[(realscrsz(3)-(realscrsz(4)-80))/2 32 realscrsz(4)-80 realscrsz(4)-54],'Results',38);
      myprint = get(prtgui,'UserData');
      set(myprint.print,'UserData','done');
      killguipid(prtgui);
      %
      if fileexist(file)==1;
         delete_file_fcn(file);
      end;
   end;
   %
   set(trace_boot_gui,'Visible','on');
   drawnow;
case 'output'
   if curr_ini.texoutputformat>=2;
      file = strrep(lower(get(boot_trace.summarymenu,'UserData')),'.txt','.ltx');
      txt_str = readtext(file);
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'\\subsection*{Bootstrap Simulation of Trace Test} \n\n');
      for i=1:size(txt_str,2);
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fclose(fout);
   else;
      txt_str = readtext(lower(get(boot_trace.summarymenu,'UserData')));
      fout = fopen(tm.outputfile,'at');
      fprintf(fout,'                      Bootstrap Simulation of Trace Test\n                      ----------------------------------\n');
      for i=5:size(txt_str,2)-4;
         fprintf(fout,'%s\n',txt_str{i});
      end;
      fprintf(fout,'\n===============================================================================\n\n');
      fclose(fout);
   end;
case 'display_bootstrap'
   epsfile = get(boot_trace.bootstrapgraph,'UserData');
   testfile = get(boot_trace.bootstrapgraphmenu,'UserData');
   my_r = get(boot_trace.my_r,'UserData');
   my_T = get(boot_trace.obs,'UserData');
   rep = get(boot_trace.rep,'UserData');
   if rep<4999;
      answer = 'Yes';
   else;
      check_txt = ['Your bootstrap setup includes ' num2str(rep) ' draws of the residuals. With ' num2str(tm.n) ' series and ' num2str(my_T) ' observations, this yields ' num2str(rep*tm.n*my_T) ' observations. Are you sure you want to load that much data into memory?'];
      answer = query(check_txt,'warning',120,'Exit',500,'no');
   end;
   if strcmp(answer,'Yes')==1;
      if isempty(tm.bc)==1;
         add_bart = '';
      else;
         add_bart = ',bc';
      end;
      txt_str = '';
      for i=1:tm.n;
         txt_str = strvcat(txt_str,['LR_{tr' add_bart '}(' num2str(i-1) ';r=' num2str(my_r) ') =']);
      end;
      %
      if strcmp(get(boot_trace.my_r,'Enable'),'on')==1;
         mybeta = tm.beta(:,1:my_r);
      else;
         mybeta = tm.beta;
      end;
      set(trace_boot_gui,'Visible','off');
      drawnow;
      thisgraph = bootgraphdlg('init',tm,epsfile,testfile,txt_str,mybeta,rep,my_T,my_r);
      bootgraph = get(thisgraph,'UserData');
      set(bootgraph.show,'UserData','done');
      killguipid(thisgraph);
      set(trace_boot_gui,'Visible','on');
      drawnow;
   end;
case 'fixobscontrol'
   if get(boot_trace.parametric,'Value')==0;
      T_str = get(boot_trace.obs,'String');
      my_T = mystr2num(strtrim(T_str(get(boot_trace.obs,'Value'),:)));
      set(boot_trace.obs,'Value',1,'UserData',my_T,'Enable','off');
      set(boot_trace.obstext,'Enable','off');
   elseif (tm.q1+tm.q0==0)&(isempty(tm.deterfile)==1);
      set(boot_trace.obs,'Enable','on');
      set(boot_trace.obstext,'Enable','on');
   end;
   trace_bootstrap('check');
case 'interpolate'
   tm.interpolate_value = get(boot_trace.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(boot_trace.adaptive,'Enable','on');
   else;
      set(boot_trace.adaptive,'Enable','off','Value',0);
   end;
case 'matfile'
   trace_sorted = get(boot_trace.display,'UserData');
   rep = get(boot_trace.rep,'UserData');
   my_r = get(boot_trace.my_r,'UserData');
   my_T = get(boot_trace.obs,'UserData');
   my_const_model = get(boot_trace.displaymenu,'UserData');
   if get(boot_trace.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_trace.block,'Value')) '-'];
   end;
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'trace_sorted');
   end;
case 'check'
   T_str = get(boot_trace.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_trace.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_trace.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_trace.rep,'UserData',rep);
   my_r = get(boot_trace.my_r,'Value')-1;
   set(boot_trace.obs,'UserData',my_T);
   set(boot_trace.my_r,'UserData',my_r);
   if strcmp(get(boot_trace.my_r,'Enable'),'on')==1;
      tm.alpha = tm.S_01*tm.beta(:,1:my_r)*inverse(tm.beta(:,1:my_r)'*tm.S_11*tm.beta(:,1:my_r));
      if isempty(tm.Z2)==0;
         tm.Psi = tm.M_02*inverse(tm.M_22)-(tm.alpha*tm.beta(:,1:my_r)'*tm.M_12*inverse(tm.M_22));
         tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:my_r)'*tm.Z1)-(tm.Psi*tm.Z2);
      else;
         tm.Psi = [];
         tm.epsilon = tm.Z0-(tm.alpha*tm.beta(:,1:my_r)'*tm.Z1);
      end;
      tm.Omega = (1/tm.T)*tm.epsilon*tm.epsilon';
   end;
   if get(boot_trace.parametric,'Value')==1;
      bootstyle = '';
      set(boot_trace.blocktext,'Enable','off');
      set(boot_trace.block,'Enable','off','Value',1);
   else;
      if strcmp(get(boot_trace.block,'Enable'),'off')==1;
         set(boot_trace.blocktext,'Enable','on');
         set(boot_trace.block,'Enable','on','Value',curr_ini.blocksize);
      end;
      bootstyle = ['np' num2str(get(boot_trace.block,'Value')) '-'];
   end;
   %
   % adjusting the view text buttons
   %
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      mod_type = 'noconst';
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      mod_type = 'trend';
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      trace_mat = load(full_mat);
      trace_results = trace_mat.trace_sorted;
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
%      if my_r<tm.n;
         set(boot_trace.display,'Enable','on','UserData',trace_results);
         set(boot_trace.displaymenu,'Enable','on','UserData',tm.const_model);
         set(boot_trace.histogram,'Enable','on');
         set(boot_trace.histogrammenu,'Enable','on');
%      end;
      set(boot_trace.matfilebutton,'Enable','on');
      set(boot_trace.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
      set(boot_trace.display,'Enable','off','UserData',[]);
      set(boot_trace.displaymenu,'Enable','off','UserData',tm.const_model);
      set(boot_trace.histogram,'Enable','off');
      set(boot_trace.histogrammenu,'Enable','off');
      set(boot_trace.matfilebutton,'Enable','off');
      set(boot_trace.matfilemenu,'Enable','off');
   end;
   %
   % Checking if residuals file exists
   %
   epsfile = [curr_ini.simulatedir tm.modelfile '-' 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
   testfile = strrep(epsfile,'.mat',['-' tm.bc 'trace-data.mat']);
   %
   if (fileexist(epsfile)==1)&(fileexist(testfile)==1);
      set(boot_trace.bootstrapgraph,'Enable','on','UserData',epsfile);
      set(boot_trace.bootstrapgraphmenu,'Enable','on','UserData',testfile);
   else;
      set(boot_trace.bootstrapgraph,'Enable','off','UserData',[]);
      set(boot_trace.bootstrapgraphmenu,'Enable','off','UserData','');
   end;
   %
   set(boot_trace.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(boot_trace.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
%   if curr_ini.texoutputformat>=2;
%      summary_txt = strrep(summary_txt,'.txt','.ltx');
%   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   if curr_ini.noprint==0;
      set(boot_trace.output,'Enable',summary_enable);
   end;
   set(boot_trace.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(boot_trace.summary,'Enable',summary_enable);
   %
   probrank_str = 'on';
   for i=0:tm.n;
      full_mat = '';
      if tm.const_model(1)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      elseif tm.const_model(2)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      elseif tm.const_model(3)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      elseif tm.const_model(4)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      elseif tm.const_model(5)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      end;
      if fileexist(full_mat)==0;
         probrank_str = 'off';
         break;
      end;
   end;
   set(boot_trace.probrank,'Enable',probrank_str);
   set(boot_trace.probrankmenu,'Enable',probrank_str);
   %
   set(trace_boot_gui,'UserData',boot_trace);
case 'summary'
   set(trace_boot_gui,'Visible','off');
   drawnow;
   file = lower(get(boot_trace.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - LR Trace Tests Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(trace_boot_gui,'Visible','on');
   drawnow;
   set(trace_boot_gui,'UserData',boot_trace);
case 'full'
   set(trace_boot_gui,'Visible','off');
   drawnow;
   rep = get(boot_trace.rep,'UserData');
   full_mat = lower(get(boot_trace.fullmenu,'UserData'));
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   trace_mat = load(full_mat);
   my_data = [trace_mat.Number trace_mat.trace_sorted];
   prt_str = '%7.0f';
   txt_str = ' Number ';
   sp_str = spacestr(curr_ini.decimals-2);
   for i=2:size(my_data,2);
      prt_str = [prt_str '  %' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      if i-2<10;
         txt_str = [txt_str '     r=' num2str(i-2,'%0.0f') '  ' sp_str];
      else;
         txt_str = [txt_str '     r=' num2str(i-2,'%0.0f') ' ' sp_str];
      end;
   end;
   txt_str = strvcat(' ',txt_str,' ');
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      txt_str = strvcat(txt_str,sprintf(prt_str,my_data(i,:)'));
   end;
   txt_str = strvcat(txt_str,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(txt_str,'Structural VAR - LR Trace Tests Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(trace_boot_gui,'Visible','on');
   drawnow;
   set(trace_boot_gui,'UserData',boot_trace);
case 'display'
   trace_sorted = get(boot_trace.display,'UserData');
   %
   % need to fix the rest
   %
   rep = get(boot_trace.rep,'UserData');
   my_r = get(boot_trace.my_r,'UserData');
   my_T = get(boot_trace.obs,'UserData');
   my_const_model = get(boot_trace.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(boot_trace.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   if curr_ini.colors==1;
      col.vec_1 = [0 0 1];
      col.vec_2 = [1 0 0];
      col.vec_3 = [0 0.75 0];
      col.vec_4 = [1 0.5 0];
      col.vec_5 = [0 0.75 0.75];
      col.vec_6 = [0 0 0];
      col.vec_7 = (1/255)*[255 28 28];
      col.vec_8 = [0 1 0];
   else;
      col.vec_1 = [0 0 0];
      col.vec_2 = [0.7 0.7 0.7];
      col.vec_3 = [0.6 0.6 0.6];
      col.vec_4 = [0.5 0.5 0.5];
      col.vec_5 = [0.4 0.4 0.4];
      col.vec_6 = [0.3 0.3 0.3];
      col.vec_7 = [0.8 0.8 0.8];
      col.vec_8 = [0.2 0.2 0.2];
   end;
   trace_series = [];
   trace_table = [];
   if my_r<tm.n;
      if (tm.n<=12)&(tm.dummies==0)&(tm.q0==0)&((gcbo~=boot_trace.histogram)&(gcbo~=boot_trace.histogrammenu));
         %
         % constructing a series with trace tests which can be displayed
         % as the asymptotic distribution
         %
         if tm.deterselect==[1 0 0 0];
            %
            % unrestricted constant
            %
            if tm.q1==0;
               trace_table = trace_1_model;
            end;
         elseif tm.deterselect==[0 1 0 0];
            %
            % restricted constant
            %
            if tm.q1==0;
               trace_table = trace_2_model;
            elseif tm.q1<12;
               if strcmp(computer,'PCWIN')==1;
                  file = [pwd '\mat\trace.mat'];
               else;
                  file = [pwd '/mat/trace.mat'];
               end;
               a = load(file);
               trace_table = getfield(a,['trace_12_' num2str(tm.q1,'%0.0f') '_rc']);
            end;
         elseif tm.deterselect==[0 0 1 0];
            %
            % constant+linear trend
            %
            if tm.q1==0;
               trace_table = trace_3_model;
            end;
         elseif tm.deterselect==[0 0 0 1];
            %
            % constant+restricted linear trend
            %
            if tm.q1==0;
               trace_table = trace_4_model;
            elseif tm.q1<12;
               if strcmp(computer,'PCWIN')==1;
                  file = [pwd '\mat\trace.mat'];
               else;
                  file = [pwd '/mat/trace.mat'];
               end;
               a = load(file);
               trace_table = getfield(a,['trace_12_' num2str(tm.q1,'%0.0f') '_rt']);
            end;
         end;
         if isempty(trace_table)==0;
            rand('state',sum(100*clock));
            %
            new_trace = rand(10000+50,1);
            new_trace = sort(new_trace(51:10000+50,:));
            trace_quant_var = quantiles_fcn;
            trace_series = zeros(10000,1);
            for i=1:10000;
               for j=1:220;
                  if new_trace(i,1)<=trace_quant_var(j,1);
                     trace_series(i,1) = trace_table(j,tm.n-my_r);
                     break;
                  elseif j==220;
                     trace_series(i,1) = trace_table(221,tm.n-my_r);
                  end;
               end;
            end;
            if get(boot_trace.pqplot,'Value')==1;
               %
               % computations for p-value plots
               %
               test_sorted = trace_sorted(:,my_r+1);
               if tm.q1==0;
                  edf_p_values = trace_pvalue(tm.n-my_r,test_sorted,tm.deterselect);
               else;
                  edf_p_values = trace_pvalue_exo(tm.n-my_r,tm.q1,test_sorted,tm.deterselect);
               end;
               p_series = zeros(221,1);
               pp_series = zeros(221,1);
               qq_series = zeros(221,1);
               for num=1:221;
                  p_num = edf_p_values(edf_p_values<=trace_quant_var(num,1));
                  p_series(num,1) = size(p_num,1)/rep;   
                  pp_num = test_sorted(test_sorted<=trace_table(num,tm.n-my_r));
                  pp_series(num,1) = size(pp_num,1)/rep;
                  qq_series(num,1) = test_sorted(ceil(trace_quant_var(num,1)*rep),1);
               end;
               clear('test_sorted');
               trace_table = trace_table(:,tm.n-my_r);
               %
      %         [t1,t2] = hist(trace_series,numcells);
      %         t1 = t1/10000;
            end;
         end;
      elseif (tm.dummies==0)&(tm.q1==0)&(tm.q0>0)&(gcbo~=boot_trace.histogram)&(gcbo~=boot_trace.histogrammenu);
         %
         % create trace table
         %
         trace_table = trace_exoi0_quant(tm.n,tm.p,tm.pe,tm.q0,quantiles_fcn,my_r,tm.deterselect,tm.d,tm.beta,tm.S_01,tm.M_02,tm.M_12,tm.M_22,tm.Z0,tm.Z1,tm.Z2);
         if isempty(trace_table)==0;
            rand('state',sum(100*clock));
            %
            new_trace = rand(10000+50,1);
            new_trace = sort(new_trace(51:10000+50,:));
            trace_quant_var = quantiles_fcn;
            trace_series = zeros(10000,1);
            for i=1:10000;
               for j=1:220;
                  if new_trace(i,1)<=trace_quant_var(j,1);
                     trace_series(i,1) = trace_table(j,1);
                     break;
                  elseif j==220;
                     trace_series(i,1) = trace_table(221,1);
                  end;
               end;
            end;
            %
            % handling p-value plots
            %
            if get(boot_trace.pqplot,'Value')==1;
               %
               % computations for p-value plots
               %
               test_sorted = trace_sorted(:,my_r+1);
               edf_p_values = trace_pvalue_exoi0(tm.n,tm.p,tm.pe,tm.q0,test_sorted,my_r,tm.deterselect,tm.d,tm.beta,tm.S_01,tm.M_02,tm.M_12,tm.M_22,tm.Z0,tm.Z1,tm.Z2);
               p_series = zeros(221,1);
               pp_series = zeros(221,1);
               qq_series = zeros(221,1);
               for num=1:221;
                  p_num = edf_p_values(edf_p_values<=trace_quant_var(num,1));
                  p_series(num,1) = size(p_num,1)/rep;   
                  pp_num = test_sorted(test_sorted<=trace_table(num,1));
                  pp_series(num,1) = size(pp_num,1)/rep;
                  qq_series(num,1) = test_sorted(ceil(trace_quant_var(num,1)*rep),1);
               end;
               clear('test_sorted');
               %
            end;
         end;
      end;
   end;
   if isempty(tm.bc)==1;
      add_name = '';
      add_title = '';
      short_name = '';
   else;
      add_name = 'Bartlett Corrected ';
      add_title = 'Bartlett corrected ';
      short_name = 'BC ';
   end;
   %
   pos = [((tm.realscrsz(3)-600)/2) ((tm.realscrsz(4)-400)/2)];
   %
   % 2x2 plots of p-value plot, p-value discrepancy plot,
   % pp plot, and qq plot
   %
   if my_r<tm.n;
      if (isempty(trace_table)==0)&(get(boot_trace.pqplot,'Value')==1);
         %
         % plotting p-value plots etc.
         %
         [pos,newplot] = pq_plot([(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2],['trace-' num2str(tm.n,'%0.0f') '.' num2str(my_r,'%0.0f') '-pqplot-'],['P-value and Quantile Plots for ' add_name 'LR Trace Test r=' num2str(my_r)],['P-value plot of ' short_name 'LR Trace Test'],['P-value discrepancy plot of ' short_name 'LR Trace Test'],['PP plot of ' short_name 'LR Trace Test'],['QQ plot of ' short_name 'LR Trace Test'],tm,trace_quant_var,trace_table,p_series,pp_series,qq_series,col);
      end;
      %
      % The trace test
      %
      [pos,thisplot] = dist_plot(pos,['trace-' num2str(tm.n,'%0.0f') '.' num2str(my_r,'%0.0f') '-plot-'],['Density for ' add_name 'LR Trace Test r=' num2str(my_r)],[add_title 'LR trace test for r<=' num2str(my_r) ' in a model with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors ' this_mod],tm,curr_ini,boot_trace,trace_sorted(:,my_r+1),trace_series,0,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,1);
   end;
   %
   % the other tests
   %
   add_plots = [];
   for i=1:tm.n;
      if i~=my_r+1;
         [pos,add_plot] = dist_plot(pos,['trace-' num2str(tm.n,'%0.0f') '.' num2str(i-1,'%0.0f') '-plot-'],['Density for ' add_name 'LR Trace Test r=' num2str(i-1)],[add_title 'LR trace test for r<=' num2str(i-1) ' in a model with ' num2str(tm.n) ' variables and ' num2str(my_r) ' cointegration vectors ' this_mod],tm,curr_ini,boot_trace,trace_sorted(:,i),[],0,0,0,col,my_80,my_90,my_95,my_975,my_99,numcells,1);
         add_plots = [add_plots add_plot];
      end;
   end;
   %
   if curr_ini.external==0;
      if my_r<tm.n;
         if (isempty(trace_table)==0)&(get(boot_trace.pqplot,'Value')==1);
            set(newplot,'Visible','on');
         end;
         set(thisplot,'Visible','on');
      end;
      if isempty(add_plots)==0;
         set(add_plots,'Visible','on');
      end;
   else;
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      if my_r<tm.n;
         if (gcbo==boot_trace.histogram)|(gcbo==boot_trace.histogrammenu);
            file1 = [curr_ini.simulatedir tm.modelfile '-trace-hist-boot-' num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         else;
            if (isempty(trace_table)==0)&(get(boot_trace.pqplot,'Value')==1);
               file = [curr_ini.simulatedir tm.modelfile '-trace-boot-pq-' num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
               set(0,'CurrentFigure',newplot);
               mstat = autosavefigure(newplot,file);
            end;
            file1 = [curr_ini.simulatedir tm.modelfile '-trace-boot-' num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         end;
         set(0,'CurrentFigure',thisplot);
         mstat1 = autosavefigure(thisplot,file1);
      end;
      add_stats = [];
      add_files = '';
      num = 1;
      for i=1:tm.n;
         if i~=my_r+1;
            if (gcbo==boot_trace.histogram)|(gcbo==boot_trace.histogrammenu);
               new_file = [curr_ini.simulatedir tm.modelfile '-trace-hist-boot-' num2str(tm.n) '.' num2str(i-1) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            else;
               new_file = [curr_ini.simulatedir tm.modelfile '-trace-boot-' num2str(tm.n) '.' num2str(i-1) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
            end;
            add_files = strvcat(add_files,new_file);
            set(0,'CurrentFigure',add_plots(1,num));
            add_stats = [add_stats;autosavefigure(add_plots(1,num),new_file)];
            num = num+1;
         end;
      end;
      %
      if my_r<tm.n;
         if isempty(trace_table)==0;
            if mstat==0;
               autoshowfigure(file);
            end;
         end;
         if mstat1==0;
            autoshowfigure(file1);
         end;
      end;
      for i=1:size(add_files,1);
         if add_stats(i,1)==0;
            autoshowfigure(strtrim(add_files(i,:)));
         end;
      end;
   end;
   set(trace_boot_gui,'UserData',boot_trace);
   %
   % case simulate
   %
case 'simulate'
   tm.trace_run = 1;
   set(trace_boot_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   T_str = get(boot_trace.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(boot_trace.obs,'Value'),:)));
   repvalues = [99 999 1999 2999 3999 4999 9999 19999 29999 39999 49999 99999 199999 299999 399999 499999 999999];
   rep_val = get(boot_trace.rep,'Value');
   rep = repvalues(rep_val);
   set(boot_trace.simulate,'UserData',rep);
   my_r = get(boot_trace.my_r,'Value')-1;
   if strcmp(get(boot_trace.my_r,'Enable'),'on')==1;
      mybeta = tm.beta(:,1:my_r);
   else;
      mybeta = tm.beta;
   end;
   blocksize = get(boot_trace.block,'Value');
   block_txt = '';
   if blocksize>1;
      block_txt = ['Applying block bootstrap with block length ' num2str(blocksize,'%0.0f') '...'];
   end;
   if get(boot_trace.parametric,'Value')==1;
      bootstyle = '';
   else;
      bootstyle = ['np' num2str(get(boot_trace.block,'Value')) '-'];
   end;
   %
   % initialize
   %
   trace_test = zeros(rep,size(tm.trace,1));
   if curr_ini.symmetric==0;
      Omega_sig = chol(tm.Omega)';
   else;
      Omega_sig = symm(tm.Omega);
   end;
   abort = '';
   draw = 1;
   showprog = get(boot_trace.progress,'Value');
   if showprog==1;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.clock = get(boot_trace.clock,'Value');
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      mywait = progressdlg(0,input_var);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   else;
      this_text = strvcat('Bootstrapping. The art of pulling oneself up by the bootstraps. Attempt started at...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','LR Trace Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      tic;
   end;
   if tm.const_model(2)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for LR trace test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'resconst';
   elseif tm.const_model(3)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for LR trace test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'const';
   elseif tm.const_model(4)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for LR trace test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'restrend';
   elseif tm.const_model(5)==1;
      setlogtext(strvcat(' ','Bootstrapping distribution for LR trace test...',block_txt,['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(tm.n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
      if showprog==1;
         set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
         drawnow;
      end;
      mod_type = 'trend';
   end;
   if get(boot_trace.bootstrap,'Value')==1;
      %
      % epsilon-file
      %
      epsfile = [curr_ini.simulatedir tm.modelfile '-' 'epsilon-' num2str(tm.scale_endo,'%0.4f') '-' bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '-' num2str(rep) '-' mod_type '.mat'];
      if fileexist(epsfile)==1;
         load_eps = 1;
         %
         % load old epsilons
         %
         eps_data = load(epsfile);
      else;
         load_eps = 0;
      end;
   else;
      load_eps = 0;
   end;
   %
   % replicating
   %
   while (draw<=rep);  % should be until rep
      if showprog==1;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(draw/rep) draw]);
         end;
      end;
      %
      % check for bootstrap style
      %
      if load_eps==0;
         if get(boot_trace.parametric,'Value')==1;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            %
            Epr = randn(tm.n,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Epr = Omega_sig*Epr;
         else;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               rand('state',draw);
            elseif curr_ini.random_state==3;
               rand('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               rand('state',sum(100*clock)+draw);
            end;
            %
            % resample from estimated epsilons
            %
            uni_draws = rand([1 my_T+50]);
            uni_draws = uni_draws(1,51:my_T+50);
            Epr = boot_draw(uni_draws,tm.epsilon,blocksize);
         end;
         if get(boot_trace.bootstrap,'Value')==1;
            bootstrap(draw).epsilon = Epr;
         end;
      else;
         Epr = eps_data.bootstrap(draw).epsilon;
      end;
      %
      % create new sample
      %
      boot = bootstrap_sample(tm,mybeta,Epr);
      %
      % Computing tests
      %
      bartcorr = [];
      [S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,lambda,trace_tst] = mlcointbasic(boot.Z0,boot.Z1,boot.Z2,tm.n);
      if ((tm.q1+tm.q0==0)&(curr_ini.tracebart==1)&(tm.dd-tm.ds<2));
         bartcorr = barttr(S_00,S_01,S_10,S_11,M_02,M_22,M_12,beta,tm.d,tm.p,my_T,tm.deterselect,[]);
         if min(bartcorr)<=0;
            new_bartcorr = [];
            num_nonzeros = 0;
            for i=1:size(bartcorr,1);
               if bartcorr(i,1)>0;
                  new_bartcorr = [new_bartcorr;bartcorr(i,1)];
                  num_nonzeros = num_nonzeros+1;
               else;
                  new_bartcorr = [new_bartcorr;0];
               end;
            end;
            av_bartcorr = (1/num_nonzeros)*sum(new_bartcorr);
            for i=1:size(bartcorr,1);
               if new_bartcorr(i,1)<=1.0e-016;
                  new_bartcorr(i,1) = av_bartcorr;
               end;
            end;
            bartcorr = new_bartcorr;
         end;
         trace_tst = trace_tst./bartcorr;
      end;
      trace_test(draw,:) = trace_tst';
      draw = draw+1;
   end;
   %
   % bootstrap has finished
   %
   if showprog==1;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   else;
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
      new_time = toc;
      my_hrs = '00';
      my_min = '00';
      my_sec = num2str(new_time,'%0.2f');
      if new_time>=60;
         ch_min = ceil(new_time/60);
         my_sec = num2str(new_time-(ch_min*60),'%0.2f');
         my_min = num2str(ch_min,'%0.0f');
         if ch_min>=60;
            ch_hrs = ceil(ch_min/60);
            my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
            my_hrs = num2str(ch_hrs,'%0.0f');
         end;
      end;
      if size(my_sec,2)==4;
         my_sec = ['0' my_sec];
      end;
      if size(my_min,2)==1;
         my_min = ['0' my_min];
      end;
      if size(my_hrs,2)==1;
         my_hrs = ['0' my_hrs];
      end;
      clock_str = [my_hrs ':' my_min ':' my_sec];
      this_text = strvcat('The bootstrapping process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
      about(this_text,'bootstrap','Simulation Time',120,350);
   end;
   %
   % if we don't cancel
   %
   if (strcmp(abort,'cancel')==0)&(isempty(trace_test)==0);
      this_text = strvcat(' ','Saving bootstrap results to disk...','Please hold!');
      mywait = waitdlg(this_text,'bootstrap','LR Trace Bootstrap Simulation');
      waitf = get(mywait,'UserData');
      if get(boot_trace.bootstrap,'Value')==1;
         if load_eps==0;
            this_text = strvcat(' ','Saving bootstrapped residuals to disk...','Please hold!');
            set(waitf.text,'String',this_text);
            save(epsfile,'bootstrap');
         end;
         clear('bootstrap');
         testfile = strrep(epsfile,'.mat',['-' tm.bc 'trace-data.mat']);
         test_data = trace_test;
         save(testfile,'test_data');
         clear('test_data');
         set(boot_trace.bootstrapgraph,'Enable','on','UserData',epsfile);
         set(boot_trace.bootstrapgraphmenu,'Enable','on','UserData',testfile);
      end;
      setlogtext(['Bootstrap simulation completed at: ' datestr(now,14) '!']);
      %
      % sort the test
      %
      trace_sorted = [];
      for i=1:tm.n;
         trace_sorted = [trace_sorted sort(trace_test(:,i))];
      end;
      set(boot_trace.rep,'UserData',rep);
      set(boot_trace.obs,'UserData',my_T);
      set(boot_trace.my_r,'UserData',my_r);
      set(boot_trace.displaymenu,'Enable','on','UserData',tm.const_model);
      if tm.const_model(2)==1;
         my_mod = 'Restricted constant';
      elseif tm.const_model(3)==1;
         my_mod = 'Constant';
      elseif tm.const_model(4)==1;
         my_mod = 'Restricted linear trend';
      elseif tm.const_model(5)==1;
         my_mod = 'Linear trend';
      end;
      %
      % save full simulations
      %
      if get(boot_trace.save,'Value')==1;
         this_text = strvcat(' ','Saving bootstrapped trace tests to disk...','Please hold!');
         set(waitf.text,'String',this_text);
         setlogtext('Saving results to mat-files...');
         if tm.const_model(1)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
         elseif tm.const_model(2)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
         elseif tm.const_model(3)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
         elseif tm.const_model(4)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
         elseif tm.const_model(5)==1;
            full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
         end;
         Number = (1:1:rep)';
         save(full_mat,'Number','trace_sorted');
         set(boot_trace.fullmenu,'Enable','on','UserData',full_mat);
         set(boot_trace.full,'Enable','on');
      end;
      setlogtext('Saving simulation summary to text file...');
      %
      % dealing with the size of the test
      %
      boot_size = [];
      boot_pval = [];
      if my_r<tm.n;
         if ((tm.n<=12)&(tm.dummies==0)&(tm.q0==0))|((tm.dummies==0)&(tm.q1==0)&(tm.q0>0));
            this_text = strvcat(' ','Determining the empirical size of the trace test...','Please hold!');
            set(waitf.text,'String',this_text);
            for j=1:5;
               if tm.q1+tm.q0==0;
                  my_cv = tracedist(tm.n,j,tm.deterselect);
               elseif (tm.q1>0)&(tm.q1<12)&(tm.q0==0)&((tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1));
                  my_cv = trace_exo_dist(tm.n,tm.q1,tm.deterselect,j);
               elseif (tm.q1==0)&(tm.q0>0);
                  my_cv = trace_exoi0_dist(tm.n,tm.p,tm.pe,tm.q0,j,tm.deterselect,tm.d,tm.beta,tm.S_01,tm.M_02,tm.M_12,tm.M_22,tm.Z0,tm.Z1,tm.Z2);
               else;
                  break;
               end;
               for i=1:rep;
                  if my_cv(my_r+1,1)>=trace_sorted(rep+1-i,my_r+1);
                     break;
                  end;
               end;
               if (i<rep)|(my_cv(my_r+1,1)>=trace_sorted(1,my_r+1));
                  boot_size = [boot_size (rep+1-i)/rep];
               else;
                  boot_size = [boot_size 0];
               end;
            end;
         end;
         %
         % bootstrap p-value
         %
         if tm.T==my_T
            this_text = strvcat(' ','Determining the empirical p-value...','Please hold!');
            set(waitf.text,'String',this_text);
            for i=1:rep;
               if tm.trace(my_r+1,1)>=trace_sorted(rep+1-i,my_r+1);
                  break;
               end;
            end;
            boot_pval = i/rep;
         end;
      end;
      %
      % dealing with power
      %
      boot_selrank = [];
      boot_power = [];
      boot_sizeadj_power = [];
      if (tm.n<=12)&(tm.dummies==0);
         this_text = strvcat(' ','Determining preferred cointegration rank and rejection frequencies...','Please hold!');
         set(waitf.text,'String',this_text);
      end;
      save_cv = [];
      for j=1:5;
         if ((tm.n<=12)&(tm.dummies==0)&(tm.q0==0))|((tm.dummies==0)&(tm.q1==0)&(tm.q0>0));
            if tm.q1+tm.q0==0;
               my_cv = tracedist(tm.n,j,tm.deterselect);
            elseif (tm.q1>0)&(tm.q1<12)&(tm.q0==0)&((tm.deterselect(1,2)==1)|(tm.deterselect(1,4)==1));
               my_cv = trace_exo_dist(tm.n,tm.q1,tm.deterselect,j);
            elseif (tm.q1==0)&(tm.q0>0);
               my_cv = trace_exoi0_dist(tm.n,tm.p,tm.pe,tm.q0,j,tm.deterselect,tm.d,tm.beta,tm.S_01,tm.M_02,tm.M_12,tm.M_22,tm.Z0,tm.Z1,tm.Z2);
            else;
               break;
            end;
            save_cv = [my_cv save_cv];
            boot_rank = [];
            for i=1:rep;
               for i1=1:tm.n;
                  if trace_test(i,i1)<=my_cv(i1,1);
                     boot_rank = [boot_rank;i1-1];
                     break;
                  elseif i1==tm.n;
                     boot_rank = [boot_rank;i1];
                  end;
               end;
            end;
            boot_rank = sort(boot_rank);
            boot_selrank_new = [];
            for i=0:tm.n;
               boot_selrank_new = [boot_selrank_new size(boot_rank(boot_rank==i),1)];
            end;
            boot_selrank = [boot_selrank;(1/rep)*boot_selrank_new];
            boot_power_new = [];
            %
            % i is actual rank
            %
            for i=0:tm.n-1;
               %
               % i1 is higher rank
               %
               big_rank = 0;
               for i1=i+1:tm.n;
                  big_rank = big_rank+size(boot_rank(boot_rank==i1),1);
               end;
               boot_power_new = [boot_power_new big_rank];
            end;
            boot_power = [boot_power;(1/rep)*boot_power_new];
         end;
      end;
      clear('trace_test');
      this_text = strvcat(' ','Writing bootstrap summary information to disk...','Please hold!');
      set(waitf.text,'String',this_text);
      %
      % write summary to file
      %
      sp_str = spacestr(curr_ini.decimals-2);
      prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      my_80 = floor(0.8*rep);
      my_90 = floor(0.9*rep);
      my_95 = floor(0.95*rep);
      my_975 = floor(0.98*rep);
      my_99 = floor(0.99*rep);
      res_str = strvcat(' ','**************************************************************','*                          Results                           *');
      res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(tm.n,'%0.0f')],['  Cointegration relations: ' num2str(my_r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
      if blocksize>1;
         res_str = strvcat(res_str,strrep(block_txt,'.',''),' ');
      end;
      for i=1:tm.n;
         res_str = strvcat(res_str,['                      LR Trace test for r<=' num2str(i-1,'%0.0f')],'                      ----------------------',' ',['    80%   ' sp_str '    90%   ' sp_str '    95%   ' sp_str '    98%   ' sp_str '    99%   ' sp_str '    Mean  ' sp_str '  Std. Dev.']);
         max_std = sqrt( (1/rep)*sum( ( trace_sorted(:,i) - ( (1/rep)*sum(trace_sorted(:,i)) ) ).*( trace_sorted(:,i) - ( (1/rep)*sum(trace_sorted(:,i)) ) ) ) );
         res_str = strvcat(res_str,sprintf([prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],trace_sorted(my_80,i),trace_sorted(my_90,i),trace_sorted(my_95,i),trace_sorted(my_975,i),trace_sorted(my_99,i),(1/rep)*sum(trace_sorted(:,i)),max_std),' ');
         %
         % include asymptotic quantiles, mean and std dev if known
         %
         if (isempty(save_cv)==0)&(my_r<tm.n)&(i-1==my_r);
            my_cv = save_cv(my_r+1,:)';
            trace_series = [];
            %
            % create trace_series variable containing 10,000 draws from the asymptotic distribution
            %
            if (tm.dummies==0)&(tm.q0==0);
               %
               % constructing a series with trace tests which can be displayed
               % as the asymptotic distribution
               %
               if tm.deterselect==[1 0 0 0];
                  %
                  % unrestricted constant
                  %
                  if tm.q1==0;
                     trace_table = trace_1_model;
                  end;
               elseif tm.deterselect==[0 1 0 0];
                  %
                  % restricted constant
                  %
                  if tm.q1==0;
                     trace_table = trace_2_model;
                  elseif tm.q1<12;
                     if strcmp(computer,'PCWIN')==1;
                        file = [pwd '\mat\trace.mat'];
                     else;
                        file = [pwd '/mat/trace.mat'];
                     end;
                     a = load(file);
                     trace_table = getfield(a,['trace_12_' num2str(tm.q1,'%0.0f') '_rc']);
                  end;
               elseif tm.deterselect==[0 0 1 0];
                  %
                  % constant+linear trend
                  %
                  if tm.q1==0;
                     trace_table = trace_3_model;
                  end;
               elseif tm.deterselect==[0 0 0 1];
                  %
                  % constant+restricted linear trend
                  %
                  if tm.q1==0;
                     trace_table = trace_4_model;
                  elseif tm.q1<12;
                     if strcmp(computer,'PCWIN')==1;
                        file = [pwd '\mat\trace.mat'];
                     else;
                        file = [pwd '/mat/trace.mat'];
                     end;
                     a = load(file);
                     trace_table = getfield(a,['trace_12_' num2str(tm.q1,'%0.0f') '_rt']);
                  end;
               end;
               if isempty(trace_table)==0;
                  rand('state',sum(100*clock));
                  %
                  new_trace = rand(10000+50,1);
                  new_trace = sort(new_trace(51:10000+50,:));
                  trace_quant_var = quantiles_fcn;
                  trace_series = zeros(10000,1);
                  for k=1:10000;
                     for j=1:220;
                        if new_trace(k,1)<=trace_quant_var(j,1);
                           trace_series(k,1) = trace_table(j,tm.n-my_r);
                           break;
                        elseif j==220;
                           trace_series(k,1) = trace_table(221,tm.n-my_r);
                        end;
                     end;
                  end;
               end;
            elseif (tm.dummies==0)&(tm.q1==0)&(tm.q0>0);
               %
               % create trace table
               %
               trace_table = trace_exoi0_quant(tm.n,tm.p,tm.pe,tm.q0,quantiles_fcn,my_r,tm.deterselect,tm.d,tm.beta,tm.S_01,tm.M_02,tm.M_12,tm.M_22,tm.Z0,tm.Z1,tm.Z2);
               if isempty(trace_table)==0;
                  rand('state',sum(100*clock));
                  %
                  new_trace = rand(10000+50,1);
                  new_trace = sort(new_trace(51:10000+50,:));
                  trace_quant_var = quantiles_fcn;
                  trace_series = zeros(10000,1);
                  for k=1:10000;
                     for j=1:220;
                        if new_trace(k,1)<=trace_quant_var(j,1);
                           trace_series(k,1) = trace_table(j,1);
                           break;
                        elseif j==220;
                           trace_series(k,1) = trace_table(221,1);
                        end;
                     end;
                  end;
               end;
            end;
            if isempty(trace_series)==0;
               mean_trace = (1/10000)*sum(trace_series);
               std_trace = sqrt((1/10000)*sum((trace_series-mean_trace).*(trace_series-mean_trace)));
               my_cv = [my_cv;mean_trace;std_trace];
               res_str = strvcat(res_str,'From the asymptotic distribution we have the following quantile values:',' ',sprintf([prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],my_cv),' ');
            end;
         end;
      end;
      if isempty(boot_size)==0;
         res_str = strvcat(res_str,['                      Empirical size for r=' num2str(my_r,'%0.0f')],'                      ----------------------',' ','Test level     20%     10%      5%      2%      1%',sprintf(['             %6.2f  %6.2f  %6.2f  %6.2f  %6.2f'],100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1))),' ');
      end;
      if isempty(boot_pval)==0;
         res_str = strvcat(res_str,'                      Empirical p-value','                      -----------------',' ',['LR(r=' num2str(my_r,'%0.0f') ')  = ' num2str(tm.trace(my_r+1,1),['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],['p-value = ' num2str(boot_pval,['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'])],' ');
      end;
      for i=1:5;
         if i==1;
            x_str = '1';
            add_str = '';
         elseif i==2;
            x_str = '2';
            add_str = '';
         elseif i==3;
            x_str = '5';
            add_str = '';
         elseif i==4;
            x_str = '10';
            add_str = '-';
         else;
            x_str = '20';
            add_str = '-';
         end;
         if isempty(boot_selrank)==0;
            res_str = strvcat(res_str,['   Frequencies of preferred cointegration rank at ' x_str '% level'],['   -------------------------------------------------------' add_str],' ');
            h_str = ' ';
            k_str = ' ';
            r_str = '';
            s_str = '';
            for j=0:tm.n;
               if j<10;
                  h_str = [h_str '   r=%0.0f  '];
               else;
                  h_str = [h_str '   r=%0.0f '];
               end;
               r_str = [r_str '  %6.2f'];
               if j<tm.n;
                  s_str = [s_str '  %6.2f'];
                  if j<10;
                     if j>0;
                        k_str = [k_str '   r<=%0.0f '];
                     else;
                        k_str = [k_str '   r=%0.0f  '];
                     end;
                  else;
                     k_str = [k_str '   r<=%0.0f'];
                  end;
               end;
            end;
            nums = (0:1:tm.n)';
            res_str = strvcat(res_str,sprintf(h_str,nums),' ',sprintf(r_str,100*boot_selrank(i,:)'),' ');
            nums = nums(1:length(nums)-1,1);
            res_str = strvcat(res_str,['       Rejection rates for null hypothesis at ' x_str '% level'],['       -----------------------------------------------' add_str],' ');
            res_str = strvcat(res_str,sprintf(k_str,nums),' ',sprintf(s_str,100*boot_power(i,:)'),' ');
            if i<5;
               res_str = strvcat(res_str,'--------------------------------------------------------------',' ');
            end;
         end;
      end;
      %
      res_str = strvcat(res_str,'**************************************************************',' ');
      %
      if tm.const_model(1)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
      elseif tm.const_model(2)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
      elseif tm.const_model(3)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
      elseif tm.const_model(4)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
      elseif tm.const_model(5)==1;
         file_txt = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
      end;
      fid_txt = fopen(file_txt,'wt');
      for i=1:size(res_str,1);
         fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
      end;
      fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
      fclose(fid_txt);
      %
      % write summary to tex-file
      %
      if tm.const_model(1)==1;
         file_tex = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.tex'];
      elseif tm.const_model(2)==1;
         file_tex = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.tex'];
      elseif tm.const_model(3)==1;
         file_tex = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.tex'];
      elseif tm.const_model(4)==1;
         file_tex = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.tex'];
      elseif tm.const_model(5)==1;
         file_tex = [curr_ini.simulatedir  tm.modelfile '-trace-boot-summary-' tm.bc bootstyle num2str(tm.n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.tex'];
      end;
      prt_val = ['%0.' num2str(curr_ini.decimals,'%0.0f') 'f'];
      file_tex = strrep(file_txt,'.txt','.ltx');
      f_id = fopen(file_tex,'wt');
      fprintf(f_id,'\\begin{tabular}{ll}\n');
      fprintf(f_id,['Model: & ' my_mod ' \\\\\n']);
      fprintf(f_id,['\\#Endogenous variables: & ' num2str(tm.n,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Cointegration relations: & ' num2str(my_r,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Replications: & ' num2str(rep,'%0.0f') ' \\\\\n']);
      fprintf(f_id,['\\#Draws per replication: & ' num2str(my_T,'%0.0f') ' \\\\\n']);
      if blocksize>1;
         fprintf(f_id,['Block size length: & ' num2str(blocksize,'%0.0f') ' \\\\\n']);
      end;
      fprintf(f_id,'\\end{tabular}\n\n');
      for i=1:tm.n;
         fprintf(f_id,'\\begin{tabular}{rrrrrrr}\n');
         fprintf(f_id,['\\multicolumn{7}{c}{LR Trace test for $r \\leq ' num2str(i-1,'%0.0f') '$} \\\\\n']);
         fprintf(f_id,'80\\%% & 90\\%% & 95\\%% & 98\\%% & 99\\%% & Mean & Std. Dev. \\\\\n');
         max_std = sqrt( (1/rep)*sum( ( trace_sorted(:,i) - ( (1/rep)*sum(trace_sorted(:,i)) ) ).*( trace_sorted(:,i) - ( (1/rep)*sum(trace_sorted(:,i)) ) ) ) );
         fprintf(f_id,[prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' & ' prt_val ' \\\\ \n'],trace_sorted(my_80,i),trace_sorted(my_90,i),trace_sorted(my_95,i),trace_sorted(my_975,i),trace_sorted(my_99,i),(1/rep)*sum(trace_sorted(:,i)),max_std);
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      set(boot_trace.display,'UserData',trace_sorted);
      clear('trace_sorted');
      if isempty(boot_size)==0;
         fprintf(f_id,'\\begin{tabular}{rrrrr}\n');
         fprintf(f_id,['\\multicolumn{5}{c}{Empirical size for $r=' num2str(my_r,'%0.0f') '$} \\\\\n']);
         fprintf(f_id,'20\\%% & 10\\%% & 5\\%% & 2\\%% & 1\\%% \\\\\n');
         fprintf(f_id,'%0.2f & %0.2f & %0.2f & %0.2f & %0.2f \\\\\n',100*(1-boot_size(1,5)),100*(1-boot_size(1,4)),100*(1-boot_size(1,3)),100*(1-boot_size(1,2)),100*(1-boot_size(1,1)));
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      if isempty(boot_pval)==0;
         fprintf(f_id,'\\begin{tabular}{ll}\n');
         fprintf(f_id,'\\multicolumn{2}{c}{Empirical $p$-value} \\\\\n');
         fprintf(f_id,[' & LR($r=%0.0f$) = ' prt_val ' \\\\ \n'],my_r,tm.trace(my_r+1,1));
         fprintf(f_id,[' & $p$-value = ' prt_val ' \\\\ \n'],boot_pval);
         fprintf(f_id,'\\end{tabular}\n\n');
      end;
      r_str = 'r';
      r1_str = 'r';
      prt_str = '%0.2f';
      prt1_str = '%0.2f';
      p_str = '$r=%0.0f$';
      p1_str = '$r \\leq %0.0f$';
      for i=1:tm.n;
         prt_str = [prt_str ' & %0.2f'];
         p_str = [p_str ' & $r=%0.0f$'];
         r_str = [r_str 'r'];
         if i<tm.n;
            prt1_str = [prt1_str ' & %0.2f'];
            p1_str = [p1_str ' & $r \\leq %0.0f$'];
            r1_str = [r1_str 'r'];
         end;
      end;
      for i=1:5;
         if i==1;
            x_str = '1';
         elseif i==2;
            x_str = '2';
         elseif i==3;
            x_str = '5';
         elseif i==4;
            x_str = '10';
         else;
            x_str = '20';
         end;
         if isempty(boot_selrank)==0;
            fprintf(f_id,'\\halfruler\n\n');
            fprintf(f_id,['\\begin{tabular}{' r_str '}\n']);
            fprintf(f_id,['\\multicolumn{' num2str(size(r_str,2),'%0.0f') '}{c}{Frequencies of preferred cointegration rank at ' x_str '\\%% level} \\\\\n']);
            fprintf(f_id,[p_str ' \\\\\n'],(0:1:tm.n));
            fprintf(f_id,[prt_str ' \\\\\n'],100*boot_selrank(i,:));
            fprintf(f_id,'\\end{tabular}\n\n');
            fprintf(f_id,['\\begin{tabular}{' r1_str '}\n']);
            fprintf(f_id,['\\multicolumn{' num2str(size(r1_str,2),'%0.0f') '}{c}{Rejection rates for $H_0$ at ' x_str '\\%% level} \\\\\n']);
            fprintf(f_id,[p1_str ' \\\\\n'],(0:1:tm.n-1));
            fprintf(f_id,[prt1_str ' \\\\\n'],100*boot_power(i,:));
            fprintf(f_id,'\\end{tabular}\n\n');
         end;
      end;
      fprintf(f_id,'\\ruler\n\n%%*************************************************************\n');
      fclose(f_id);
      if curr_ini.noprint==0;
         set(boot_trace.output,'Enable','on');
      end;
      set(boot_trace.summarymenu,'Enable','on','UserData',file_txt);
      set(boot_trace.summary,'Enable','on');
%      if my_r<tm.n;
         set(boot_trace.display,'Enable','on');
         set(boot_trace.displaymenu,'Enable','on');
         set(boot_trace.histogram,'Enable','on');
         set(boot_trace.histogrammenu,'Enable','on');
%      end;
      set(boot_trace.matfilebutton,'Enable','on');
      set(boot_trace.matfilemenu,'Enable','on');
      set(waitf.text,'UserData','done');
      delete(mywait);
      drawnow;
   else;
      setlogtext('Cancelled...');
   end;
   tm.trace_run = 0;
   %
   probrank_str = 'on';
   for i=0:tm.n;
      full_mat = '';
      if tm.const_model(1)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
      elseif tm.const_model(2)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
      elseif tm.const_model(3)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
      elseif tm.const_model(4)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
      elseif tm.const_model(5)==1;
         full_mat = [curr_ini.simulatedir  tm.modelfile '-trace-boot-full-' tm.bc bootstyle num2str(tm.n) '.' num2str(i) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
      end;
      if fileexist(full_mat)==0;
         probrank_str = 'off';
         break;
      end;
   end;
   set(boot_trace.probrank,'Enable',probrank_str);
   set(boot_trace.probrankmenu,'Enable',probrank_str);
   %
   set(trace_boot_gui,'Visible','on');
case 'done'
   if tm.trace_run==0;
      set(boot_trace.done,'UserData','done');
      pid = get(boot_trace.filemenu,'UserData');
      if isempty(pid)==1;
         delete(trace_boot_gui);
      else;
         close(trace_boot_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(trace_boot_gui,'Name') ' ' fix_filepath([pwd '\icons\bootstrap.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(boot_trace.filemenu,'UserData',pid);
         set(trace_boot_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(trace_boot_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(boot_trace.matfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(boot_trace.done,'UserData','done');
end;

%
% end of trace_bootstrap.m
%
