function currdir = uigetdir_old( varargin )

% UIGETDIR_OLD A dialog window that fetches a directory; analogous to UIGETFILE.
%

%   Original Author(s): P. N. Secakusuma, 27/04/98
%   Copyright (c) 1997 by The MathWorks, Inc.
%   $Revision: 1.0 $   $Date: 1998/04/27 13:00:00 $

%
%   Considerable Changes: Anders Warne, 05/30/2003
%   This verions: May 18, 2006
%
%   Accepts 2 optional input arguments:
%   start_path  dialog_title
%
%   Returns current base directory if OK pressed, else
%   returns 0 (=cancel or close)
%

if nargin==0;
   origdir = pwd;
   name = 'Browse for Directory';
else;
   if isstr(varargin{1})==1;
      %
      % need to check if we're dealing with an existing directory
      %
      origdir = varargin{1};
      if strcmp(origdir(1,size(origdir,2)),'\')==1;
         origdir = origdir(1,1:size(origdir,2)-1);
      end;
      checkdir = dir(origdir);
      if size(checkdir,1)==0;
         mystatus = makedirs(varargin{1},0);
         if mystatus==0;
            origdir = pwd;
         end;
      end;
   end;
   if nargin==2;
      if isstr(varargin{2})==1;
         name = varargin{2};
         name = strtrim(name(1,:));
      end;
   else;
      name = 'Browse for Directory';
   end;
end;


if (nargin==0)|(isstr(varargin{1})==1);
   realscrsz = get(0,'ScreenSize');

   fig = figure('NumberTitle', 'off', ...
      'MenuBar', 'none', ...
      'Name',name, ...
      'Resize', 'off', ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Units','pixels', ...
      'Position', [(realscrsz(3)-373)/2 (realscrsz(4)-390)/2 373 390], ...
      'WindowStyle','modal', ...
      'Visible','off', ...
      'CloseRequestFcn','set(gcf,''Userdata'',''Cancel'')', ...
      'Tag','GetDirectoryWindow');

   if matlabnumber>=7.0;
      set(fig,'DockControl','off');
   end;

   imageaxes = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[20 348 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   mycons = getstoredimages;
   curr_ini = find_inisettings;
   if curr_ini.use_toolbar_bgcolor==1;
      bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
      bgcolor(1) = max(0,bgcolor(1));
      bgcolor(2) = max(0,bgcolor(2));
      bgcolor(3) = max(0,bgcolor(3));
   else;
      bgcolor = get(0,'defaultuicontrolbackgroundcolor');
   end;
   %
   image('CData',mirrorimage(maketrans(mycons.explore_image,[160 160 164],bgcolor)),'Clipping','off','Parent',imageaxes);

   uicontrol('Style', 'Text', ...
      'String','Current Directories:', ...
      'HorizontalAlignment', 'left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Position', [20 320 100 20], ...
      'Tag','BrowseText');

   hedit = uicontrol('Style', 'Edit', ...
      'String',origdir, ...
      'UserData',origdir, ...
      'HorizontalAlignment', 'left', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[80 60 273 25], ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Tag','PWDText', ...
      'Callback','uigetdir_old(5)');

   DirList = dir(origdir);
   [void,ind] = sort({DirList.name});
   DirList = DirList(ind);
   DirName = { DirList.name }';
   finddir = find(cat(1, DirList.isdir));
   finddir = finddir(2:size(finddir,1),:);
   DirName = DirName(finddir);

   hlist = uicontrol('Style', 'Listbox', ...
      'String', DirName, ...
      'BackgroundColor', 'w', ...
      'Position', [20 100 333 220], ...
      'Callback', 'uigetdir_old(1)', ...
      'FontSize',curr_ini.gui_fontsize+2, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Max', 1, ...
      'Tag', 'DirectoryContentListbox');

   uicontrol('Style', 'Text', ...
      'String','Directory:', ...
      'HorizontalAlignment', 'left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Position', [20 60 60 20], ...
      'Tag','ChosenDirectoryText');

   ok_btn = uicontrol('Style', 'Pushbutton', ...
      'String', 'OK', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Callback', 'uigetdir_old(2)', ...
      'Position', [80 15 88 30]);

   uicontrol('Style', 'Pushbutton', ...
      'String', 'Cancel', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Callback', 'uigetdir_old(3)', ...
      'Position', [172.5 15 88 30]);

   uicontrol('Style', 'Pushbutton', ...
      'String', 'New Directory', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Callback', 'uigetdir_old(4)', ...
      'Position', [265 15 88 30]);

   if (iswinnt==1)&(iscompiled==1)&(curr_ini.noicon==1);
      set(fig,'WindowStyle','normal');
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(fig,'Name') ' NULL'];
      dos(prog);
      wait_fcn(curr_ini.delay);
      pos = get(fig,'Position');
      set(fig,'Position',[0 0 1 1]);
   end;

   set(fig,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1);
      if curr_ini.noicon==1;
         drawnow;
         set(fig,'WindowStyle','modal');
         prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(fig,'Name') ' NULL'];
         dos(prog);
         wait_fcn(curr_ini.delay);
         set(fig,'Position',pos);
      end;
      drawnow;
      if matlabnumber<7;
         prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(fig,'Name') ' 3'];
         dos(prog);
         drawnow;
      else;
         uicontrol(ok_btn);
      end;
      if curr_ini.noicon==1;
         set(fig,'Position',pos);
      end;
   elseif matlabnumber>=7;
      uicontrol(ok_btn);
   end;

   waitfor(fig, 'Userdata');
              
   switch get(fig, 'Userdata');
      case 'OK';
         currentdir = get(hedit, 'String');
      case 'Cancel';
         currentdir = 0;
      end;
      if nargout==1;
         if strcmp(computer,'PCWIN')==1;
            if isstr(currentdir)==1;
               currdir = [currentdir '\'];
            else;
               currdir = currentdir;
            end;
         else;
            currdir = currentdir;
         end;
      end;
      delete(fig);
else;
   switch varargin{1};
   case 1;
      if strcmp(get(gcf, 'SelectionType'), 'open'),
         hfig  = findobj('Tag', 'GetDirectoryWindow');
         hlist = findobj(hfig, 'Tag', 'DirectoryContentListbox');
         hedit = findobj(hfig, 'Tag', 'PWDText');
         hlist_val = get(hlist, 'Value');
         hlist_str = get(hlist, 'String');
         hlist_dir = char(hlist_str{hlist_val});
         if isstr(hlist_dir)==1;
            hlist_dir = strtrim(hlist_dir(1,:));
         end;
         origdir = get(hedit,'String');
         if strcmp(hlist_dir,'..')==1;
            currentdir = getpath(origdir);
            if (strcmp(currentdir(1,size(currentdir,2)),'\')==1)|(strcmp(currentdir(1,size(currentdir,2)),'/')==1);
               currentdir = currentdir(1,1:size(currentdir,2)-1);
            end;
         else;
            if strcmp(computer,'PCWIN')==1;
               currentdir = [origdir '\' hlist_dir];
            else;
               currentdir = [origdir '/' hlist_dir];
            end;
         end;
         DirList = dir(currentdir);
         [void,ind] = sort({DirList.name});
         DirList = DirList(ind);
         DirName = { DirList.name }';
         finddir = find(cat(1, DirList.isdir));
         finddir = finddir(2:size(finddir,1),:);
         DirName = DirName(finddir);
         set(hlist,'String',DirName,'Value', 1);
         set(hedit,'String',currentdir,'UserData',currentdir);
      end;
   case 2;
      set(gcf, 'Userdata', 'OK');
   case 3;
      set(gcf, 'Userdata', 'Cancel');
   case 4;
      [action,new_directory] = editdlg('Create New Directory','Enter Name:','new-dir');
      new_directory = strrep(new_directory,' ','');
      new_directory = strrep(new_directory,'*','');
      new_directory = strrep(new_directory,'''','');
      new_directory = strrep(new_directory,'"','');
      new_directory = strrep(new_directory,'#','');
      new_directory = strrep(new_directory,'(','');
      new_directory = strrep(new_directory,')','');
      new_directory = strrep(new_directory,'[','');
      new_directory = strrep(new_directory,']','');
      new_directory = strrep(new_directory,'{','');
      new_directory = strrep(new_directory,'}','');
      new_directory = strrep(new_directory,'~','');
      new_directory = strrep(new_directory,'`','');
      new_directory = strrep(new_directory,'','');
      new_directory = strrep(new_directory,'[','');
      new_directory = strrep(new_directory,'\','');
      new_directory = strrep(new_directory,'/','');
      new_directory = strrep(new_directory,'<','');
      new_directory = strrep(new_directory,'>','');
      new_directory = strrep(new_directory,'|','');
      new_directory = strrep(new_directory,':','');
      new_directory = strrep(new_directory,';','');
      new_directory = strrep(new_directory,'?','');
      new_directory = strrep(new_directory,'!','');
      if strcmp(action,'OK')==1;
         hfig  = findobj('Tag','GetDirectoryWindow');
         hlist = findobj(hfig,'Tag','DirectoryContentListbox');
         hedit = findobj(hfig,'Tag','PWDText');
         hlist_str = get(hlist,'String');
         base_directory = get(hedit,'String');
         newdir = 1;
         for i=1:size(hlist_str,1);
            hlist_diri = char(hlist_str{i});
            if strcmp(lower(new_directory),lower(hlist_diri))==1;
               newdir = 0;
               break;
            end;
         end;
         if isempty(new_directory)==1;
            newdir = 2;
         end;
         create_dir = '';
         if newdir==1;
            if strcmp(computer,'PCWIN')==1;
               create_dir = [base_directory '\' new_directory '\'];
               currentdir = [base_directory '\' new_directory];
            else;
               if isunix==1;
                  create_dir = [base_directory '/' new_directory];
                  currentdir = create_dir;
               end;
            end;
            if isempty(create_dir)==0;
               mystatus = makedirs(create_dir,0);
               if mystatus>0;
                  DirList = dir(currentdir);
                  [void,ind] = sort({DirList.name});
                  DirList = DirList(ind);
                  DirName = { DirList.name }';
                  finddir = find(cat(1, DirList.isdir));
                  finddir = finddir(2:size(finddir,1),:);
                  DirName = DirName(finddir);
                  set(hlist,'String',DirName,'Value', 1);
                  set(hedit,'String',currentdir,'UserData',currentdir);
               else;
                  set(hedit,'String',get(hedit,'UserData'));
               end;
            end;
         elseif newdir==2;
            this_text = 'You didn''t select a name for the directory!';
            about(this_text,'error','Bad Directory Name',120,350);
         else;
            this_text = ['The directory ' new_directory ' already exists. Please select another name!'];
            about(this_text,'error','Bad Directory Name',120,350);
         end;
      end;
   case 5;
      hfig  = findobj('Tag','GetDirectoryWindow');
      hlist = findobj(hfig,'Tag','DirectoryContentListbox');
      hedit = findobj(hfig,'Tag','PWDText');
      hlist_str = get(hlist,'String');
      new_directory = get(hedit,'String');
      if isempty(new_directory)==1;
         currentdir = get(hedit,'UserData');
         set(hedit,'String',currentdir);
         return;
      end;
      new_directory = new_directory(1,:);
      new_directory = strrep(new_directory,' ','');
      new_directory = strrep(new_directory,'*','');
      new_directory = strrep(new_directory,'''','');
      new_directory = strrep(new_directory,'"','');
      new_directory = strrep(new_directory,'#','');
      new_directory = strrep(new_directory,'(','');
      new_directory = strrep(new_directory,')','');
      new_directory = strrep(new_directory,'[','');
      new_directory = strrep(new_directory,']','');
      new_directory = strrep(new_directory,'{','');
      new_directory = strrep(new_directory,'}','');
      new_directory = strrep(new_directory,'~','');
      new_directory = strrep(new_directory,'`','');
      new_directory = strrep(new_directory,'','');
      new_directory = strrep(new_directory,'[','');
      new_directory = strrep(new_directory,'<','');
      new_directory = strrep(new_directory,'>','');
      new_directory = strrep(new_directory,'|','');
      new_directory = strrep(new_directory,';','');
      new_directory = strrep(new_directory,'?','');
      new_directory = strrep(new_directory,'!','');
      if isempty(new_directory)==1;
         currentdir = get(hedit,'UserData');
         set(hedit,'String',currentdir);
         return;
      end;
      if (strcmp(new_directory(1,size(new_directory,2)),'\')==1)|(strcmp(new_directory(1,size(new_directory,2)),'\')==1);
         new_directory = new_directory(1,1:size(new_directory,2)-1);
      end;
      DirList = dir(new_directory);
      if size(DirList,1)>=1;
         %
         % we are dealing with an existing directory
         %
         [void,ind] = sort({DirList.name});
         DirList = DirList(ind);
         DirName = { DirList.name }';
         finddir = find(cat(1, DirList.isdir));
         finddir = finddir(2:size(finddir,1),:);
         DirName = DirName(finddir);
         set(hlist,'String',DirName,'Value',1);
         set(hedit,'String',new_directory,'UserData',new_directory);
      else;
         %
         % we may be dealing with a new directory
         %
         check_path = getpath(new_directory);
         if isempty(check_path)==1;
            %
            % treat new_directory as a subdirectory
            %
            if strcmp(computer,'PCWIN')==1;
               show_dir = [get(hedit,'UserData') '\' new_directory];
               new_directory = [get(hedit,'UserData') '\' new_directory '\'];
            else;
               new_directory = [get(hedit,'UserData') '/' new_directory];
               show_dir = new_directory;
            end;
         else;
            %
            % check to make sure that check_path is a valid path
            %
            check_dir = dir(check_path);
            if size(check_dir)>=1;
               if strcmp(computer,'PCWIN')==1;
                  show_dir = new_directory;
                  new_directory = [new_directory '\'];
               else;
                  show_dir = new_directory;
               end;
            else;
               set(hedit,'String',get(hedit,'UserData'));
               this_text = strvcat('The path you entered',' ',['   ' new_directory],' ','is not valid. Please try again!');
               about(this_text,'error','Bad Path...',120,350);
               return;
            end;
         end;
         %
         % check if user wants to create the new directory
         %
         this_text = strvcat('Are you sure you want to create the directory:',' ',['   ' show_dir '?']);
         answer = query(this_text,'question',120,'Create New Directory...',400);
         if strcmp(answer,'Yes')==1;
            mystatus = makedirs(new_directory,0);
            if mystatus>0;
               DirList = dir(show_dir);
               [void,ind] = sort({DirList.name});
               DirList = DirList(ind);
               DirName = { DirList.name }';
               finddir = find(cat(1, DirList.isdir));
               finddir = finddir(2:size(finddir,1),:);
               DirName = DirName(finddir);
               set(hlist,'String',DirName,'Value',1);
               set(hedit,'String',show_dir,'UserData',show_dir);
            else;
               set(hedit,'String',get(hedit,'UserData'));
            end;
         else;
            set(hedit,'String',get(hedit,'UserData'));
         end;
      end;
   end;
end;

return;

%
% end of uigetdir_old.m
%
