%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab function for vectorizing an nxn symmetric      %
%          matrix A column by column using only the elements on  %
%          and below the diagonal                                %
%                                                                %
%          Function: vech                                        %
%                                                                %
%          Input:                                                %
%                        A: nxn matrix                           %
%                                                                %
%          Output:                                               %
%                        vecha: n(n+1)/2x1 vector                %
%                                                                %
%          This version:        July 9, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function vecha = vech(A)

[n m] = size(A);

if n==m;
   if abs(A-A')<1.0e-005;
      Dn = duplication(n);
      Dmp = inverse(Dn'*Dn)*Dn';
      vecha = Dmp*vec(A);
   else;
      vecha = [];
   end;
else;
   vecha = [];
end;

%
% end of function vech.m
%
